@@ -10,7 +10,10 @@
 #  Website: https://github.com/vacanza/holidays
 #  License: MIT (see LICENSE file)
 
+from __future__ import annotations
+
 from gettext import gettext as tr
+from typing import TYPE_CHECKING
 
 from holidays.calendars import (
     _CustomBuddhistHolidays,
@@ -51,6 +54,9 @@ from holidays.observed_holiday_base import (
     SUN_TO_NEXT_WORKDAY,
 )
 
+if TYPE_CHECKING:
+    from datetime import date
+
 
 class Malaysia(
     ObservedHolidayBase,
@@ -163,6 +169,14 @@ class Malaysia(
         kwargs.setdefault("observed_rule", SUN_TO_NEXT_WORKDAY)
         super().__init__(*args, **kwargs)
 
+    def _get_weekend(self, dt: date) -> set[int]:
+        if (
+            self.subdiv == "01" and (dt.year <= 1994 or 2014 <= dt.year <= 2024)
+        ) or self.subdiv in {"02", "03", "11"}:
+            return {FRI, SAT}
+        else:
+            return {SAT, SUN}
+
     def _populate_public_holidays(self):
         self.dts_observed = set()
 
@@ -229,13 +243,10 @@ class Malaysia(
             self.subdiv == "01" and (self._year <= 1994 or 2014 <= self._year <= 2024)
         ) or self.subdiv == "02":
             self._observed_rule = FRI_TO_NEXT_WORKDAY
-            self.weekend = {FRI, SAT}
         elif self.subdiv in {"03", "11"}:
             self._observed_rule = SAT_TO_NEXT_WORKDAY
-            self.weekend = {FRI, SAT}
         else:
             self._observed_rule = SUN_TO_NEXT_WORKDAY
-            self.weekend = {SAT, SUN}
 
         if self.observed:
             self._populate_observed(self.dts_observed)
