@@ -13,7 +13,7 @@
 from __future__ import annotations
 
 from gettext import gettext as tr
-from typing import Optional, TYPE_CHECKING
+from typing import TYPE_CHECKING
 
 from holidays.calendars.gregorian import (
     JAN,
@@ -32,7 +32,6 @@ from holidays.calendars.gregorian import (
     FRI,
     SAT,
     SUN,
-    _get_nth_weekday_of_month,
 )
 from holidays.constants import GOVERNMENT, OPTIONAL, PUBLIC, SCHOOL, WORKDAY
 from holidays.groups import ChineseCalendarHolidays, InternationalHolidays, StaticHolidays
@@ -101,10 +100,8 @@ class Taiwan(ObservedHolidayBase, ChineseCalendarHolidays, InternationalHolidays
         if dt.year <= 2000:
             weekend = {SUN}
             if dt.weekday() == SAT:
-                if dt in {
-                    _get_nth_weekday_of_month(2, SAT, dt.month, dt.year),  # 2nd Saturday.
-                    _get_nth_weekday_of_month(4, SAT, dt.month, dt.year),  # 4th Saturday.
-                }:
+                nth_saturday = (dt.day - 1) // 7 + 1  # Saturday number in the month.
+                if nth_saturday in {2, 4}:
                     weekend.add(SAT)
         else:
             weekend = {SAT, SUN}
@@ -112,7 +109,7 @@ class Taiwan(ObservedHolidayBase, ChineseCalendarHolidays, InternationalHolidays
         return weekend
 
     def _populate_observed(
-        self, dts: set[date], rule: Optional[ObservedRule] = None, since: int = 2015
+        self, dts: set[date], rule: ObservedRule | None = None, since: int = 2015
     ) -> None:
         """
         Taiwan's General Observance Rule first started in 2015 as per
@@ -348,7 +345,7 @@ class TaiwanStaticHolidays:
     substituted_date_format = tr("%Y-%m-%d")
 
     # Day off (substituted from %s).
-    substituted_label = tr("休息日（%s日起取代）")
+    substituted_label = tr("放假日（%s 補班）")
 
     # Women's Day.
     womens_day = tr("婦女節")
