@@ -24,8 +24,8 @@ class Turkey(HolidayBase, InternationalHolidays, IslamicHolidays, StaticHolidays
 
     References:
         * <https://en.wikipedia.org/wiki/Public_holidays_in_Turkey>
-        * [Law 2739](https://web.archive.org/web/20250102114014/https://www5.tbmm.gov.tr/tutanaklar/KANUNLAR_KARARLAR/kanuntbmmc015/kanuntbmmc015/kanuntbmmc01502739.pdf)
-        * [Law 2429](https://web.archive.org/web/20250121111504/http://www.mevzuat.gov.tr/MevzuatMetin/1.5.2429.pdf)
+        * [Law 2739 of May 27, 1935](https://web.archive.org/web/20250102114014/https://www5.tbmm.gov.tr/tutanaklar/KANUNLAR_KARARLAR/kanuntbmmc015/kanuntbmmc015/kanuntbmmc01502739.pdf)
+        * [Law 2429 of March 19, 1981](https://web.archive.org/web/20250121111504/http://www.mevzuat.gov.tr/MevzuatMetin/1.5.2429.pdf)
         * [Hijri calendar holidays](https://web.archive.org/web/20250415045516/https://vakithesaplama.diyanet.gov.tr/hicriden_miladiye.php)
     """
 
@@ -35,7 +35,7 @@ class Turkey(HolidayBase, InternationalHolidays, IslamicHolidays, StaticHolidays
     estimated_label = tr("%s (tahmini)")
     supported_categories = (HALF_DAY, PUBLIC)
     supported_languages = ("en_US", "tr", "uk")
-    # Law 2739 of 27 May 1935.
+    # Law 2739 of May 27, 1935.
     start_year = 1936
 
     def __init__(self, *args, islamic_show_estimated: bool = True, **kwargs):
@@ -64,7 +64,10 @@ class Turkey(HolidayBase, InternationalHolidays, IslamicHolidays, StaticHolidays
             else tr("Ulusal Egemenlik Bayramı")
         )
 
-        if self._year >= 2009:
+        if self._year <= 1980:
+            # Spring Day.
+            self._add_labor_day(tr("Bahar Bayramı"))
+        elif self._year >= 2009:
             # Labour and Solidarity Day.
             self._add_labor_day(tr("Emek ve Dayanışma Günü"))
 
