@@ -11,7 +11,6 @@
 #  License: MIT (see LICENSE file)
 
 from gettext import gettext as tr
-from typing import Union
 
 from holidays.calendars.gregorian import (
     FEB,
@@ -115,7 +114,7 @@ class UnitedStates(ObservedHolidayBase, ChristianHolidays, InternationalHolidays
     supported_languages = ("en_US", "th")
     # Independence Declared on July 4th, 1776.
     start_year = 1777
-    subdivisions: Union[tuple[()], tuple[str, ...]] = (
+    subdivisions: tuple[()] | tuple[str, ...] = (
         "AK",  # Alaska.
         "AL",  # Alabama.
         "AR",  # Arkansas.
@@ -1282,6 +1281,10 @@ class UnitedStates(ObservedHolidayBase, ChristianHolidays, InternationalHolidays
             # Presidents' Day.
             self._add_holiday_3rd_mon_of_feb(tr("Presidents' Day"))
 
+        if self._year >= 2014:
+            # Native American Heritage Day.
+            self._add_holiday_1_day_past_4th_thu_of_nov(tr("Native American Heritage Day"))
+
     def _populate_subdiv_wi_public_holidays(self):
         if self._year >= 1976:
             # Susan B. Anthony Day.
