@@ -10,11 +10,9 @@
 #  Website: https://github.com/vacanza/holidays
 #  License: MIT (see LICENSE file)
 
-# ruff: noqa: F401
-
 from holidays.financial.brasil_bolsa_balcao import BrasilBolsaBalcao, BVMF, B3
 from holidays.financial.european_central_bank import EuropeanCentralBank, XECB, ECB, TAR
-from holidays.financial.ice_futures_europe import ICEFuturesEurope, IFEU
+from holidays.financial.ice_futures_europe import IceFuturesEurope, ICEFuturesEurope, IFEU
 from holidays.financial.national_stock_exchange_of_india import (
     NationalStockExchangeOfIndia,
     XNSE,
