@@ -414,6 +414,16 @@ class ChristianHolidays:
         """
         return self._add_holiday(name, _timedelta(self._easter_sunday, +9))
 
+    def _add_saint_anthonys_day(self, name) -> date:
+        """
+        Add Saint Anthony of Padua's Day (June 13th).
+
+        Saint Anthony's Day is celebrated on 13 June, the traditionally
+        accepted date of the saint's death.
+        https://en.wikipedia.org/wiki/Anthony_of_Padua
+        """
+        return self._add_holiday_jun_13(name)
+
     def _add_saint_georges_day(self, name) -> date:
         """
         Add Saint George's Day (April 23th).
@@ -455,6 +465,16 @@ class ChristianHolidays:
         """
         return self._add_holiday_mar_19(name)
 
+    def _add_saint_martins_day(self, name) -> date:
+        """
+        Add Saint Martin of Tours Day (November 11th).
+
+        Saint Martin of Tours is the patron saint of many communities and organizations
+        across Europe, including France's Third Republic.
+        https://en.wikipedia.org/wiki/Martin_of_Tours
+        """
+        return self._add_holiday_nov_11(name)
+
     def _add_saint_patricks_day(self, name) -> date:
         """
         Add Saint Patrick's Day (March 17th).
