@@ -21,7 +21,7 @@ from datetime import date, datetime, timedelta, timezone
 from functools import cached_property
 from gettext import gettext, translation
 from pathlib import Path
-from typing import Any, Literal, Optional, Union, cast
+from typing import Any, Literal, Union, cast
 
 from dateutil.parser import parse
 
@@ -43,15 +43,17 @@ from holidays.calendars.gregorian import (
 from holidays.constants import HOLIDAY_NAME_DELIMITER, PUBLIC, DEFAULT_START_YEAR, DEFAULT_END_YEAR
 from holidays.helpers import _normalize_arguments, _normalize_tuple
 
-CategoryArg = Union[str, Iterable[str]]
-DateArg = Union[date, tuple[int, int], tuple[int, int, int]]
-DateLike = Union[date, datetime, str, float, int]
-SpecialHoliday = Union[tuple[int, int, str], tuple[tuple[int, int, str], ...]]
-SubstitutedHoliday = Union[
-    Union[tuple[int, int, int, int], tuple[int, int, int, int, int]],
-    tuple[Union[tuple[int, int, int, int], tuple[int, int, int, int, int]], ...],
-]
-YearArg = Union[int, Iterable[int]]
+CategoryArg = str | Iterable[str]
+DateArg = date | tuple[int, int] | tuple[int, int, int]
+DateLike = date | datetime | str | float | int
+NameLookup = Literal["contains", "exact", "startswith", "icontains", "iexact", "istartswith"]
+SpecialHoliday = tuple[int, int, str] | tuple[tuple[int, int, str], ...]
+SubstitutedHoliday = (
+    tuple[int, int, int, int]
+    | tuple[int, int, int, int, int]
+    | tuple[tuple[int, int, int, int] | tuple[int, int, int, int, int], ...]
+)
+YearArg = int | Iterable[int]
 
 
 class HolidayBase(dict[date, str]):
@@ -199,9 +201,9 @@ class HolidayBase(dict[date, str]):
     is requested."""
     observed: bool
     """Whether dates when public holiday are observed are included."""
-    subdiv: Optional[str] = None
+    subdiv: str | None = None
     """The subdiv requested as ISO 3166-2 code or one of the aliases."""
-    special_holidays: dict[int, Union[SpecialHoliday, SubstitutedHoliday]] = {}
+    special_holidays: dict[int, SpecialHoliday | SubstitutedHoliday] = {}
     """A list of the country-wide special (as opposite to regular) holidays for
     a specific year."""
     _deprecated_subdivisions: tuple[str, ...] = ()
@@ -213,7 +215,7 @@ class HolidayBase(dict[date, str]):
     """Working days moved to weekends."""
     default_category: str = PUBLIC
     """The entity category used by default."""
-    default_language: Optional[str] = None
+    default_language: str | None = None
     """The entity language used by default."""
     categories: set[str] = set()
     """Requested holiday categories."""
@@ -225,19 +227,19 @@ class HolidayBase(dict[date, str]):
     """Start year of holidays presence for this entity."""
     end_year: int = DEFAULT_END_YEAR
     """End year of holidays presence for this entity."""
-    parent_entity: Optional[type["HolidayBase"]] = None
+    parent_entity: type["HolidayBase"] | None = None
     """Optional parent entity to reference as a base."""
 
     def __init__(
         self,
-        years: Optional[YearArg] = None,
+        years: YearArg | None = None,
         expand: bool = True,
         observed: bool = True,
-        subdiv: Optional[str] = None,
-        prov: Optional[str] = None,  # Deprecated.
-        state: Optional[str] = None,  # Deprecated.
-        language: Optional[str] = None,
-        categories: Optional[CategoryArg] = None,
+        subdiv: str | None = None,
+        prov: str | None = None,  # Deprecated.
+        state: str | None = None,  # Deprecated.
+        language: str | None = None,
+        categories: CategoryArg | None = None,
     ) -> None:
         """
         Args:
@@ -557,27 +559,25 @@ class HolidayBase(dict[date, str]):
 
             if key.step is None:
                 step = 1
-            elif isinstance(key.step, timedelta):
-                step = key.step.days
             elif isinstance(key.step, int):
                 step = key.step
+            elif isinstance(key.step, timedelta):
+                step = key.step.days
             else:
                 raise TypeError(f"Cannot convert type '{type(key.step)}' to int.")
 
             if step == 0:
                 raise ValueError("Step value must not be zero.")
 
-            date_diff = stop - start
-            if date_diff.days < 0 <= step or date_diff.days >= 0 > step:
-                step *= -1
+            diff_days = (stop - start).days
+            if diff_days < 0 <= step or diff_days >= 0 > step:
+                step = -step
 
-            days_in_range = []
-            for delta_days in range(0, date_diff.days, step):
-                day = _timedelta(start, delta_days)
-                if day in self:
-                    days_in_range.append(day)
-
-            return days_in_range
+            return [
+                day
+                for delta_days in range(0, diff_days, step)
+                if (day := _timedelta(start, delta_days)) in self
+            ]
 
         return dict.__getitem__(self, self.__keytransform__(key))
 
@@ -605,7 +605,7 @@ class HolidayBase(dict[date, str]):
             The corresponding `datetime.date` representation.
         """
 
-        dt: Optional[date] = None
+        dt: date | None = None
         # Try to catch `date` and `str` type keys first.
         # Using type() here to skip date subclasses.
         # Key is `date`.
@@ -662,26 +662,21 @@ class HolidayBase(dict[date, str]):
     def __radd__(self, other: Any) -> "HolidayBase":
         return self.__add__(other)
 
-    def __reduce__(self) -> Union[str, tuple[Any, ...]]:
+    def __reduce__(self) -> str | tuple[Any, ...]:
         return super().__reduce__()
 
     def __repr__(self) -> str:
         if self:
             return super().__repr__()
 
-        parts = []
         if hasattr(self, "market"):
-            parts.append(f"holidays.financial_holidays({self.market!r}")
-            parts.append(")")
+            return f"holidays.financial_holidays({self.market!r})"
         elif hasattr(self, "country"):
-            parts.append(f"holidays.country_holidays({self.country!r}")
             if self.subdiv:
-                parts.append(f", subdiv={self.subdiv!r}")
-            parts.append(")")
-        else:
-            parts.append("holidays.HolidayBase()")
+                return f"holidays.country_holidays({self.country!r}, subdiv={self.subdiv!r})"
+            return f"holidays.country_holidays({self.country!r})"
 
-        return "".join(parts)
+        return "holidays.HolidayBase()"
 
     def __setattr__(self, key: str, value: Any) -> None:
         dict.__setattr__(self, key, value)
@@ -794,7 +789,7 @@ class HolidayBase(dict[date, str]):
         """Returns True if the year is leap. Returns False otherwise."""
         return isleap(self._year)
 
-    def _add_holiday(self, name: str, *args) -> Optional[date]:
+    def _add_holiday(self, name: str, *args) -> date | None:
         """Add a holiday."""
         if not args:
             raise TypeError("Incorrect number of arguments.")
@@ -808,6 +803,37 @@ class HolidayBase(dict[date, str]):
         self[dt] = self.tr(name)
         return dt
 
+    def _add_multiday_holiday(
+        self, start_date: date, duration_days: int, *, name: str | None = None
+    ) -> set[date]:
+        """Add a multi-day holiday.
+
+        Args:
+            start_date:
+                First day of the holiday.
+
+            duration_days:
+                Number of additional days to add.
+
+            name:
+                Optional holiday name; inferred from `start_date` if omitted.
+
+        Returns:
+            A set of all added holiday dates.
+
+        Raises:
+            ValueError:
+                If the holiday name cannot be inferred from `start_date`.
+        """
+        if (holiday_name := name or self.get(start_date)) is None:
+            raise ValueError(f"Cannot infer holiday name for date {start_date!r}.")
+
+        return {
+            d
+            for delta in range(1, duration_days + 1)
+            if (d := self._add_holiday(holiday_name, _timedelta(start_date, delta)))
+        }
+
     def _add_special_holidays(self, mapping_names, *, observed=False):
         """Add special holidays."""
         for mapping_name in mapping_names:
@@ -936,7 +962,7 @@ class HolidayBase(dict[date, str]):
                 for category in self._sorted_categories
             )
 
-    def append(self, *args: Union[dict[DateLike, str], list[DateLike], DateLike]) -> None:
+    def append(self, *args: dict[DateLike, str] | list[DateLike] | DateLike) -> None:
         """Alias for [update()][holidays.holiday_base.HolidayBase.update] to mimic list type.
 
         Args:
@@ -953,7 +979,7 @@ class HolidayBase(dict[date, str]):
         """Return a copy of the object."""
         return copy.copy(self)
 
-    def get(self, key: DateLike, default: Union[str, Any] = None) -> Union[str, Any]:
+    def get(self, key: DateLike, default: str | Any = None) -> str | Any:
         """Retrieve the holiday name(s) for a given date.
 
         If the date is a holiday, returns the holiday name as a string.
@@ -996,7 +1022,10 @@ class HolidayBase(dict[date, str]):
         return [name for name in self.get(key, "").split(HOLIDAY_NAME_DELIMITER) if name]
 
     def get_named(
-        self, holiday_name: str, lookup: str = "icontains", split_multiple_names: bool = True
+        self,
+        holiday_name: str,
+        lookup: NameLookup = "icontains",
+        split_multiple_names: bool = True,
     ) -> list[date]:
         """Find all holiday dates matching a given name.
 
@@ -1055,9 +1084,9 @@ class HolidayBase(dict[date, str]):
 
     def get_closest_holiday(
         self,
-        target_date: Optional[DateLike] = None,
+        target_date: DateLike | None = None,
         direction: Literal["forward", "backward"] = "forward",
-    ) -> Optional[tuple[date, str]]:
+    ) -> tuple[date, str] | None:
         """Find the closest holiday relative to a given date.
 
         If `direction` is "forward", returns the next holiday after `target_date`.
@@ -1170,7 +1199,7 @@ class HolidayBase(dict[date, str]):
         dt = self.__keytransform__(key)
         return dt in self.weekend_workdays if self._is_weekend(dt) else dt not in self
 
-    def pop(self, key: DateLike, default: Union[str, Any] = None) -> Union[str, Any]:
+    def pop(self, key: DateLike, default: str | Any = None) -> str | Any:
         """Remove a holiday for a given date and return its name.
 
         If the specified date is a holiday, it will be removed, and its name will
@@ -1201,7 +1230,7 @@ class HolidayBase(dict[date, str]):
 
         return dict.pop(self, self.__keytransform__(key), default)
 
-    def pop_named(self, holiday_name: str, lookup: str = "icontains") -> list[date]:
+    def pop_named(self, holiday_name: str, lookup: NameLookup = "icontains") -> list[date]:
         """Remove all holidays matching the given name.
 
         This method removes all dates associated with a holiday name, so they are
@@ -1276,7 +1305,7 @@ class HolidayBase(dict[date, str]):
         return popped
 
     def update(  # type: ignore[override]
-        self, *args: Union[dict[DateLike, str], list[DateLike], DateLike]
+        self, *args: dict[DateLike, str] | list[DateLike] | DateLike
     ) -> None:
         """Update the object, overwriting existing dates.
 
@@ -1319,11 +1348,11 @@ class HolidaySum(HolidayBase):
     * Holidays are generated (expanded) for all years included in the operands.
     """
 
-    country: Union[str, list[str]]  # type: ignore[assignment]
+    country: str | list[str]  # type: ignore[assignment]
     """Countries included in the addition."""
-    market: Union[str, list[str]]  # type: ignore[assignment]
+    market: str | list[str]  # type: ignore[assignment]
     """Markets included in the addition."""
-    subdiv: Optional[Union[str, list[str]]]  # type: ignore[assignment]
+    subdiv: str | list[str] | None  # type: ignore[assignment]
     """Subdivisions included in the addition."""
     holidays: list[HolidayBase]
     """The original HolidayBase objects included in the addition."""
@@ -1382,7 +1411,7 @@ class HolidaySum(HolidayBase):
         # and Milano, or ... you get the picture.
         # Same goes when countries and markets are being mixed (working, yet
         # still nonsensical).
-        value: Optional[Union[str, list[str]]]
+        value: str | list[str] | None
         for attr in ("country", "market", "subdiv"):
             a1 = getattr(h1, attr, None)
             a2 = getattr(h2, attr, None)
