@@ -13,7 +13,7 @@
 import importlib
 from collections.abc import Iterable
 from threading import RLock
-from typing import Any, Optional
+from typing import Any
 
 from holidays.holiday_base import HolidayBase
 
@@ -287,7 +287,7 @@ COUNTRIES: RegistryDict = {
 FINANCIAL: RegistryDict = {
     "brasil_bolsa_balcao": ("BrasilBolsaBalcao", "BVMF", "B3"),
     "european_central_bank": ("EuropeanCentralBank", "XECB", "ECB", "TAR"),
-    "ice_futures_europe": ("ICEFuturesEurope", "IFEU"),
+    "ice_futures_europe": ("IceFuturesEurope", "IFEU", "ICEFuturesEurope"),
     "national_stock_exchange_of_india": ("NationalStockExchangeOfIndia", "XNSE", "NSE"),
     "ny_stock_exchange": ("NewYorkStockExchange", "XNYS", "NYSE"),
 }
@@ -327,7 +327,7 @@ class EntityLoader:
         cls = self.get_entity()
         return cls(*args, **kwargs)  # type: ignore[misc, operator]
 
-    def __getattr__(self, name: str) -> Optional[Any]:
+    def __getattr__(self, name: str) -> Any | None:
         """Return attribute of a lazy-loaded entity."""
         cls = self.get_entity()
         return getattr(cls, name)
@@ -339,7 +339,7 @@ class EntityLoader:
             f"use the '{self.module_name}.{self.entity_name}' class directly."
         )
 
-    def get_entity(self) -> Optional[HolidayBase]:
+    def get_entity(self) -> HolidayBase | None:
         """Return lazy-loaded entity."""
         if self.entity is None:
             # Avoid deadlock due to importlib.import_module not being thread-safe by caching all
