@@ -7,7 +7,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
+#  Authors: Vacanza Team and individual contributors (see CONTRIBUTORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -59,8 +59,8 @@ def generate_data():
             g_year = g_date.year
             if g_year < g_year_min or g_year > g_year_max:
                 continue
-            if g_year in dates:
-                dates[g_year][hol_name] = g_date
+            if dt := dates.get(g_year):
+                dt[hol_name] = g_date
             else:
                 dates[g_year] = {hol_name: g_date}
 
