@@ -7,7 +7,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
+#  Authors: Vacanza Team and individual contributors (see CONTRIBUTORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -38,6 +38,8 @@ ISLAMIC_HOLIDAYS = (
     (1, 10, "ASHURA"),  # Ashura
     # MY
     (2, 6, "HARI_HOL_JOHOR"),  # Hari Hol of Johor
+    # SN
+    (2, 18, "GRAND_MAGAL_OF_TOUBA"),  # Grand Magal of Touba
     # BH, DJ, EG, ET, IN, ID, MY, MA, NG, PK, TN, AE
     (3, 12, "MAWLID"),  # Birthday of Prophet
     # DJ, ID, IR, MY, AE
@@ -83,11 +85,11 @@ def generate_data():
                 h_day = convert.Hijri(h_year, h_month, 1).month_length() + h_day + 1
             g_date = convert.Hijri(h_year, h_month, h_day).to_gregorian()
             g_year = g_date.year
-            if g_year in dates:
-                if hol_name in dates[g_year]:
-                    dates[g_year][hol_name].append(g_date)
+            if dt := dates.get(g_year):
+                if dts := dt.get(hol_name):
+                    dts.append(g_date)
                 else:
-                    dates[g_year][hol_name] = [g_date]
+                    dt[hol_name] = [g_date]
             else:
                 dates[g_year] = {hol_name: [g_date]}
 
