@@ -24,9 +24,9 @@ def main():
     entities_data = [
         "* [Overview](index.md)",
         "* [Additional Examples](examples.md)",
+        "* [Changelog](changelog.md)",
         "* [Contributing](contributing.md)",
         "* [API Reference](api.md)",
-        "* [Mixins](mixins.md)",
         "* Supported Entities",
     ]
 
@@ -38,8 +38,6 @@ def main():
                 continue
             entities_data.append(f"        * [{file_name}](auto_gen_docs/{file_name}.md)")
 
-    entities_data.append("* [Changelog](changelog.md)")
-
     with mkdocs_gen_files.open("SUMMARY.md", "w") as f:
         f.write("\n".join(entities_data))
 
