@@ -13,7 +13,9 @@
 #  Website: https://github.com/vacanza/holidays
 #  License: MIT (see LICENSE file)
 
+from concurrent.futures import ProcessPoolExecutor
 from pathlib import Path
+from time import perf_counter
 
 from polib import pofile
 
@@ -22,15 +24,26 @@ class MOGenerator:
     """Creates .mo files for supported country/market entities."""
 
     @staticmethod
-    def run():
+    def _convert_po_to_mo(po_path: Path) -> None:
+        """Convert a single .po file to .mo file."""
+        pofile(po_path).save_as_mofile(str(po_path.with_suffix(".mo")))
+
+    @staticmethod
+    def _unlink_file(path: Path) -> None:
+        """Unlink old .mo file"""
+        path.unlink(missing_ok=True)
+
+    @staticmethod
+    def run() -> None:
         """Runs the .mo files generation process."""
         locale_path = Path("holidays/locale")
-
-        for mo_path in locale_path.rglob("*.mo"):
-            mo_path.unlink()
-        for po_path in locale_path.rglob("*.po"):
-            pofile(po_path).save_as_mofile(po_path.with_suffix(".mo"))
+        with ProcessPoolExecutor() as executor:
+            list(executor.map(MOGenerator._unlink_file, locale_path.rglob("*.mo")))
+            list(executor.map(MOGenerator._convert_po_to_mo, locale_path.rglob("*.po")))
 
 
 if __name__ == "__main__":
+    mo_time_start = perf_counter()
     MOGenerator.run()
+    mo_time_end = perf_counter()
+    print(f"[TIMER] Total generate mo files runtime: {mo_time_end - mo_time_start:.2f} seconds")
