@@ -14,13 +14,13 @@ import unittest
 from datetime import date
 
 from holidays import calendars
-from holidays.calendars.gregorian import JAN, FEB, MAR, APR, MAY, JUN, JUL, AUG, SEP, OCT, NOV
+from holidays.calendars.gregorian import JAN, FEB, MAR, APR, MAY, JUN, JUL, AUG, SEP, OCT, NOV, DEC
 from holidays.calendars.thai import KHMER_CALENDAR
 
 
 class TestThaiLunisolarCalendar(unittest.TestCase):
     def setUp(self) -> None:
-        super().setUpClass()
+        super().setUp()
         self.calendar = calendars._ThaiLunisolar()
 
     def test_check_calendar(self):
@@ -151,6 +151,172 @@ class TestThaiLunisolarCalendar(unittest.TestCase):
                 boun_suang_heua_year_date[year], self.calendar.boun_suang_heua_date(year)
             )
 
+    def test_buddhist_sabbath_dates(self):
+        expected_buddhist_sabbath_dates = {
+            self.calendar.START_YEAR - 1: set(),
+            self.calendar.END_YEAR + 1: set(),
+            # Athikamat (Extra-Month Year).
+            2023: {
+                date(2023, JAN, 6),  # 15 Waxing (Month 2 Started in Previous Gregorian Year).
+                date(2023, JAN, 14),  # 8 Waning.
+                date(2023, JAN, 21),  # 15 Waning.
+                date(2023, JAN, 29),  # 8 Waxing (Month 3).
+                date(2023, FEB, 5),  # 15 Waxing.
+                date(2023, FEB, 13),  # 8 Waning.
+                date(2023, FEB, 19),  # 14 Waning.
+                date(2023, FEB, 27),  # 8 Waxing (Month 4).
+                date(2023, MAR, 6),  # 15 Waxing.
+                date(2023, MAR, 14),  # 8 Waning.
+                date(2023, MAR, 21),  # 15 Waning.
+                date(2023, MAR, 29),  # 8 Waxing (Month 5).
+                date(2023, APR, 5),  # 15 Waxing.
+                date(2023, APR, 13),  # 8 Waning.
+                date(2023, APR, 19),  # 14 Waning.
+                date(2023, APR, 27),  # 8 Waxing (Month 6).
+                date(2023, MAY, 4),  # 15 Waxing.
+                date(2023, MAY, 12),  # 8 Waning.
+                date(2023, MAY, 19),  # 15 Waning.
+                date(2023, MAY, 27),  # 8 Waxing (Month 7).
+                date(2023, JUN, 3),  # 15 Waxing.
+                date(2023, JUN, 11),  # 8 Waning.
+                date(2023, JUN, 17),  # 14 Waning.
+                date(2023, JUN, 25),  # 8 Waxing (Month 8).
+                date(2023, JUL, 2),  # 15 Waxing.
+                date(2023, JUL, 10),  # 8 Waning.
+                date(2023, JUL, 17),  # 14 Waning.
+                date(2023, JUL, 25),  # 8 Waxing (Month 8.8).
+                date(2023, AUG, 1),  # 15 Waxing.
+                date(2023, AUG, 9),  # 8 Waning.
+                date(2023, AUG, 16),  # 15 Waning.
+                date(2023, AUG, 24),  # 8 Waxing (Month 9).
+                date(2023, AUG, 31),  # 15 Waxing.
+                date(2023, SEP, 8),  # 8 Waning.
+                date(2023, SEP, 14),  # 14 Waning.
+                date(2023, SEP, 22),  # 8 Waxing (Month 10).
+                date(2023, SEP, 29),  # 15 Waxing.
+                date(2023, OCT, 7),  # 8 Waning.
+                date(2023, OCT, 14),  # 15 Waning.
+                date(2023, OCT, 22),  # 8 Waxing (Month 11).
+                date(2023, OCT, 29),  # 15 Waxing.
+                date(2023, NOV, 6),  # 8 Waning.
+                date(2023, NOV, 12),  # 14 Waning.
+                date(2023, NOV, 20),  # 8 Waxing (Month 12).
+                date(2023, NOV, 27),  # 15 Waxing.
+                date(2023, DEC, 5),  # 8 Waning.
+                date(2023, DEC, 12),  # 15 Waning.
+                date(2023, DEC, 20),  # 8 Waxing (Month 1 Next Year).
+                date(2023, DEC, 27),  # 15 Waxing.
+            },
+            # Pakatimat (Normal Year).
+            2024: {
+                date(2024, JAN, 4),  # 8 Waning (Month 1 Started in Previous Gregorian Year).
+                date(2024, JAN, 10),  # 14 Waning.
+                date(2024, JAN, 18),  # 8 Waxing (Month 2).
+                date(2024, JAN, 25),  # 15 Waxing.
+                date(2024, FEB, 2),  # 8 Waning.
+                date(2024, FEB, 9),  # 15 Waning.
+                date(2024, FEB, 17),  # 8 Waxing (Month 3).
+                date(2024, FEB, 24),  # 15 Waxing.
+                date(2024, MAR, 3),  # 8 Waning.
+                date(2024, MAR, 9),  # 14 Waning.
+                date(2024, MAR, 17),  # 8 Waxing (Month 4).
+                date(2024, MAR, 24),  # 15 Waxing.
+                date(2024, APR, 1),  # 8 Waning.
+                date(2024, APR, 8),  # 15 Waning.
+                date(2024, APR, 16),  # 8 Waxing (Month 5).
+                date(2024, APR, 23),  # 15 Waxing.
+                date(2024, MAY, 1),  # 8 Waning.
+                date(2024, MAY, 7),  # 14 Waning.
+                date(2024, MAY, 15),  # 8 Waxing (Month 6).
+                date(2024, MAY, 22),  # 15 Waxing.
+                date(2024, MAY, 30),  # 8 Waning.
+                date(2024, JUN, 6),  # 15 Waning.
+                date(2024, JUN, 14),  # 8 Waxing (Month 7).
+                date(2024, JUN, 21),  # 15 Waxing.
+                date(2024, JUN, 29),  # 8 Waning.
+                date(2024, JUL, 5),  # 14 Waning.
+                date(2024, JUL, 13),  # 8 Waxing (Month 8).
+                date(2024, JUL, 20),  # 15 Waxing.
+                date(2024, JUL, 28),  # 8 Waning.
+                date(2024, AUG, 4),  # 15 Waning.
+                date(2024, AUG, 12),  # 8 Waxing (Month 9).
+                date(2024, AUG, 19),  # 15 Waxing.
+                date(2024, AUG, 27),  # 8 Waning.
+                date(2024, SEP, 2),  # 14 Waning.
+                date(2024, SEP, 10),  # 8 Waxing (Month 10).
+                date(2024, SEP, 17),  # 15 Waxing.
+                date(2024, SEP, 25),  # 8 Waning.
+                date(2024, OCT, 2),  # 15 Waning.
+                date(2024, OCT, 10),  # 8 Waxing (Month 11).
+                date(2024, OCT, 17),  # 15 Waxing.
+                date(2024, OCT, 25),  # 8 Waning.
+                date(2024, OCT, 31),  # 15 Waning.
+                date(2024, NOV, 8),  # 8 Waxing (Month 12).
+                date(2024, NOV, 15),  # 15 Waxing.
+                date(2024, NOV, 23),  # 8 Waning.
+                date(2024, NOV, 30),  # 15 Waning.
+                date(2024, DEC, 8),  # 8 Waxing (Month 1 Next Year).
+                date(2024, DEC, 15),  # 15 Waxing.
+                date(2024, DEC, 23),  # 8 Waning.
+                date(2024, DEC, 29),  # 14 Waning.
+            },
+            # Athikawan (Extra-Day Year).
+            2025: {
+                date(2025, JAN, 6),  # 8 Waxing (Month 2).
+                date(2025, JAN, 13),  # 15 Waxing.
+                date(2025, JAN, 21),  # 8 Waning.
+                date(2025, JAN, 28),  # 15 Waning.
+                date(2025, FEB, 5),  # 8 Waxing (Month 3).
+                date(2025, FEB, 12),  # 15 Waxing.
+                date(2025, FEB, 20),  # 8 Waning.
+                date(2025, FEB, 26),  # 14 Waning.
+                date(2025, MAR, 6),  # 8 Waxing (Month 4).
+                date(2025, MAR, 13),  # 15 Waxing.
+                date(2025, MAR, 21),  # 8 Waning.
+                date(2025, MAR, 28),  # 15 Waning.
+                date(2025, APR, 5),  # 8 Waxing (Month 5).
+                date(2025, APR, 12),  # 15 Waxing.
+                date(2025, APR, 20),  # 8 Waning.
+                date(2025, APR, 26),  # 14 Waning.
+                date(2025, MAY, 4),  # 8 Waxing (Month 6).
+                date(2025, MAY, 11),  # 15 Waxing.
+                date(2025, MAY, 19),  # 8 Waning.
+                date(2025, MAY, 26),  # 15 Waning.
+                date(2025, JUN, 3),  # 8 Waxing (Month 7).
+                date(2025, JUN, 10),  # 15 Waxing.
+                date(2025, JUN, 18),  # 8 Waning.
+                date(2025, JUN, 25),  # 15 Waning.
+                date(2025, JUL, 3),  # 8 Waxing (Month 8).
+                date(2025, JUL, 10),  # 15 Waxing.
+                date(2025, JUL, 18),  # 8 Waning.
+                date(2025, JUL, 25),  # 15 Waning.
+                date(2025, AUG, 2),  # 8 Waxing (Month 9).
+                date(2025, AUG, 9),  # 15 Waxing.
+                date(2025, AUG, 17),  # 8 Waning.
+                date(2025, AUG, 23),  # 14 Waning.
+                date(2025, AUG, 31),  # 8 Waxing (Month 10).
+                date(2025, SEP, 7),  # 15 Waxing.
+                date(2025, SEP, 15),  # 8 Waning.
+                date(2025, SEP, 22),  # 15 Waning.
+                date(2025, SEP, 30),  # 8 Waxing (Month 11).
+                date(2025, OCT, 7),  # 15 Waxing.
+                date(2025, OCT, 15),  # 8 Waning.
+                date(2025, OCT, 21),  # 15 Waning.
+                date(2025, OCT, 29),  # 8 Waxing (Month 12).
+                date(2025, NOV, 5),  # 15 Waxing.
+                date(2025, NOV, 13),  # 8 Waning.
+                date(2025, NOV, 20),  # 15 Waning.
+                date(2025, NOV, 28),  # 8 Waxing (Month 1 Next Year).
+                date(2025, DEC, 5),  # 15 Waxing.
+                date(2025, DEC, 13),  # 8 Waning.
+                date(2025, DEC, 19),  # 14 Waning.
+                date(2025, DEC, 27),  # 8 Waxing (Month 2 Next Year).
+            },
+        }
+        for year, expected_dates in expected_buddhist_sabbath_dates.items():
+            result = self.calendar.buddhist_sabbath_dates(year)
+            self.assertEqual(result, expected_dates)
+
     def test_khao_phansa_date(self):
         # THAI_CALENDAR
         khao_phansa_year_date = {
