@@ -12,45 +12,66 @@
 
 from unittest import TestCase
 
-from holidays.countries.albania import Albania, AL, ALB
+from holidays.countries.albania import Albania
 from tests.common import CommonCountryTests
 
 
 class TestAlbania(CommonCountryTests, TestCase):
     @classmethod
     def setUpClass(cls):
-        super().setUpClass(Albania, years=range(1993, 2050))
-        cls.no_estimated_holidays = Albania(years=range(1993, 2050), islamic_show_estimated=False)
-
-    def test_country_aliases(self):
-        self.assertAliases(Albania, AL, ALB)
-
-    def test_no_holidays(self):
-        self.assertNoHolidays(Albania(years=1992))
+        super().setUpClass(Albania)
 
     def test_special_holidays(self):
-        self.assertHoliday(
+        self.assertHolidayName(
+            "Ditë pushimi",
             "2020-01-03",
             "2022-03-21",
             "2024-03-15",
         )
 
     def test_new_years_day(self):
+        name = "Festat e Vitit të Ri"
         self.assertHolidayName(
-            "Festat e Vitit të Ri",
-            (f"{year}-01-01" for year in range(1993, 2050)),
-            (f"{year}-01-02" for year in range(1993, 2050)),
+            name,
+            (f"{year}-01-01" for year in self.full_range),
+            (f"{year}-01-02" for year in self.full_range),
         )
+        obs_dts = (
+            "2012-01-03",
+            "2016-01-04",
+            "2017-01-03",
+            "2021-01-04",
+            "2022-01-03",
+            "2022-01-04",
+            "2023-01-03",
+        )
+        self.assertHolidayName(f"{name} (ditë pushimi e shtyrë)", obs_dts)
+        self.assertNoNonObservedHoliday(obs_dts)
 
     def test_summer_day(self):
         name = "Dita e Verës"
-        self.assertHolidayName(name, (f"{year}-03-14" for year in range(2004, 2050)))
-        self.assertNoHolidayName(name, range(1993, 2004))
+        self.assertHolidayName(name, (f"{year}-03-14" for year in range(2004, self.end_year)))
+        self.assertNoHolidayName(name, range(self.start_year, 2004))
+        obs_dts = (
+            "2010-03-15",
+            "2015-03-16",
+            "2020-03-16",
+            "2021-03-15",
+        )
+        self.assertHolidayName(f"{name} (ditë pushimi e shtyrë)", obs_dts)
+        self.assertNoNonObservedHoliday(obs_dts)
 
     def test_nowruz_day(self):
         name = "Dita e Nevruzit"
-        self.assertHolidayName(name, (f"{year}-03-22" for year in range(1996, 2050)))
-        self.assertNoHolidayName(name, range(1993, 1996))
+        self.assertHolidayName(name, (f"{year}-03-22" for year in range(1996, self.end_year)))
+        self.assertNoHolidayName(name, range(self.start_year, 1996))
+        obs_dts = (
+            "2014-03-24",
+            "2015-03-23",
+            "2020-03-23",
+        )
+        self.assertHolidayName(f"{name} (ditë pushimi e shtyrë)", obs_dts)
+        self.assertNoNonObservedHoliday(obs_dts)
 
     def test_catholic_easter_sunday(self):
         name = "E diela e Pashkëve Katolike"
@@ -64,7 +85,13 @@ class TestAlbania(CommonCountryTests, TestCase):
             "2023-04-09",
             "2024-03-31",
         )
-        self.assertHolidayName(name, range(1993, 2050))
+        self.assertHolidayName(name, self.full_range)
+        obs_dts = (
+            # Special.
+            "2008-03-25",
+        )
+        self.assertHolidayName(f"{name} (ditë pushimi e shtyrë)", obs_dts)
+        self.assertNoNonObservedHoliday(obs_dts)
 
     def test_orthodox_easter_sunday(self):
         name = "E diela e Pashkëve Ortodokse"
@@ -78,45 +105,115 @@ class TestAlbania(CommonCountryTests, TestCase):
             "2023-04-16",
             "2024-05-05",
         )
-        self.assertHolidayName(name, range(1993, 2050))
+        self.assertHolidayName(name, self.full_range)
+        obs_dts = (
+            # Special.
+            "2000-05-02",
+            "2021-05-04",
+            "2027-05-04",
+        )
+        self.assertHolidayName(f"{name} (ditë pushimi e shtyrë)", obs_dts)
+        self.assertNoNonObservedHoliday(obs_dts)
 
     def test_international_workers_day(self):
-        self.assertHolidayName(
-            "Dita Ndërkombëtare e Punëtorëve", (f"{year}-05-01" for year in range(1993, 2050))
+        name = "Dita Ndërkombëtare e Punëtorëve"
+        self.assertHolidayName(name, (f"{year}-05-01" for year in self.full_range))
+        obs_dts = (
+            "2010-05-03",
+            "2011-05-02",
+            "2016-05-02",
+            "2021-05-03",
         )
+        self.assertHolidayName(f"{name} (ditë pushimi e shtyrë)", obs_dts)
+        self.assertNoNonObservedHoliday(obs_dts)
 
     def test_mother_teresa_day(self):
-        name1 = "Dita e Lumturimit të Shenjt Terezës"
-        name2 = "Dita e Shenjtërimit të Shenjt Terezës"
-        self.assertHolidayName(name1, (f"{year}-10-19" for year in range(2004, 2018)))
-        self.assertNoHolidayName(name1, range(1993, 2004), range(2018, 2050))
-        self.assertHolidayName(name2, (f"{year}-09-05" for year in range(2018, 2050)))
-        self.assertNoHolidayName(name2, range(1993, 2018))
+        name_blessed = "Dita e Lumturimit të Shenjt Terezës"
+        name_saint = "Dita e Shenjtërimit të Shenjt Terezës"
+        self.assertHolidayName(name_blessed, (f"{year}-10-19" for year in range(2004, 2018)))
+        self.assertNoHolidayName(
+            name_blessed, range(self.start_year, 2004), range(2018, self.end_year)
+        )
+        self.assertHolidayName(
+            name_saint, (f"{year}-09-05" for year in range(2018, self.end_year))
+        )
+        self.assertNoHolidayName(name_saint, range(self.start_year, 2018))
+        obs_dts_blessed = (
+            "2013-10-21",
+            "2014-10-20",
+        )
+        self.assertHolidayName(f"{name_blessed} (ditë pushimi e shtyrë)", obs_dts_blessed)
+        obs_dts_saint = (
+            "2020-09-07",
+            "2021-09-06",
+        )
+        self.assertHolidayName(f"{name_saint} (ditë pushimi e shtyrë)", obs_dts_saint)
+        self.assertNoNonObservedHoliday(obs_dts_blessed, obs_dts_saint)
 
     def test_alphabet_day(self):
         name = "Dita e Alfabetit"
-        self.assertHolidayName(name, (f"{year}-11-22" for year in range(2024, 2050)))
-        self.assertNoHolidayName(name, range(1993, 2024))
+        self.assertHolidayName(name, (f"{year}-11-22" for year in range(2024, self.end_year)))
+        self.assertNoHolidayName(name, range(self.start_year, 2024))
+        obs_dts = (
+            "2025-11-24",
+            "2026-11-23",
+        )
+        self.assertHolidayName(f"{name} (ditë pushimi e shtyrë)", obs_dts)
+        self.assertNoNonObservedHoliday(obs_dts)
 
     def test_flag_and_independence_day(self):
-        self.assertHolidayName(
-            "Dita Flamurit dhe e Pavarësisë", (f"{year}-11-28" for year in range(1993, 2050))
+        name = "Dita Flamurit dhe e Pavarësisë"
+        self.assertHolidayName(name, (f"{year}-11-28" for year in self.full_range))
+        obs_dts = (
+            "2010-11-30",
+            "2015-11-30",
+            "2020-11-30",
+            "2021-11-30",
         )
+        self.assertHolidayName(f"{name} (ditë pushimi e shtyrë)", obs_dts)
+        self.assertNoNonObservedHoliday(obs_dts)
 
     def test_liberation_day(self):
-        self.assertHolidayName("Dita e Çlirimit", (f"{year}-11-29" for year in range(1993, 2050)))
+        name = "Dita e Çlirimit"
+        self.assertHolidayName(name, (f"{year}-11-29" for year in self.full_range))
+        obs_dts = (
+            "2014-12-01",
+            "2015-12-01",
+            "2020-12-01",
+        )
+        self.assertHolidayName(f"{name} (ditë pushimi e shtyrë)", obs_dts)
+        self.assertNoNonObservedHoliday(obs_dts)
 
     def test_national_youth_day(self):
         name = "Dita Kombëtare e Rinisë"
-        self.assertHolidayName(name, (f"{year}-12-08" for year in range(2009, 2050)))
-        self.assertNoHolidayName(name, range(1993, 2009))
+        self.assertHolidayName(name, (f"{year}-12-08" for year in range(2009, self.end_year)))
+        self.assertNoHolidayName(name, range(self.start_year, 2009))
+        obs_dts = (
+            "2012-12-10",
+            "2013-12-09",
+            "2018-12-10",
+            "2019-12-09",
+            "2024-12-09",
+        )
+        self.assertHolidayName(f"{name} (ditë pushimi e shtyrë)", obs_dts)
+        self.assertNoNonObservedHoliday(obs_dts)
 
     def test_christmas_day(self):
-        self.assertHolidayName("Krishtlindjet", (f"{year}-12-25" for year in range(1993, 2050)))
+        name = "Krishtlindjet"
+        self.assertHolidayName(name, (f"{year}-12-25" for year in self.full_range))
+        obs_dts = (
+            "2010-12-27",
+            "2011-12-26",
+            "2016-12-26",
+            "2021-12-27",
+            "2022-12-26",
+        )
+        self.assertHolidayName(f"{name} (ditë pushimi e shtyrë)", obs_dts)
+        self.assertNoNonObservedHoliday(obs_dts)
 
     def test_eid_al_fitr(self):
         name = "Dita e Bajramit të Madh"
-        self.assertHolidayName(
+        self.assertIslamicNoEstimatedHolidayName(
             name,
             "2018-06-15",
             "2019-06-04",
@@ -126,12 +223,21 @@ class TestAlbania(CommonCountryTests, TestCase):
             "2023-04-21",
             "2024-04-10",
         )
-        self.assertHolidayName(name, self.no_estimated_holidays, range(1993, 2050))
+        self.assertIslamicNoEstimatedHolidayName(name, self.full_range)
+        obs_dts = (
+            "2012-08-20",
+            "2017-06-26",
+            "2020-05-25",
+        )
+        self.assertIslamicNoEstimatedHolidayName(f"{name} (ditë pushimi e shtyrë)", obs_dts)
+        self.assertNoNonObservedHoliday(obs_dts)
 
     def test_eid_al_adha(self):
         name = "Dita e Kurban Bajramit"
-        self.assertHolidayName(
+        self.assertIslamicNoEstimatedHolidayName(
             name,
+            "2006-01-10",
+            "2006-12-31",
             "2018-08-21",
             "2019-08-11",
             "2020-07-31",
@@ -140,90 +246,21 @@ class TestAlbania(CommonCountryTests, TestCase):
             "2023-06-28",
             "2024-06-16",
         )
-        self.assertHoliday(
-            "2006-01-10",
-            "2006-12-31",
-        )
-        self.assertHolidayName(name, self.no_estimated_holidays, range(1993, 2050))
-
-    def test_observed(self):
-        dt = (
-            # New Year's Day.
-            "2012-01-03",
-            "2016-01-04",
-            "2017-01-03",
-            "2021-01-04",
-            "2022-01-03",
-            "2022-01-04",
-            "2023-01-03",
-            # Summer Day.
-            "2010-03-15",
-            "2015-03-16",
-            "2020-03-16",
-            "2021-03-15",
-            # Nowruz Day.
-            "2014-03-24",
-            "2015-03-23",
-            "2020-03-23",
-            # International Workers' Day.
-            "2010-05-03",
-            "2011-05-02",
-            "2016-05-02",
-            "2021-05-03",
-            # Mother Teresa Beatification/Canonization Day.
-            "2013-10-21",
-            "2014-10-20",
-            "2020-09-07",
-            "2021-09-06",
-            # Alphabet Day.
-            "2025-11-24",
-            "2026-11-23",
-            # Flag and Independence Day.
-            "2010-11-30",
-            "2015-11-30",
-            "2020-11-30",
-            "2021-11-30",
-            # Liberation Day.
-            "2014-12-01",
-            "2015-12-01",
-            "2020-12-01",
-            # National Youth Day.
-            "2012-12-10",
-            "2013-12-09",
-            "2018-12-10",
-            "2019-12-09",
-            "2024-12-09",
-            # Christmas Day.
-            "2010-12-27",
-            "2011-12-26",
-            "2016-12-26",
-            "2021-12-27",
-            "2022-12-26",
-            # Eid al-Fitr.
-            "2012-08-20",
-            "2017-06-26",
-            "2020-05-25",
-            # Eid al-Adha.
+        self.assertIslamicNoEstimatedHolidayName(name, self.full_range)
+        obs_dts = (
             "2007-01-03",
             "2014-10-06",
             "2016-09-12",
             "2019-08-12",
             "2022-07-11",
             "2024-06-17",
-            # special cases:
-            # Catholic Easter Sunday.
-            "2008-03-25",
-            # Orthodox Easter Sunday.
-            "2000-05-02",
-            "2021-05-04",
-            "2027-05-04",
         )
-        self.assertHoliday(dt)
-        self.assertNoNonObservedHoliday(dt)
+        self.assertIslamicNoEstimatedHolidayName(f"{name} (ditë pushimi e shtyrë)", obs_dts)
+        self.assertNoNonObservedHoliday(obs_dts)
 
     def test_2022(self):
-        self.assertHolidays(
-            Albania(years=2022),
+        self.assertHolidaysInYear(
+            2022,
             ("2022-01-01", "Festat e Vitit të Ri"),
             ("2022-01-02", "Festat e Vitit të Ri"),
             ("2022-01-03", "Festat e Vitit të Ri (ditë pushimi e shtyrë)"),
@@ -249,8 +286,8 @@ class TestAlbania(CommonCountryTests, TestCase):
         )
 
     def test_2023(self):
-        self.assertHolidays(
-            Albania(years=2023),
+        self.assertHolidaysInYear(
+            2023,
             ("2023-01-01", "Festat e Vitit të Ri"),
             ("2023-01-02", "Festat e Vitit të Ri"),
             ("2023-01-03", "Festat e Vitit të Ri (ditë pushimi e shtyrë)"),
