@@ -12,55 +12,45 @@
 
 from unittest import TestCase
 
-from holidays.constants import CHRISTIAN, HEBREW
-from holidays.countries.algeria import Algeria, DZ, DZA
+from holidays.countries.algeria import Algeria
 from tests.common import CommonCountryTests
 
 
 class TestAlgeria(CommonCountryTests, TestCase):
     @classmethod
     def setUpClass(cls):
-        years = range(1964, 2050)
-        super().setUpClass(Algeria, years=years)
-        cls.christian_holidays = Algeria(categories=CHRISTIAN, years=years)
-        cls.hebrew_holidays = Algeria(categories=HEBREW, years=years)
-        cls.no_estimated_holidays = Algeria(years=years, islamic_show_estimated=False)
-
-    def test_country_aliases(self):
-        self.assertAliases(Algeria, DZ, DZA)
-
-    def test_no_holidays(self):
-        self.assertNoHolidays(Algeria(categories=Algeria.supported_categories, years=1963))
+        super().setUpClass(Algeria)
 
     def test_new_years_day(self):
         self.assertHolidayName(
-            "رأس السنة الميلادية", (f"{year}-01-01" for year in range(1964, 2050))
+            "رأس السنة الميلادية", (f"{year}-01-01" for year in self.full_range)
         )
 
     def test_amazigh_new_year(self):
         name = "رأس السنة الأمازيغية"
-        self.assertHolidayName(name, (f"{year}-01-12" for year in range(2018, 2050)))
-        self.assertNoHolidayName(name, range(1964, 2018))
+        self.assertHolidayName(name, (f"{year}-01-12" for year in range(2018, self.end_year)))
+        self.assertNoHolidayName(name, range(self.start_year, 2018))
 
     def test_labor_day(self):
-        self.assertHolidayName("عيد العمال", (f"{year}-05-01" for year in range(1964, 2050)))
+        self.assertHolidayName("عيد العمال", (f"{year}-05-01" for year in self.full_range))
 
     def test_independence_day(self):
         name_1964 = "عيد الاستقلال وجبهة التحرير الوطني"
         name_2005 = "عيد الاستقلال"
-        self.assertHolidayName(name_1964, (f"{year}-07-05" for year in range(1964, 2005)))
-        self.assertHolidayName(name_2005, (f"{year}-07-05" for year in range(2005, 2050)))
-        self.assertNoHolidayName(name_1964, range(2005, 2050))
-        self.assertNoHolidayName(name_2005, range(1964, 2005))
+        self.assertHolidayName(
+            name_1964, (f"{year}-07-05" for year in range(self.start_year, 2005))
+        )
+        self.assertHolidayName(name_2005, (f"{year}-07-05" for year in range(2005, self.end_year)))
+        self.assertNoHolidayName(name_1964, range(2005, self.end_year))
+        self.assertNoHolidayName(name_2005, range(self.start_year, 2005))
 
     def test_revolution_day(self):
-        self.assertHolidayName("عيد الثورة", (f"{year}-11-01" for year in range(1964, 2050)))
+        self.assertHolidayName("عيد الثورة", (f"{year}-11-01" for year in self.full_range))
 
     def test_islamic_new_year(self):
         name = "رأس السنة الهجرية"
-        self.assertHolidayName(
+        self.assertIslamicNoEstimatedHolidayName(
             name,
-            self.no_estimated_holidays,
             "2020-08-20",
             "2021-08-09",
             "2022-07-30",
@@ -68,13 +58,12 @@ class TestAlgeria(CommonCountryTests, TestCase):
             "2024-07-07",
             "2025-06-26",
         )
-        self.assertHolidayName(name, self.no_estimated_holidays, range(1964, 2050))
+        self.assertIslamicNoEstimatedHolidayName(name, self.full_range)
 
     def test_ashura(self):
         name = "عاشورة"
-        self.assertHolidayName(
+        self.assertIslamicNoEstimatedHolidayName(
             name,
-            self.no_estimated_holidays,
             "2020-08-29",
             "2021-08-18",
             "2022-08-08",
@@ -82,13 +71,12 @@ class TestAlgeria(CommonCountryTests, TestCase):
             "2024-07-16",
             "2025-07-05",
         )
-        self.assertHolidayName(name, self.no_estimated_holidays, range(1964, 2050))
+        self.assertIslamicNoEstimatedHolidayName(name, self.full_range)
 
     def test_prophets_birthday(self):
         name = "عيد المولد النبوي"
-        self.assertHolidayName(
+        self.assertIslamicNoEstimatedHolidayName(
             name,
-            self.no_estimated_holidays,
             "2020-10-29",
             "2021-10-18",
             "2022-10-08",
@@ -96,13 +84,12 @@ class TestAlgeria(CommonCountryTests, TestCase):
             "2024-09-15",
             "2025-09-04",
         )
-        self.assertHolidayName(name, self.no_estimated_holidays, range(1964, 2050))
+        self.assertIslamicNoEstimatedHolidayName(name, self.full_range)
 
     def test_eid_al_fitr(self):
         name = "عيد الفطر"
-        self.assertHolidayName(
+        self.assertIslamicNoEstimatedHolidayName(
             name,
-            self.no_estimated_holidays,
             "2020-05-24",
             "2020-05-25",
             "2021-05-13",
@@ -118,25 +105,19 @@ class TestAlgeria(CommonCountryTests, TestCase):
             "2025-03-31",
             "2025-04-01",
         )
-        self.assertHolidayNameCount(
-            name,
-            2,
-            self.no_estimated_holidays,
-            range(1964, 1968),
-            range(1969, 2000),
-            range(2001, 2024),
+        self.assertIslamicNoEstimatedHolidayNameCount(
+            name, 2, range(1964, 1968), range(1969, 2000), range(2001, 2024)
         )
-        self.assertHolidayNameCount(
-            name, 3, self.no_estimated_holidays, range(2024, 2033), range(2034, 2050)
+        self.assertIslamicNoEstimatedHolidayNameCount(
+            name, 3, range(2024, 2033), range(2034, self.end_year)
         )
-        self.assertHolidayNameCount(name, 4, self.no_estimated_holidays, 1968, 2000)
-        self.assertHolidayNameCount(name, 6, self.no_estimated_holidays, 2033)
+        self.assertIslamicNoEstimatedHolidayNameCount(name, 4, 1968, 2000)
+        self.assertIslamicNoEstimatedHolidayNameCount(name, 6, 2033)
 
     def test_eid_al_adha(self):
         name = "عيد الأضحى"
-        self.assertHolidayName(
+        self.assertIslamicNoEstimatedHolidayName(
             name,
-            self.no_estimated_holidays,
             "2020-07-31",
             "2020-08-01",
             "2021-07-20",
@@ -153,32 +134,21 @@ class TestAlgeria(CommonCountryTests, TestCase):
             "2025-06-07",
             "2025-06-08",
         )
-        self.assertHolidayNameCount(name, 1, self.no_estimated_holidays, range(1964, 1969))
-        self.assertHolidayNameCount(
-            name,
-            2,
-            self.no_estimated_holidays,
-            range(1969, 1974),
-            range(1975, 2006),
-            range(2008, 2023),
+        self.assertIslamicNoEstimatedHolidayNameCount(name, 1, range(1964, 1969))
+        self.assertIslamicNoEstimatedHolidayNameCount(
+            name, 2, range(1969, 1974), range(1975, 2006), range(2008, 2023)
         )
-        self.assertHolidayNameCount(
-            name,
-            3,
-            self.no_estimated_holidays,
-            range(2006, 2008),
-            range(2023, 2039),
-            range(2040, 2050),
+        self.assertIslamicNoEstimatedHolidayNameCount(
+            name, 3, range(2006, 2008), range(2023, 2039), range(2040, self.end_year)
         )
-        self.assertHolidayNameCount(name, 4, self.no_estimated_holidays, 1974)
-        self.assertHolidayNameCount(name, 6, self.no_estimated_holidays, 2039)
+        self.assertIslamicNoEstimatedHolidayNameCount(name, 4, 1974)
+        self.assertIslamicNoEstimatedHolidayNameCount(name, 6, 2039)
 
     def test_easter_monday(self):
         name = "إثنين الفصح"
         self.assertNoHolidayName(name)
-        self.assertHolidayName(
+        self.assertChristianHolidayName(
             name,
-            self.christian_holidays,
             "2020-04-13",
             "2021-04-05",
             "2022-04-18",
@@ -186,14 +156,13 @@ class TestAlgeria(CommonCountryTests, TestCase):
             "2024-04-01",
             "2025-04-21",
         )
-        self.assertHolidayName(name, self.christian_holidays, range(1964, 2050))
+        self.assertChristianHolidayName(name, self.full_range)
 
     def test_ascension_day(self):
         name = "عيد الصعود"
         self.assertNoHolidayName(name)
-        self.assertHolidayName(
+        self.assertChristianHolidayName(
             name,
-            self.christian_holidays,
             "2020-05-21",
             "2021-05-13",
             "2022-05-26",
@@ -201,14 +170,13 @@ class TestAlgeria(CommonCountryTests, TestCase):
             "2024-05-09",
             "2025-05-29",
         )
-        self.assertHolidayName(name, self.christian_holidays, range(1964, 2050))
+        self.assertChristianHolidayName(name, self.full_range)
 
     def test_whit_monday(self):
         name = "إثنين العنصرة"
         self.assertNoHolidayName(name)
-        self.assertHolidayName(
+        self.assertChristianHolidayName(
             name,
-            self.christian_holidays,
             "2020-06-01",
             "2021-05-24",
             "2022-06-06",
@@ -216,28 +184,23 @@ class TestAlgeria(CommonCountryTests, TestCase):
             "2024-05-20",
             "2025-06-09",
         )
-        self.assertHolidayName(name, self.christian_holidays, range(1964, 2050))
+        self.assertChristianHolidayName(name, self.full_range)
 
     def test_assumption_day(self):
         name = "عيد انتقال السيدة العذراء"
         self.assertNoHolidayName(name)
-        self.assertHolidayName(
-            name, self.christian_holidays, (f"{year}-08-15" for year in range(1964, 2050))
-        )
+        self.assertChristianHolidayName(name, (f"{year}-08-15" for year in self.full_range))
 
     def test_christmas_day(self):
         name = "عيد الميلاد"
         self.assertNoHolidayName(name)
-        self.assertHolidayName(
-            name, self.christian_holidays, (f"{year}-12-25" for year in range(1964, 2050))
-        )
+        self.assertChristianHolidayName(name, (f"{year}-12-25" for year in self.full_range))
 
     def test_rosh_hashanah(self):
         name = "رأس السنة العبرية"
         self.assertNoHolidayName(name)
-        self.assertHolidayName(
+        self.assertHebrewHolidayName(
             name,
-            self.hebrew_holidays,
             "2020-09-19",
             "2021-09-07",
             "2022-09-26",
@@ -245,14 +208,13 @@ class TestAlgeria(CommonCountryTests, TestCase):
             "2024-10-03",
             "2025-09-23",
         )
-        self.assertHolidayName(name, self.hebrew_holidays, range(1964, 2050))
+        self.assertHebrewHolidayName(name, self.full_range)
 
     def test_yom_kippur(self):
         name = "يوم الغفران"
         self.assertNoHolidayName(name)
-        self.assertHolidayName(
+        self.assertHebrewHolidayName(
             name,
-            self.hebrew_holidays,
             "2020-09-28",
             "2021-09-16",
             "2022-10-05",
@@ -260,14 +222,13 @@ class TestAlgeria(CommonCountryTests, TestCase):
             "2024-10-12",
             "2025-10-02",
         )
-        self.assertHolidayName(name, self.hebrew_holidays, range(1964, 2050))
+        self.assertHebrewHolidayName(name, self.full_range)
 
     def test_pesach(self):
         name = "عيد الفصح اليهودي"
         self.assertNoHolidayName(name)
-        self.assertHolidayName(
+        self.assertHebrewHolidayName(
             name,
-            self.hebrew_holidays,
             "2020-04-09",
             "2021-03-28",
             "2022-04-16",
@@ -275,7 +236,7 @@ class TestAlgeria(CommonCountryTests, TestCase):
             "2024-04-23",
             "2025-04-13",
         )
-        self.assertHolidayName(name, self.hebrew_holidays, range(1964, 2050))
+        self.assertHebrewHolidayName(name, self.full_range)
 
     def test_weekend(self):
         for dt in (
