@@ -12,28 +12,52 @@
 
 from unittest import TestCase
 
-from holidays.countries.american_samoa import HolidaysAS, AmericanSamoa, AS, ASM
+from holidays.countries.american_samoa import AmericanSamoa
 from tests.common import CommonCountryTests
 
 
 class TestAS(CommonCountryTests, TestCase):
     @classmethod
     def setUpClass(cls):
-        super().setUpClass(HolidaysAS)
+        super().setUpClass(AmericanSamoa)
 
-    def test_country_aliases(self):
-        self.assertAliases(HolidaysAS, AmericanSamoa, AS, ASM)
+    def test_american_samoa_flag_day(self):
+        name = "American Samoa Flag Day"
+        self.assertHolidayName(name, (f"{year}-04-17" for year in self.full_range))
+        obs_dts = (
+            "2011-04-18",
+            "2016-04-18",
+            "2021-04-16",
+            "2022-04-18",
+        )
+        self.assertHolidayName(f"{name} (observed)", obs_dts)
+        self.assertNoNonObservedHoliday(obs_dts)
 
-    def test_no_holidays(self):
-        self.assertNoHolidays(HolidaysAS(years=1900))
+    def test_manuaa_islands_cession_day(self):
+        name = "Manu'a Islands Cession Day"
+        self.assertHolidayName(name, (f"{year}-07-16" for year in range(1983, self.end_year)))
+        self.assertNoHolidayName(name, range(self.start_year, 1983))
+        obs_dts = (
+            "2016-07-15",
+            "2017-07-17",
+            "2022-07-15",
+            "2023-07-17",
+        )
+        self.assertHolidayName(f"{name} (observed)", obs_dts)
+        self.assertNoNonObservedHoliday(obs_dts)
 
-    def test_as_only(self):
-        """Check for a holiday that is not returned by US unless the subdivision is specified."""
-        self.assertHolidayName("American Samoa Flag Day", "2016-04-17")
-        self.assertHolidayName("American Samoa Flag Day (observed)", "2016-04-18")
-        self.assertHolidayName("Manu'a Islands Cession Day (observed)", "2016-07-15")
-        self.assertHolidayName("Manu'a Islands Cession Day", "2016-07-16")
-        self.assertHolidayName("White Sunday", "2016-10-09")
+    def test_white_sunday(self):
+        name = "White Sunday"
+        self.assertHolidayName(
+            name,
+            "2020-10-11",
+            "2021-10-10",
+            "2022-10-09",
+            "2023-10-08",
+            "2024-10-13",
+            "2025-10-12",
+        )
+        self.assertHolidayName(name, self.full_range)
 
     def test_l10n_default(self):
         self.assertLocalizedHolidays(
