@@ -14,19 +14,14 @@ from datetime import date
 from unittest import TestCase
 
 from holidays.calendars.gregorian import JAN, MAR, APR, MAY, JUN, AUG, SEP, OCT, NOV, DEC
-from holidays.constants import BANK, HALF_DAY, PUBLIC
-from holidays.countries.australia import Australia, AU, AUS
+from holidays.countries.australia import Australia
 from tests.common import CommonCountryTests
 
 
 class TestAustralia(CommonCountryTests, TestCase):
     @classmethod
     def setUpClass(cls):
-        years = range(1900, 2050)
-        super().setUpClass(Australia, years=years)
-        cls.subdiv_holidays = {
-            subdiv: Australia(subdiv=subdiv, years=years) for subdiv in Australia.subdivisions
-        }
+        super().setUpClass(Australia, with_subdiv_categories=True)
 
     def _assertVariableDays(self, year: int, subdiv_holidays_mapping: dict):  # noqa: N802
         for dt, subdivisions in subdiv_holidays_mapping.items():
@@ -38,43 +33,42 @@ class TestAustralia(CommonCountryTests, TestCase):
                     f"Failed date `{dt:%Y-%m-%d}`, subdiv `{subdiv}`: {', '.join(subdivisions)}",
                 )
 
-    def test_country_aliases(self):
-        self.assertAliases(Australia, AU, AUS)
-
-    def test_new_years(self):
+    def test_new_years_day(self):
         name = "New Year's Day"
-        self.assertHolidayName(name, (f"{year}-01-01" for year in range(1900, 2050)))
+        self.assertHolidayName(name, (f"{year}-01-01" for year in self.full_range))
         for holidays in self.subdiv_holidays.values():
-            self.assertHolidayName(name, holidays, range(1900, 2050))
+            self.assertHolidayName(name, holidays, self.full_range)
 
     def test_australia_day(self):
-        name_1 = "Anniversary Day"
-        name_2 = "Australia Day"
-        self.assertHolidayName(name_2, (f"{year}-01-26" for year in range(1935, 2050)))
-        self.assertNoHolidayName(name_2, range(1900, 1935))
-        self.assertNoHoliday(f"{year}-01-26" for year in range(1900, 1935))
+        name_1801 = "Anniversary Day"
+        name_1935 = "Australia Day"
+        self.assertHolidayName(name_1935, (f"{year}-01-26" for year in range(1935, self.end_year)))
+        self.assertNoHolidayName(name_1935, range(self.start_year, 1935))
+        self.assertNoHoliday(f"{year}-01-26" for year in range(self.start_year, 1935))
 
         for subdiv, holidays in self.subdiv_holidays.items():
             if subdiv == "NSW":
-                self.assertHolidayName(name_1, holidays, range(1900, 1946))
-                self.assertHolidayName(name_2, holidays, range(1946, 2050))
-                self.assertNoHolidayName(name_1, holidays, range(1946, 2050))
-                self.assertNoHolidayName(name_2, holidays, range(1900, 1946))
-                self.assertNoHolidayName(name_1, Australia(subdiv="NSW", years=1887))
+                self.assertHolidayName(name_1801, holidays, range(1888, 1946))
+                self.assertHolidayName(name_1935, holidays, range(1946, self.end_year))
+                self.assertNoHolidayName(
+                    name_1801, holidays, range(self.start_year, 1888), range(1946, self.end_year)
+                )
+                self.assertNoHolidayName(name_1935, holidays, range(self.start_year, 1946))
             elif subdiv == "SA":
-                self.assertHolidayName(name_2, holidays, range(1935, 2050))
-                self.assertNoHolidayName(name_2, holidays, range(1900, 1935))
-                self.assertNoHolidayName(name_1, holidays)
+                self.assertHolidayName(name_1935, holidays, range(1935, self.end_year))
+                self.assertNoHolidayName(name_1935, holidays, range(self.start_year, 1935))
+                self.assertNoHolidayName(name_1801, holidays)
             else:
-                self.assertHolidayName(name_1, holidays, range(1900, 1935))
-                self.assertHolidayName(name_2, holidays, range(1935, 2050))
-                self.assertNoHolidayName(name_1, holidays, range(1935, 2050))
-                self.assertNoHolidayName(name_2, holidays, range(1900, 1935))
-                self.assertNoHolidayName(name_1, Australia(subdiv=subdiv, years=1887))
+                self.assertHolidayName(name_1801, holidays, range(1888, 1935))
+                self.assertHolidayName(name_1935, holidays, range(1935, self.end_year))
+                self.assertNoHolidayName(
+                    name_1801, holidays, range(self.start_year, 1888), range(1935, self.end_year)
+                )
+                self.assertNoHolidayName(name_1935, holidays, range(self.start_year, 1935))
 
     def test_good_friday(self):
         name = "Good Friday"
-        dt = (
+        dts = (
             "1999-04-02",
             "2000-04-21",
             "2010-04-02",
@@ -86,11 +80,11 @@ class TestAustralia(CommonCountryTests, TestCase):
             "2023-04-07",
             "2024-03-29",
         )
-        self.assertHolidayName(name, dt)
-        self.assertHolidayName(name, range(1900, 2050))
+        self.assertHolidayName(name, dts)
+        self.assertHolidayName(name, self.full_range)
         for holidays in self.subdiv_holidays.values():
-            self.assertHolidayName(name, holidays, dt)
-            self.assertHolidayName(name, holidays, range(1900, 2050))
+            self.assertHolidayName(name, holidays, dts)
+            self.assertHolidayName(name, holidays, self.full_range)
 
     def test_easter_saturday(self):
         name = "Easter Saturday"
@@ -98,18 +92,18 @@ class TestAustralia(CommonCountryTests, TestCase):
 
         for subdiv, holidays in self.subdiv_holidays.items():
             if subdiv == "VIC":
-                self.assertHolidayName(name, holidays, range(2003, 2050))
-                self.assertNoHolidayName(name, holidays, range(1900, 2003))
+                self.assertHolidayName(name, holidays, range(2003, self.end_year))
+                self.assertNoHolidayName(name, holidays, range(self.start_year, 2003))
             elif subdiv in {"TAS", "WA"}:
                 self.assertNoHolidayName(name, holidays)
             else:
-                self.assertHolidayName(name, holidays, range(1900, 2050))
+                self.assertHolidayName(name, holidays, self.full_range)
 
     def test_easter_sunday(self):
         name = "Easter Sunday"
         self.assertNoHolidayName(name)
 
-        start_years = {
+        subdiv_start_years = {
             "ACT": 2016,
             "NSW": 2011,
             "NT": 2024,
@@ -119,16 +113,15 @@ class TestAustralia(CommonCountryTests, TestCase):
             "WA": 2022,
         }
         for subdiv, holidays in self.subdiv_holidays.items():
-            start_year = start_years.get(subdiv)
-            if start_year:
-                self.assertHolidayName(name, holidays, range(start_year, 2050))
-                self.assertNoHolidayName(name, holidays, range(1900, start_year))
+            if start_year := subdiv_start_years.get(subdiv):
+                self.assertHolidayName(name, holidays, range(start_year, self.end_year))
+                self.assertNoHolidayName(name, holidays, range(self.start_year, start_year))
             else:
                 self.assertNoHolidayName(name, holidays)
 
     def test_easter_monday(self):
         name = "Easter Monday"
-        dt = (
+        dts = (
             "1999-04-05",
             "2000-04-24",
             "2010-04-05",
@@ -140,27 +133,27 @@ class TestAustralia(CommonCountryTests, TestCase):
             "2023-04-10",
             "2024-04-01",
         )
-        self.assertHolidayName(name, dt)
-        self.assertHolidayName(name, range(1900, 2050))
+        self.assertHolidayName(name, dts)
+        self.assertHolidayName(name, self.full_range)
         for holidays in self.subdiv_holidays.values():
-            self.assertHolidayName(name, holidays, dt)
-            self.assertHolidayName(name, holidays, range(1900, 2050))
+            self.assertHolidayName(name, holidays, dts)
+            self.assertHolidayName(name, holidays, self.full_range)
 
     def test_anzac_day(self):
         name = "ANZAC Day"
-        self.assertHolidayName(name, (f"{year}-04-25" for year in range(1921, 2050)))
-        self.assertNoHolidayName(name, range(1900, 1921))
+        self.assertHolidayName(name, (f"{year}-04-25" for year in range(1921, self.end_year)))
+        self.assertNoHolidayName(name, range(self.start_year, 1921))
         for holidays in self.subdiv_holidays.values():
-            self.assertHolidayName(name, holidays, range(1921, 2050))
-            self.assertNoHolidayName(name, holidays, range(1900, 1921))
+            self.assertHolidayName(name, holidays, range(1921, self.end_year))
+            self.assertNoHolidayName(name, holidays, range(self.start_year, 1921))
 
-    def test_labour_day(self):
+    def test_labor_day(self):
         name = "Labour Day"
         self.assertNoHolidayName(name)
 
         names = {"NT": "May Day", "TAS": "Eight Hours Day"}
         for subdiv, holidays in self.subdiv_holidays.items():
-            self.assertHolidayName(names.get(subdiv, name), holidays, range(1900, 2050))
+            self.assertHolidayName(names.get(subdiv, name), holidays, self.full_range)
 
     def test_sovereigns_birthday(self):
         name_king = "King's Birthday"
@@ -178,51 +171,52 @@ class TestAustralia(CommonCountryTests, TestCase):
                 (f"{year}-11-09" for year in range(1902, 1912)),
                 (f"{year}-06-03" for year in range(1912, 1936)),
             )
-        self.assertNoHolidayName(name_king, range(1936, 2050))
-        self.assertNoHolidayName(name_queen, range(1936, 2050))
+        self.assertNoHolidayName(name_king, range(1936, self.end_year))
+        self.assertNoHolidayName(name_queen, range(1936, self.end_year))
 
     def test_christmas_day(self):
         name = "Christmas Day"
-        self.assertHolidayName(name, (f"{year}-12-25" for year in range(1900, 2050)))
+        self.assertHolidayName(name, (f"{year}-12-25" for year in self.full_range))
 
         for holidays in self.subdiv_holidays.values():
-            self.assertHolidayName(name, holidays, range(1900, 2050))
+            self.assertHolidayName(name, holidays, self.full_range)
 
     def test_boxing_day(self):
         name_common = "Boxing Day"
         name_sa = "Proclamation Day"
-        self.assertHolidayName(name_common, (f"{year}-12-26" for year in range(1900, 2050)))
+        self.assertHolidayName(name_common, (f"{year}-12-26" for year in self.full_range))
 
         for subdiv, holidays in self.subdiv_holidays.items():
             name = name_sa if subdiv == "SA" else name_common
-            self.assertHolidayName(name, holidays, range(1900, 2050))
+            self.assertHolidayName(name, holidays, self.full_range)
 
     def test_canberra_day(self):
         name = "Canberra Day"
         self.assertNoHolidayName(name)
 
-        dt = (
-            "1959-03-16",
-            "2000-03-20",
-            "2007-03-19",
-            "2008-03-10",
-            "2010-03-08",
-            "2012-03-12",
-            "2018-03-12",
-            "2019-03-11",
-            "2020-03-09",
-            "2021-03-08",
-            "2022-03-14",
-            "2023-03-13",
-            "2024-03-11",
-        )
         for subdiv, holidays in self.subdiv_holidays.items():
             if subdiv == "ACT":
                 self.assertHolidayName(
                     name, holidays, (f"{year}-03-12" for year in range(1913, 1959))
                 )
-                self.assertHolidayName(name, holidays, dt)
-                self.assertNoHolidayName(name, holidays, range(1900, 1913))
+                self.assertHolidayName(
+                    name,
+                    holidays,
+                    "1959-03-16",
+                    "2000-03-20",
+                    "2007-03-19",
+                    "2008-03-10",
+                    "2010-03-08",
+                    "2012-03-12",
+                    "2018-03-12",
+                    "2019-03-11",
+                    "2020-03-09",
+                    "2021-03-08",
+                    "2022-03-14",
+                    "2023-03-13",
+                    "2024-03-11",
+                )
+                self.assertNoHolidayName(name, holidays, range(self.start_year, 1913))
             else:
                 self.assertNoHolidayName(name, holidays)
 
@@ -230,20 +224,23 @@ class TestAustralia(CommonCountryTests, TestCase):
         name = "Family & Community Day"
         self.assertNoHolidayName(name)
 
-        dt = (
-            "2010-09-26",
-            "2011-10-10",
-            "2012-10-08",
-            "2013-09-30",
-            "2014-09-29",
-            "2015-09-28",
-            "2016-09-26",
-            "2017-09-25",
-        )
         for subdiv, holidays in self.subdiv_holidays.items():
             if subdiv == "ACT":
-                self.assertHolidayName(name, holidays, dt)
-                self.assertNoHolidayName(name, holidays, range(1900, 2010), range(2018, 2050))
+                self.assertHolidayName(
+                    name,
+                    holidays,
+                    "2010-09-26",
+                    "2011-10-10",
+                    "2012-10-08",
+                    "2013-09-30",
+                    "2014-09-29",
+                    "2015-09-28",
+                    "2016-09-26",
+                    "2017-09-25",
+                )
+                self.assertNoHolidayName(
+                    name, holidays, range(self.start_year, 2010), range(2018, self.end_year)
+                )
             else:
                 self.assertNoHolidayName(name, holidays)
 
@@ -251,19 +248,20 @@ class TestAustralia(CommonCountryTests, TestCase):
         name = "Reconciliation Day"
         self.assertNoHolidayName(name)
 
-        dt = (
-            "2018-05-28",
-            "2019-05-27",
-            "2020-06-01",
-            "2021-05-31",
-            "2022-05-30",
-            "2023-05-29",
-            "2024-05-27",
-        )
         for subdiv, holidays in self.subdiv_holidays.items():
             if subdiv == "ACT":
-                self.assertHolidayName(name, holidays, dt)
-                self.assertNoHolidayName(name, holidays, range(1900, 2018))
+                self.assertHolidayName(
+                    name,
+                    holidays,
+                    "2018-05-28",
+                    "2019-05-27",
+                    "2020-06-01",
+                    "2021-05-31",
+                    "2022-05-30",
+                    "2023-05-29",
+                    "2024-05-27",
+                )
+                self.assertNoHolidayName(name, holidays, range(self.start_year, 2018))
             else:
                 self.assertNoHolidayName(name, holidays)
 
@@ -271,14 +269,8 @@ class TestAustralia(CommonCountryTests, TestCase):
         name = "Bank Holiday"
         self.assertNoHolidayName(name)
 
-        dt = (
-            "2000-08-07",
-            "2007-08-06",
-            "2008-08-04",
-            "2009-08-03",
-            "2010-08-02",
-        )
-        dt_bank = (
+        self.assertSubdivNswBankHolidayName(
+            name,
             "2018-08-06",
             "2019-08-05",
             "2020-08-03",
@@ -287,11 +279,20 @@ class TestAustralia(CommonCountryTests, TestCase):
             "2023-08-07",
             "2024-08-05",
         )
-        self.assertHolidayName(name, Australia(subdiv="NSW", categories=BANK), dt_bank)
         for subdiv, holidays in self.subdiv_holidays.items():
             if subdiv == "NSW":
-                self.assertHolidayName(name, holidays, dt)
-                self.assertNoHolidayName(name, holidays, range(1900, 1912), range(2011, 2050))
+                self.assertHolidayName(
+                    name,
+                    holidays,
+                    "2000-08-07",
+                    "2007-08-06",
+                    "2008-08-04",
+                    "2009-08-03",
+                    "2010-08-02",
+                )
+                self.assertNoHolidayName(
+                    name, holidays, range(self.start_year, 1912), range(2011, self.end_year)
+                )
             else:
                 self.assertNoHolidayName(name, holidays)
 
@@ -299,21 +300,22 @@ class TestAustralia(CommonCountryTests, TestCase):
         name = "Picnic Day"
         self.assertNoHolidayName(name)
 
-        dt = (
-            "2000-08-07",
-            "2010-08-02",
-            "2018-08-06",
-            "2019-08-05",
-            "2020-08-03",
-            "2021-08-02",
-            "2022-08-01",
-            "2023-08-07",
-            "2024-08-05",
-        )
         for subdiv, holidays in self.subdiv_holidays.items():
             if subdiv == "NT":
-                self.assertHolidayName(name, holidays, dt)
-                self.assertHolidayName(name, holidays, range(1900, 2050))
+                self.assertHolidayName(
+                    name,
+                    holidays,
+                    "2000-08-07",
+                    "2010-08-02",
+                    "2018-08-06",
+                    "2019-08-05",
+                    "2020-08-03",
+                    "2021-08-02",
+                    "2022-08-01",
+                    "2023-08-07",
+                    "2024-08-05",
+                )
+                self.assertHolidayName(name, holidays, self.full_range)
             else:
                 self.assertNoHolidayName(name, holidays)
 
@@ -321,21 +323,22 @@ class TestAustralia(CommonCountryTests, TestCase):
         name = "The Royal Queensland Show"
         self.assertNoHolidayName(name)
 
-        dt = (
-            "2000-08-16",
-            "2010-08-11",
-            "2018-08-15",
-            "2019-08-14",
-            "2020-08-14",
-            "2021-10-29",
-            "2022-08-10",
-            "2023-08-16",
-            "2024-08-14",
-        )
         for subdiv, holidays in self.subdiv_holidays.items():
             if subdiv == "QLD":
-                self.assertHolidayName(name, holidays, dt)
-                self.assertHolidayName(name, holidays, range(1900, 2050))
+                self.assertHolidayName(
+                    name,
+                    holidays,
+                    "2000-08-16",
+                    "2010-08-11",
+                    "2018-08-15",
+                    "2019-08-14",
+                    "2020-08-14",
+                    "2021-10-29",
+                    "2022-08-10",
+                    "2023-08-16",
+                    "2024-08-14",
+                )
+                self.assertHolidayName(name, holidays, self.full_range)
             else:
                 self.assertNoHolidayName(name, holidays)
 
@@ -343,23 +346,24 @@ class TestAustralia(CommonCountryTests, TestCase):
         name = "Adelaide Cup Day"
         self.assertNoHolidayName(name)
 
-        dt = (
-            "2000-05-15",
-            "2005-05-16",
-            "2006-03-13",
-            "2018-03-12",
-            "2019-03-11",
-            "2020-03-09",
-            "2021-03-08",
-            "2022-03-14",
-            "2023-03-13",
-            "2024-03-11",
-        )
         for subdiv, holidays in self.subdiv_holidays.items():
             if subdiv == "SA":
-                self.assertHolidayName(name, holidays, dt)
-                self.assertHolidayName(name, holidays, range(1973, 2050))
-                self.assertNoHolidayName(name, holidays, range(1900, 1973))
+                self.assertHolidayName(
+                    name,
+                    holidays,
+                    "2000-05-15",
+                    "2005-05-16",
+                    "2006-03-13",
+                    "2018-03-12",
+                    "2019-03-11",
+                    "2020-03-09",
+                    "2021-03-08",
+                    "2022-03-14",
+                    "2023-03-13",
+                    "2024-03-11",
+                )
+                self.assertHolidayName(name, holidays, range(1973, self.end_year))
+                self.assertNoHolidayName(name, holidays, range(self.start_year, 1973))
             else:
                 self.assertNoHolidayName(name, holidays)
 
@@ -367,22 +371,23 @@ class TestAustralia(CommonCountryTests, TestCase):
         name = "Melbourne Cup Day"
         self.assertNoHolidayName(name)
 
-        dt = (
-            "2009-11-03",
-            "2010-11-02",
-            "2018-11-06",
-            "2019-11-05",
-            "2020-11-03",
-            "2021-11-02",
-            "2022-11-01",
-            "2023-11-07",
-            "2024-11-05",
-        )
         for subdiv, holidays in self.subdiv_holidays.items():
             if subdiv == "VIC":
-                self.assertHolidayName(name, holidays, dt)
-                self.assertHolidayName(name, holidays, range(2009, 2050))
-                self.assertNoHolidayName(name, holidays, range(1900, 2009))
+                self.assertHolidayName(
+                    name,
+                    holidays,
+                    "2009-11-03",
+                    "2010-11-02",
+                    "2018-11-06",
+                    "2019-11-05",
+                    "2020-11-03",
+                    "2021-11-02",
+                    "2022-11-01",
+                    "2023-11-07",
+                    "2024-11-05",
+                )
+                self.assertHolidayName(name, holidays, range(2009, self.end_year))
+                self.assertNoHolidayName(name, holidays, range(self.start_year, 2009))
             else:
                 self.assertNoHolidayName(name, holidays)
 
@@ -390,83 +395,84 @@ class TestAustralia(CommonCountryTests, TestCase):
         name = "Grand Final Day"
         self.assertNoHolidayName(name)
 
-        dt = (
-            "2015-10-02",
-            "2016-09-30",
-            "2017-09-29",
-            "2018-09-28",
-            "2019-09-27",
-            "2020-10-23",
-            "2021-09-24",
-            "2022-09-23",
-            "2023-09-29",
-            "2024-09-27",
-        )
         for subdiv, holidays in self.subdiv_holidays.items():
             if subdiv == "VIC":
-                self.assertHolidayName(name, holidays, dt)
-                self.assertHolidayName(name, holidays, range(2015, 2050))
-                self.assertNoHolidayName(name, holidays, range(1900, 2015))
+                self.assertHolidayName(
+                    name,
+                    holidays,
+                    "2015-10-02",
+                    "2016-09-30",
+                    "2017-09-29",
+                    "2018-09-28",
+                    "2019-09-27",
+                    "2020-10-23",
+                    "2021-09-24",
+                    "2022-09-23",
+                    "2023-09-29",
+                    "2024-09-27",
+                )
+                self.assertHolidayName(name, holidays, range(2015, self.end_year))
+                self.assertNoHolidayName(name, holidays, range(self.start_year, 2015))
             else:
                 self.assertNoHolidayName(name, holidays)
 
     def test_western_australia_day(self):
-        name_1 = "Foundation Day"
-        name_2 = "Western Australia Day"
-        self.assertNoHolidayName(name_1)
-        self.assertNoHolidayName(name_2)
+        name_1833 = "Foundation Day"
+        name_2012 = "Western Australia Day"
+        self.assertNoHolidayName(name_1833)
+        self.assertNoHolidayName(name_2012)
 
-        dt_1 = (
-            "2000-06-05",
-            "2005-06-06",
-            "2010-06-07",
-            "2011-06-06",
-        )
-        dt_2 = (
-            "2012-06-04",
-            "2013-06-03",
-            "2014-06-02",
-            "2015-06-01",
-            "2016-06-06",
-            "2017-06-05",
-            "2018-06-04",
-            "2019-06-03",
-            "2020-06-01",
-            "2021-06-07",
-            "2022-06-06",
-        )
         for subdiv, holidays in self.subdiv_holidays.items():
             if subdiv == "WA":
-                self.assertHolidayName(name_1, holidays, dt_1)
-                self.assertHolidayName(name_2, holidays, dt_2)
-                self.assertNoHolidayName(name_1, holidays, range(2012, 2050))
-                self.assertNoHolidayName(name_2, holidays, range(1900, 2012))
+                self.assertHolidayName(
+                    name_1833,
+                    holidays,
+                    "2000-06-05",
+                    "2005-06-06",
+                    "2010-06-07",
+                    "2011-06-06",
+                )
+                self.assertHolidayName(
+                    name_2012,
+                    holidays,
+                    "2012-06-04",
+                    "2013-06-03",
+                    "2014-06-02",
+                    "2015-06-01",
+                    "2016-06-06",
+                    "2017-06-05",
+                    "2018-06-04",
+                    "2019-06-03",
+                    "2020-06-01",
+                    "2021-06-07",
+                    "2022-06-06",
+                )
+                self.assertNoHolidayName(name_1833, holidays, range(2012, self.end_year))
+                self.assertNoHolidayName(name_2012, holidays, range(self.start_year, 2012))
             else:
-                self.assertNoHolidayName(name_1, holidays)
-                self.assertNoHolidayName(name_2, holidays)
-        self.assertNoHolidayName(name_1, Australia(subdiv="WA", years=1832))
+                self.assertNoHolidayName(name_1833, holidays)
+                self.assertNoHolidayName(name_2012, holidays)
+        self.assertNoSubdivWaHolidayName(name_1833, 1832)
 
     def test_national_day_of_mourning_for_queen_elizabeth_ii(self):
         name = "National Day of Mourning for Queen Elizabeth II"
-        dt = "2022-09-22"
-        self.assertHolidayName(name, dt)
+        dts = "2022-09-22"
+        self.assertHolidayName(name, dts)
         for holidays in self.subdiv_holidays.values():
-            self.assertHolidayName(name, holidays, dt)
+            self.assertHolidayName(name, holidays, dts)
 
     def test_special_holidays(self):
-        self.assertHoliday(self.subdiv_holidays["ACT"], "2020-04-20", "2021-04-25")
-        self.assertHoliday(self.subdiv_holidays["QLD"], "2010-12-28", "2011-01-03", "2012-06-11")
-        self.assertNoNonObservedHoliday(
-            Australia(subdiv="QLD", observed=False, years=(2010, 2011)), "2010-12-28", "2011-01-03"
-        )
-        self.assertHoliday(self.subdiv_holidays["WA"], "2011-04-26")
+        self.assertSubdivActHoliday("2020-04-20", "2021-04-25")
+        self.assertSubdivQldHoliday("2010-12-28", "2011-01-03", "2012-06-11")
+        self.assertNoSubdivQldNonObservedHoliday("2010-12-28", "2011-01-03")
+        self.assertSubdivWaHoliday("2011-04-26")
 
     def test_all_holidays(self):
         holidays_found = set()
         for subdiv in Australia.subdivisions:
             holidays_found.update(
                 Australia(
-                    categories=(BANK, HALF_DAY, PUBLIC),
+                    categories=Australia.supported_categories,
                     subdiv=subdiv,
                     observed=False,
                     years=(1930, 1957, 2012, 2015, 2023),
