@@ -12,7 +12,7 @@
 
 from unittest import TestCase
 
-from holidays.countries.bouvet_island import BouvetIsland, BV, BVT
+from holidays.countries.bouvet_island import BouvetIsland
 from tests.common import CommonCountryTests
 
 
@@ -20,10 +20,4 @@ class TestBouvetIsland(CommonCountryTests, TestCase):
     @classmethod
     def setUpClass(cls):
         cls.full_range = range(1900, 2050)
-        super().setUpClass(BouvetIsland, years=cls.full_range)
-
-    def test_country_aliases(self):
-        self.assertAliases(BouvetIsland, BV, BVT)
-
-    def test_no_holidays(self):
-        self.assertNoHolidays(BouvetIsland(years=self.full_range))
+        super().setUpClass(BouvetIsland)
