@@ -12,39 +12,27 @@
 
 from unittest import TestCase
 
-from holidays.constants import OPTIONAL, PUBLIC
-from holidays.countries.cabo_verde import CaboVerde, CV, CPV
+from holidays.countries.cabo_verde import CaboVerde
 from tests.common import CommonCountryTests
 
 
 class TestCapeVerde(CommonCountryTests, TestCase):
     @classmethod
     def setUpClass(cls):
-        years = range(1976, 2050)
-        super().setUpClass(CaboVerde, years=years)
-        cls.subdiv_holidays = {
-            subdiv: CaboVerde(subdiv=subdiv, years=years) for subdiv in CaboVerde.subdivisions
-        }
-        cls.opt_holidays = CaboVerde(categories=OPTIONAL, years=years)
-
-    def test_country_aliases(self):
-        self.assertAliases(CaboVerde, CV, CPV)
-
-    def test_no_holidays(self):
-        self.assertNoHolidays(CaboVerde(categories=(OPTIONAL, PUBLIC), years=1975))
+        super().setUpClass(CaboVerde)
 
     def test_new_years_day(self):
-        self.assertHolidayName("Ano Novo", (f"{year}-01-01" for year in range(1976, 2050)))
+        self.assertHolidayName("Ano Novo", (f"{year}-01-01" for year in self.full_range))
 
     def test_democracy_and_freedom_day(self):
         name = "Dia da Liberdade e da Democracia"
-        self.assertHolidayName(name, (f"{year}-01-13" for year in range(2000, 2050)))
-        self.assertNoHolidayName(name, range(1976, 2000))
+        self.assertHolidayName(name, (f"{year}-01-13" for year in range(2000, self.end_year)))
+        self.assertNoHolidayName(name, range(self.start_year, 2000))
 
     def test_heroes_day(self):
         self.assertHolidayName(
             "Dia da Nacionalidade e dos Heróis Nacionais",
-            (f"{year}-01-20" for year in range(1976, 2050)),
+            (f"{year}-01-20" for year in self.full_range),
         )
 
     def test_ash_wednesday(self):
@@ -58,7 +46,7 @@ class TestCapeVerde(CommonCountryTests, TestCase):
             "2024-02-14",
             "2025-03-05",
         )
-        self.assertHolidayName(name, range(1976, 2050))
+        self.assertHolidayName(name, self.full_range)
 
     def test_good_friday(self):
         name = "Sexta-feira Santa"
@@ -71,7 +59,7 @@ class TestCapeVerde(CommonCountryTests, TestCase):
             "2024-03-29",
             "2025-04-18",
         )
-        self.assertHolidayName(name, range(1976, 2050))
+        self.assertHolidayName(name, self.full_range)
 
     def test_easter_sunday(self):
         name = "Páscoa"
@@ -84,40 +72,37 @@ class TestCapeVerde(CommonCountryTests, TestCase):
             "2024-03-31",
             "2025-04-20",
         )
-        self.assertHolidayName(name, range(1976, 2050))
+        self.assertHolidayName(name, self.full_range)
 
     def test_workers_day(self):
-        self.assertHolidayName(
-            "Dia do Trabalhador", (f"{year}-05-01" for year in range(1976, 2050))
-        )
+        self.assertHolidayName("Dia do Trabalhador", (f"{year}-05-01" for year in self.full_range))
 
     def test_international_childrens_day(self):
         name = "Dia Mundial da Criança"
-        self.assertHolidayName(name, (f"{year}-06-01" for year in range(2005, 2050)))
-        self.assertNoHolidayName(name, range(1976, 2005))
+        self.assertHolidayName(name, (f"{year}-06-01" for year in range(2005, self.end_year)))
+        self.assertNoHolidayName(name, range(self.start_year, 2005))
 
     def test_independence_day(self):
         self.assertHolidayName(
-            "Dia da Independência Nacional", (f"{year}-07-05" for year in range(1976, 2050))
+            "Dia da Independência Nacional", (f"{year}-07-05" for year in self.full_range)
         )
 
     def test_assumption_day(self):
-        self.assertHolidayName("Dia da Assunção", (f"{year}-08-15" for year in range(1976, 2050)))
+        self.assertHolidayName("Dia da Assunção", (f"{year}-08-15" for year in self.full_range))
 
     def test_all_saints_day(self):
         self.assertHolidayName(
-            "Dia de Todos os Santos", (f"{year}-11-01" for year in range(1976, 2050))
+            "Dia de Todos os Santos", (f"{year}-11-01" for year in self.full_range)
         )
 
     def test_christmas_day(self):
-        self.assertHolidayName("Dia do Natal", (f"{year}-12-25" for year in range(1976, 2050)))
+        self.assertHolidayName("Dia do Natal", (f"{year}-12-25" for year in self.full_range))
 
     def test_holy_thursday(self):
         name = "Quinta-Feira Santa"
         self.assertNoHolidayName(name)
-        self.assertHolidayName(
+        self.assertOptionalHolidayName(
             name,
-            self.opt_holidays,
             "2020-04-09",
             "2021-04-01",
             "2022-04-14",
@@ -125,14 +110,13 @@ class TestCapeVerde(CommonCountryTests, TestCase):
             "2024-03-28",
             "2025-04-17",
         )
-        self.assertHolidayName(name, self.opt_holidays, range(1976, 2050))
+        self.assertOptionalHolidayName(name, self.full_range)
 
     def test_mothers_day(self):
         name = "Dia das Mães"
         self.assertNoHolidayName(name)
-        self.assertHolidayName(
+        self.assertOptionalHolidayName(
             name,
-            self.opt_holidays,
             "2020-05-10",
             "2021-05-09",
             "2022-05-08",
@@ -140,14 +124,13 @@ class TestCapeVerde(CommonCountryTests, TestCase):
             "2024-05-12",
             "2025-05-11",
         )
-        self.assertHolidayName(name, self.opt_holidays, range(1976, 2050))
+        self.assertOptionalHolidayName(name, self.full_range)
 
     def test_fathers_day(self):
         name = "Dia dos Pais"
         self.assertNoHolidayName(name)
-        self.assertHolidayName(
+        self.assertOptionalHolidayName(
             name,
-            self.opt_holidays,
             "2020-06-21",
             "2021-06-20",
             "2022-06-19",
@@ -155,7 +138,7 @@ class TestCapeVerde(CommonCountryTests, TestCase):
             "2024-06-16",
             "2025-06-15",
         )
-        self.assertHolidayName(name, self.opt_holidays, range(1976, 2050))
+        self.assertOptionalHolidayName(name, self.full_range)
 
     def test_brava_municipality_day(self):
         name = "Dia do Município da Brava"
@@ -163,9 +146,9 @@ class TestCapeVerde(CommonCountryTests, TestCase):
         for subdiv, holidays in self.subdiv_holidays.items():
             if subdiv == "BR":
                 self.assertHolidayName(
-                    name, holidays, (f"{year}-06-24" for year in range(1983, 2050))
+                    name, holidays, (f"{year}-06-24" for year in range(1983, self.end_year))
                 )
-                self.assertNoHolidayName(name, holidays, range(1976, 1983))
+                self.assertNoHolidayName(name, holidays, range(self.start_year, 1983))
             else:
                 self.assertNoHolidayName(name, holidays)
 
@@ -175,9 +158,9 @@ class TestCapeVerde(CommonCountryTests, TestCase):
         for subdiv, holidays in self.subdiv_holidays.items():
             if subdiv == "BV":
                 self.assertHolidayName(
-                    name, holidays, (f"{year}-07-04" for year in range(1983, 2050))
+                    name, holidays, (f"{year}-07-04" for year in range(1983, self.end_year))
                 )
-                self.assertNoHolidayName(name, holidays, range(1976, 1983))
+                self.assertNoHolidayName(name, holidays, range(self.start_year, 1983))
             else:
                 self.assertNoHolidayName(name, holidays)
 
@@ -187,9 +170,9 @@ class TestCapeVerde(CommonCountryTests, TestCase):
         for subdiv, holidays in self.subdiv_holidays.items():
             if subdiv == "CA":
                 self.assertHolidayName(
-                    name, holidays, (f"{year}-11-25" for year in range(1982, 2050))
+                    name, holidays, (f"{year}-11-25" for year in range(1982, self.end_year))
                 )
-                self.assertNoHolidayName(name, holidays, range(1976, 1982))
+                self.assertNoHolidayName(name, holidays, range(self.start_year, 1982))
             else:
                 self.assertNoHolidayName(name, holidays)
 
@@ -199,9 +182,9 @@ class TestCapeVerde(CommonCountryTests, TestCase):
         for subdiv, holidays in self.subdiv_holidays.items():
             if subdiv == "CF":
                 self.assertHolidayName(
-                    name, holidays, (f"{year}-11-25" for year in range(2005, 2050))
+                    name, holidays, (f"{year}-11-25" for year in range(2005, self.end_year))
                 )
-                self.assertNoHolidayName(name, holidays, range(1976, 2005))
+                self.assertNoHolidayName(name, holidays, range(self.start_year, 2005))
             else:
                 self.assertNoHolidayName(name, holidays)
 
@@ -211,9 +194,9 @@ class TestCapeVerde(CommonCountryTests, TestCase):
         for subdiv, holidays in self.subdiv_holidays.items():
             if subdiv == "CR":
                 self.assertHolidayName(
-                    name, holidays, (f"{year}-07-25" for year in range(1983, 2050))
+                    name, holidays, (f"{year}-07-25" for year in range(1983, self.end_year))
                 )
-                self.assertNoHolidayName(name, holidays, range(1976, 1983))
+                self.assertNoHolidayName(name, holidays, range(self.start_year, 1983))
             else:
                 self.assertNoHolidayName(name, holidays)
 
@@ -223,9 +206,9 @@ class TestCapeVerde(CommonCountryTests, TestCase):
         for subdiv, holidays in self.subdiv_holidays.items():
             if subdiv == "MA":
                 self.assertHolidayName(
-                    name, holidays, (f"{year}-09-08" for year in range(1983, 2050))
+                    name, holidays, (f"{year}-09-08" for year in range(1983, self.end_year))
                 )
-                self.assertNoHolidayName(name, holidays, range(1976, 1983))
+                self.assertNoHolidayName(name, holidays, range(self.start_year, 1983))
             else:
                 self.assertNoHolidayName(name, holidays)
 
@@ -235,9 +218,9 @@ class TestCapeVerde(CommonCountryTests, TestCase):
         for subdiv, holidays in self.subdiv_holidays.items():
             if subdiv == "MO":
                 self.assertHolidayName(
-                    name, holidays, (f"{year}-08-15" for year in range(1992, 2050))
+                    name, holidays, (f"{year}-08-15" for year in range(1992, self.end_year))
                 )
-                self.assertNoHolidayName(name, holidays, range(1976, 1992))
+                self.assertNoHolidayName(name, holidays, range(self.start_year, 1992))
             else:
                 self.assertNoHolidayName(name, holidays)
 
@@ -247,9 +230,9 @@ class TestCapeVerde(CommonCountryTests, TestCase):
         for subdiv, holidays in self.subdiv_holidays.items():
             if subdiv in {"PA", "PN", "RG"}:
                 self.assertHolidayName(
-                    name, holidays, (f"{year}-01-17" for year in range(1983, 2050))
+                    name, holidays, (f"{year}-01-17" for year in range(1983, self.end_year))
                 )
-                self.assertNoHolidayName(name, holidays, range(1976, 1983))
+                self.assertNoHolidayName(name, holidays, range(self.start_year, 1983))
             else:
                 self.assertNoHolidayName(name, holidays)
 
@@ -259,9 +242,9 @@ class TestCapeVerde(CommonCountryTests, TestCase):
         for subdiv, holidays in self.subdiv_holidays.items():
             if subdiv == "PA":
                 self.assertHolidayName(
-                    name, holidays, (f"{year}-06-13" for year in range(1983, 2050))
+                    name, holidays, (f"{year}-06-13" for year in range(1983, self.end_year))
                 )
-                self.assertNoHolidayName(name, holidays, range(1976, 1983))
+                self.assertNoHolidayName(name, holidays, range(self.start_year, 1983))
             else:
                 self.assertNoHolidayName(name, holidays)
 
@@ -271,9 +254,9 @@ class TestCapeVerde(CommonCountryTests, TestCase):
         for subdiv, holidays in self.subdiv_holidays.items():
             if subdiv == "PN":
                 self.assertHolidayName(
-                    name, holidays, (f"{year}-09-02" for year in range(1983, 2050))
+                    name, holidays, (f"{year}-09-02" for year in range(1983, self.end_year))
                 )
-                self.assertNoHolidayName(name, holidays, range(1976, 1983))
+                self.assertNoHolidayName(name, holidays, range(self.start_year, 1983))
             else:
                 self.assertNoHolidayName(name, holidays)
 
@@ -283,9 +266,9 @@ class TestCapeVerde(CommonCountryTests, TestCase):
         for subdiv, holidays in self.subdiv_holidays.items():
             if subdiv == "PR":
                 self.assertHolidayName(
-                    name, holidays, (f"{year}-05-19" for year in range(1983, 2050))
+                    name, holidays, (f"{year}-05-19" for year in range(1983, self.end_year))
                 )
-                self.assertNoHolidayName(name, holidays, range(1976, 1983))
+                self.assertNoHolidayName(name, holidays, range(self.start_year, 1983))
             else:
                 self.assertNoHolidayName(name, holidays)
 
@@ -295,9 +278,9 @@ class TestCapeVerde(CommonCountryTests, TestCase):
         for subdiv, holidays in self.subdiv_holidays.items():
             if subdiv == "RB":
                 self.assertHolidayName(
-                    name, holidays, (f"{year}-12-06" for year in range(2005, 2050))
+                    name, holidays, (f"{year}-12-06" for year in range(2005, self.end_year))
                 )
-                self.assertNoHolidayName(name, holidays, range(1976, 2005))
+                self.assertNoHolidayName(name, holidays, range(self.start_year, 2005))
             else:
                 self.assertNoHolidayName(name, holidays)
 
@@ -307,9 +290,9 @@ class TestCapeVerde(CommonCountryTests, TestCase):
         for subdiv, holidays in self.subdiv_holidays.items():
             if subdiv == "RG":
                 self.assertHolidayName(
-                    name, holidays, (f"{year}-05-07" for year in range(1983, 2050))
+                    name, holidays, (f"{year}-05-07" for year in range(1983, self.end_year))
                 )
-                self.assertNoHolidayName(name, holidays, range(1976, 1983))
+                self.assertNoHolidayName(name, holidays, range(self.start_year, 1983))
             else:
                 self.assertNoHolidayName(name, holidays)
 
@@ -319,9 +302,9 @@ class TestCapeVerde(CommonCountryTests, TestCase):
         for subdiv, holidays in self.subdiv_holidays.items():
             if subdiv == "RS":
                 self.assertHolidayName(
-                    name, holidays, (f"{year}-01-31" for year in range(2006, 2050))
+                    name, holidays, (f"{year}-01-31" for year in range(2006, self.end_year))
                 )
-                self.assertNoHolidayName(name, holidays, range(1976, 2006))
+                self.assertNoHolidayName(name, holidays, range(self.start_year, 2006))
             else:
                 self.assertNoHolidayName(name, holidays)
 
@@ -331,9 +314,9 @@ class TestCapeVerde(CommonCountryTests, TestCase):
         for subdiv, holidays in self.subdiv_holidays.items():
             if subdiv == "SD":
                 self.assertHolidayName(
-                    name, holidays, (f"{year}-03-13" for year in range(1994, 2050))
+                    name, holidays, (f"{year}-03-13" for year in range(1994, self.end_year))
                 )
-                self.assertNoHolidayName(name, holidays, range(1976, 1994))
+                self.assertNoHolidayName(name, holidays, range(self.start_year, 1994))
             else:
                 self.assertNoHolidayName(name, holidays)
 
@@ -343,9 +326,9 @@ class TestCapeVerde(CommonCountryTests, TestCase):
         for subdiv, holidays in self.subdiv_holidays.items():
             if subdiv == "SF":
                 self.assertHolidayName(
-                    name, holidays, (f"{year}-05-01" for year in range(1992, 2050))
+                    name, holidays, (f"{year}-05-01" for year in range(1992, self.end_year))
                 )
-                self.assertNoHolidayName(name, holidays, range(1976, 1992))
+                self.assertNoHolidayName(name, holidays, range(self.start_year, 1992))
             else:
                 self.assertNoHolidayName(name, holidays)
 
@@ -355,9 +338,9 @@ class TestCapeVerde(CommonCountryTests, TestCase):
         for subdiv, holidays in self.subdiv_holidays.items():
             if subdiv == "SL":
                 self.assertHolidayName(
-                    name, holidays, (f"{year}-09-15" for year in range(1983, 2050))
+                    name, holidays, (f"{year}-09-15" for year in range(1983, self.end_year))
                 )
-                self.assertNoHolidayName(name, holidays, range(1976, 1983))
+                self.assertNoHolidayName(name, holidays, range(self.start_year, 1983))
             else:
                 self.assertNoHolidayName(name, holidays)
 
@@ -367,9 +350,9 @@ class TestCapeVerde(CommonCountryTests, TestCase):
         for subdiv, holidays in self.subdiv_holidays.items():
             if subdiv == "SM":
                 self.assertHolidayName(
-                    name, holidays, (f"{year}-09-29" for year in range(1997, 2050))
+                    name, holidays, (f"{year}-09-29" for year in range(1997, self.end_year))
                 )
-                self.assertNoHolidayName(name, holidays, range(1976, 1997))
+                self.assertNoHolidayName(name, holidays, range(self.start_year, 1997))
             else:
                 self.assertNoHolidayName(name, holidays)
 
@@ -379,9 +362,9 @@ class TestCapeVerde(CommonCountryTests, TestCase):
         for subdiv, holidays in self.subdiv_holidays.items():
             if subdiv == "SO":
                 self.assertHolidayName(
-                    name, holidays, (f"{year}-05-09" for year in range(2005, 2050))
+                    name, holidays, (f"{year}-05-09" for year in range(2005, self.end_year))
                 )
-                self.assertNoHolidayName(name, holidays, range(1976, 2005))
+                self.assertNoHolidayName(name, holidays, range(self.start_year, 2005))
             else:
                 self.assertNoHolidayName(name, holidays)
 
@@ -391,9 +374,9 @@ class TestCapeVerde(CommonCountryTests, TestCase):
         for subdiv, holidays in self.subdiv_holidays.items():
             if subdiv == "SS":
                 self.assertHolidayName(
-                    name, holidays, (f"{year}-07-19" for year in range(2005, 2050))
+                    name, holidays, (f"{year}-07-19" for year in range(2005, self.end_year))
                 )
-                self.assertNoHolidayName(name, holidays, range(1976, 2005))
+                self.assertNoHolidayName(name, holidays, range(self.start_year, 2005))
             else:
                 self.assertNoHolidayName(name, holidays)
 
@@ -403,9 +386,9 @@ class TestCapeVerde(CommonCountryTests, TestCase):
         for subdiv, holidays in self.subdiv_holidays.items():
             if subdiv == "SV":
                 self.assertHolidayName(
-                    name, holidays, (f"{year}-01-22" for year in range(1983, 2050))
+                    name, holidays, (f"{year}-01-22" for year in range(1983, self.end_year))
                 )
-                self.assertNoHolidayName(name, holidays, range(1976, 1983))
+                self.assertNoHolidayName(name, holidays, range(self.start_year, 1983))
             else:
                 self.assertNoHolidayName(name, holidays)
 
@@ -424,8 +407,8 @@ class TestCapeVerde(CommonCountryTests, TestCase):
                     "2024-02-13",
                     "2025-03-04",
                 )
-                self.assertHolidayName(name, holidays, range(1983, 2050))
-                self.assertNoHolidayName(name, holidays, range(1976, 1983))
+                self.assertHolidayName(name, holidays, range(1983, self.end_year))
+                self.assertNoHolidayName(name, holidays, range(self.start_year, 1983))
             else:
                 self.assertNoHolidayName(name, holidays)
 
@@ -435,9 +418,9 @@ class TestCapeVerde(CommonCountryTests, TestCase):
         for subdiv, holidays in self.subdiv_holidays.items():
             if subdiv == "TA":
                 self.assertHolidayName(
-                    name, holidays, (f"{year}-01-15" for year in range(1983, 2050))
+                    name, holidays, (f"{year}-01-15" for year in range(1983, self.end_year))
                 )
-                self.assertNoHolidayName(name, holidays, range(1976, 1983))
+                self.assertNoHolidayName(name, holidays, range(self.start_year, 1983))
             else:
                 self.assertNoHolidayName(name, holidays)
 
@@ -447,15 +430,15 @@ class TestCapeVerde(CommonCountryTests, TestCase):
         for subdiv, holidays in self.subdiv_holidays.items():
             if subdiv == "TS":
                 self.assertHolidayName(
-                    name, holidays, (f"{year}-08-02" for year in range(2005, 2050))
+                    name, holidays, (f"{year}-08-02" for year in range(2005, self.end_year))
                 )
-                self.assertNoHolidayName(name, holidays, range(1976, 2005))
+                self.assertNoHolidayName(name, holidays, range(self.start_year, 2005))
             else:
                 self.assertNoHolidayName(name, holidays)
 
     def test_2024_public_holidays(self):
-        self.assertHolidays(
-            CaboVerde(categories=PUBLIC, years=2024),
+        self.assertHolidaysInYear(
+            2024,
             ("2024-01-01", "Ano Novo"),
             ("2024-01-13", "Dia da Liberdade e da Democracia"),
             ("2024-01-20", "Dia da Nacionalidade e dos Heróis Nacionais"),
@@ -471,8 +454,8 @@ class TestCapeVerde(CommonCountryTests, TestCase):
         )
 
     def test_2024_optional_holidays(self):
-        self.assertHolidays(
-            CaboVerde(categories=OPTIONAL, years=2024),
+        self.assertOptionalHolidaysInYear(
+            2024,
             ("2024-03-28", "Quinta-Feira Santa"),
             ("2024-05-12", "Dia das Mães"),
             ("2024-06-16", "Dia dos Pais"),
