@@ -12,20 +12,14 @@
 
 from unittest import TestCase
 
-from holidays.countries.cambodia import Cambodia, KH, KHM
+from holidays.countries.cambodia import Cambodia
 from tests.common import CommonCountryTests
 
 
 class TestCambodia(CommonCountryTests, TestCase):
     @classmethod
     def setUpClass(cls):
-        super().setUpClass(Cambodia, years=range(1993, 2050))
-
-    def test_country_aliases(self):
-        self.assertAliases(Cambodia, KH, KHM)
-
-    def test_no_holidays(self):
-        self.assertNoHolidays(Cambodia(years=1992))
+        super().setUpClass(Cambodia)
 
     def test_special_holidays(self):
         self.assertHoliday(
@@ -43,8 +37,8 @@ class TestCambodia(CommonCountryTests, TestCase):
         )
 
     def test_2022(self):
-        self.assertHolidays(
-            Cambodia(years=2022),
+        self.assertHolidaysInYear(
+            2022,
             ("2022-01-01", "ទិវាចូលឆ្នាំសាកល"),
             ("2022-01-07", "ទិវាជ័យជម្នះលើរបបប្រល័យពូជសាសន៍"),
             ("2022-03-08", "ទិវាអន្តរជាតិនារី"),
@@ -81,8 +75,8 @@ class TestCambodia(CommonCountryTests, TestCase):
         )
 
     def test_2023(self):
-        self.assertHolidays(
-            Cambodia(years=2023),
+        self.assertHolidaysInYear(
+            2023,
             ("2023-01-01", "ទិវាចូលឆ្នាំសាកល"),
             ("2023-01-07", "ទិវាជ័យជម្នះលើរបបប្រល័យពូជសាសន៍"),
             ("2023-03-08", "ទិវាអន្តរជាតិនារី"),
@@ -119,12 +113,19 @@ class TestCambodia(CommonCountryTests, TestCase):
             ("2023-11-28", "ព្រះរាជពិធីបុណ្យអុំទូក បណ្តែតប្រទីប និងសំពះព្រះខែអកអំបុក"),
         )
 
+    def test_new_years_day(self):
+        self.assertHolidayName("ទិវាចូលឆ្នាំសាកល", (f"{year}-01-01" for year in self.full_range))
+
     def test_day_of_victory_over_genocidal_regime(self):
         self.assertHolidayName(
-            "ទិវាជ័យជម្នះលើរបបប្រល័យពូជសាសន៍", (f"{year}-01-07" for year in range(1993, 2050))
+            "ទិវាជ័យជម្នះលើរបបប្រល័យពូជសាសន៍", (f"{year}-01-07" for year in self.full_range)
         )
 
-    def test_sangkranta(self):
+    def test_international_womens_day(self):
+        self.assertHolidayName("ទិវាអន្តរជាតិនារី", (f"{year}-03-08" for year in self.full_range))
+
+    def test_khmer_new_year(self):
+        name = "ពិធីបុណ្យចូលឆ្នាំថ្មីប្រពៃណីជាតិ"
         years_sangkranta_apr14 = {
             2017,
             2018,
@@ -138,38 +139,61 @@ class TestCambodia(CommonCountryTests, TestCase):
             2030,
             2031,
         }
-        for year in set(range(1993, 2050)).difference({2020}):
-            if year in years_sangkranta_apr14:
-                self.assertHoliday(f"{year}-04-14", f"{year}-04-15", f"{year}-04-16")
-            else:
-                self.assertHoliday(f"{year}-04-13", f"{year}-04-14", f"{year}-04-15")
+        self.assertHolidayNameCount(
+            name, 3, range(self.start_year, 2020), range(2021, 2024), range(2025, self.end_year)
+        )
+        self.assertHolidayNameCount(name, 4, 2024)
+        self.assertHolidayName(name, (f"{year}-04-14" for year in years_sangkranta_apr14))
+        self.assertHolidayName(
+            name,
+            (
+                f"{year}-04-13"
+                for year in self.full_range
+                if year not in years_sangkranta_apr14 and year != 2020
+            ),
+        )
+        self.assertNoHolidayName(name, 2020)
+        self.assertNoHolidayName(name, (f"{year}-04-13" for year in years_sangkranta_apr14))
+        self.assertNoHolidayName(
+            name,
+            (
+                f"{year}-04-16"
+                for year in self.full_range
+                if year not in years_sangkranta_apr14 and year not in {2020, 2024}
+            ),
+        )
+
+    def test_international_labor_day(self):
+        self.assertHolidayName("ទិវាពលកម្មអន្តរជាតិ", (f"{year}-05-01" for year in self.full_range))
 
     def test_king_sihamoni_birthday(self):
         name = "ព្រះរាជពិធីបុណ្យចម្រើនព្រះជន្ម ព្រះករុណា ព្រះបាទសម្តេចព្រះបរមនាថ នរោត្តម សីហមុនី"
-        self.assertHolidayName(name, (f"{year}-05-13" for year in range(2005, 2020)))
-        self.assertHolidayName(name, (f"{year}-05-14" for year in range(2005, 2050)))
-        self.assertHolidayName(name, (f"{year}-05-15" for year in range(2005, 2020)))
-        self.assertNoHolidayName(name, range(1993, 2005))
+        self.assertHolidayName(
+            name,
+            (f"{year}-05-13" for year in range(2005, 2020)),
+            (f"{year}-05-14" for year in range(2005, self.end_year)),
+            (f"{year}-05-15" for year in range(2005, 2020)),
+        )
+        self.assertNoHolidayName(name, range(self.start_year, 2005))
+        self.assertHolidayNameCount(name, 1, range(2020, self.end_year))
 
     def test_national_day_of_remembrance(self):
         name = "ទិវាជាតិនៃការចងចាំ"
         self.assertHolidayName(name, (f"{year}-05-20" for year in range(2018, 2020)))
-        self.assertNoHolidayName(name, range(1993, 2018), range(2020, 2050))
+        self.assertNoHolidayName(name, range(self.start_year, 2018), range(2020, self.end_year))
 
     def test_international_children_day(self):
         name = "ទិវាកុមារអន្តរជាតិ"
-        self.assertHolidayName(name, (f"{year}-06-01" for year in range(1993, 2020)))
-        self.assertNoHolidayName(name, range(2020, 2050))
+        self.assertHolidayName(name, (f"{year}-06-01" for year in range(self.start_year, 2020)))
+        self.assertNoHolidayName(name, range(2020, self.end_year))
 
     def test_queen_mother_monineath_birthday(self):
         name = "ព្រះរាជពិធីបុណ្យចម្រើនព្រះជន្ម សម្តេចព្រះមហាក្សត្រី ព្រះវររាជមាតា នរោត្តម មុនិនាថ សីហនុ"
-        self.assertHolidayName(name, (f"{year}-06-18" for year in range(1994, 2050)))
-        self.assertNoHolidayName(name, 1993)
+        self.assertHolidayName(name, (f"{year}-06-18" for year in range(1994, self.end_year)))
+        self.assertNoHolidayName(name, self.start_year)
 
     def test_constitution_day(self):
-        self.assertHolidayName(
-            "ទិវាប្រកាសរដ្ឋធម្មនុញ្ញ", (f"{year}-09-24" for year in range(1993, 2050))
-        )
+        self.assertHolidayName("ទិវាប្រកាសរដ្ឋធម្មនុញ្ញ", (f"{year}-09-24" for year in self.full_range))
 
     def test_king_sihanouk_memorial_day(self):
         name = (
@@ -177,13 +201,13 @@ class TestCambodia(CommonCountryTests, TestCase):
             " នរោត្តម សីហនុ ព្រះមហាវីរក្សត្រ ព្រះវររាជបិតាឯករាជ្យ បូរណភាពទឹកដី"
             " និងឯកភាពជាតិខ្មែរ ព្រះបរមរតនកោដ្ឋ"
         )
-        self.assertHolidayName(name, (f"{year}-10-15" for year in range(2012, 2050)))
-        self.assertNoHolidayName(name, range(1993, 2012))
+        self.assertHolidayName(name, (f"{year}-10-15" for year in range(2012, self.end_year)))
+        self.assertNoHolidayName(name, range(self.start_year, 2012))
 
     def test_paris_peace_agreement_day(self):
         name = "ទិវារំលឹកសន្ធិសញ្ញាសន្តិភាពទីក្រុងប៉ារីស"
-        self.assertHolidayName(name, (f"{year}-10-23" for year in range(1993, 2020)))
-        self.assertNoHolidayName(name, range(2020, 2050))
+        self.assertHolidayName(name, (f"{year}-10-23" for year in range(self.start_year, 2020)))
+        self.assertNoHolidayName(name, range(2020, self.end_year))
 
     def test_king_sihamoni_coronation_day(self):
         name = (
@@ -191,21 +215,61 @@ class TestCambodia(CommonCountryTests, TestCase):
             "ព្រះបាទសម្តេចព្រះបរមនាថ នរោត្តម សីហមុនី "
             "ព្រះមហាក្សត្រនៃព្រះរាជាណាចក្រកម្ពុជា"
         )
-        self.assertHolidayName(name, (f"{year}-10-29" for year in range(2004, 2050)))
-        self.assertNoHolidayName(name, range(1993, 2004))
+        self.assertHolidayName(name, (f"{year}-10-29" for year in range(2004, self.end_year)))
+        self.assertNoHolidayName(name, range(self.start_year, 2004))
 
     def test_national_independence_day(self):
-        self.assertHolidayName("ពិធីបុណ្យឯករាជ្យជាតិ", (f"{year}-11-09" for year in range(1993, 2050)))
+        self.assertHolidayName("ពិធីបុណ្យឯករាជ្យជាតិ", (f"{year}-11-09" for year in self.full_range))
 
     def test_international_human_rights_day(self):
         name = "ទិវាសិទ្ធិមនុស្សអន្តរជាតិ"
-        self.assertHolidayName(name, (f"{year}-12-10" for year in range(1993, 2020)))
-        self.assertNoHolidayName(name, range(2020, 2050))
+        self.assertHolidayName(name, (f"{year}-12-10" for year in range(self.start_year, 2020)))
+        self.assertNoHolidayName(name, range(2020, self.end_year))
 
     def test_peace_day_in_cambodia(self):
         name = "ទិវាសន្តិភាពនៅកម្ពុជា"
-        self.assertHolidayName(name, (f"{year}-12-29" for year in range(2024, 2050)))
-        self.assertNoHolidayName(name, range(1993, 2024))
+        self.assertHolidayName(name, (f"{year}-12-29" for year in range(2024, self.end_year)))
+        self.assertNoHolidayName(name, range(self.start_year, 2024))
+
+    def test_meak_bochea(self):
+        name = "ពិធីបុណ្យមាឃបូជា"
+        self.assertHolidayName(
+            name,
+            "2014-02-14",
+            "2015-02-03",
+            "2016-02-22",
+            "2017-02-11",
+            "2018-01-31",
+            "2019-02-19",
+        )
+        self.assertHolidayName(name, range(self.start_year, 2020))
+        self.assertNoHolidayName(name, range(2020, self.end_year))
+
+    def test_visaka_bochea(self):
+        name = "ពិធីបុណ្យវិសាខបូជា"
+        self.assertHolidayName(
+            name,
+            "2020-05-06",
+            "2021-04-26",
+            "2022-05-15",
+            "2023-05-04",
+            "2024-05-22",
+            "2025-05-11",
+        )
+        self.assertHolidayName(name, self.full_range)
+
+    def test_royal_ploughing_ceremony(self):
+        name = "ព្រះរាជពិធីច្រត់ព្រះនង្គ័ល"
+        self.assertHolidayName(
+            name,
+            "2020-05-10",
+            "2021-04-30",
+            "2022-05-19",
+            "2023-05-08",
+            "2024-05-26",
+            "2025-05-15",
+        )
+        self.assertHolidayName(name, self.full_range)
 
     def test_pchum_ben(self):
         name = "ពិធីបុណ្យភ្ផុំបិណ្ឌ"
@@ -239,6 +303,8 @@ class TestCambodia(CommonCountryTests, TestCase):
             "2023-10-14",
             "2023-10-15",
         )
+        self.assertHolidayNameCount(name, 2, range(self.start_year, 2017))
+        self.assertHolidayNameCount(name, 3, range(2017, self.end_year))
 
     def test_bon_om_touk(self):
         name = "ព្រះរាជពិធីបុណ្យអុំទូក បណ្តែតប្រទីប និងសំពះព្រះខែអកអំបុក"
@@ -273,6 +339,7 @@ class TestCambodia(CommonCountryTests, TestCase):
             "2023-11-27",
             "2023-11-28",
         )
+        self.assertHolidayNameCount(name, 3, self.full_range)
 
     def test_l10n_default(self):
         self.assertLocalizedHolidays(
