@@ -12,22 +12,14 @@
 
 from unittest import TestCase
 
-from holidays.constants import HALF_DAY, PUBLIC
-from holidays.countries.china import China, CN, CHN
+from holidays.countries.china import China
 from tests.common import CommonCountryTests, WorkingDayTests
 
 
 class TestChina(CommonCountryTests, WorkingDayTests, TestCase):
     @classmethod
     def setUpClass(cls):
-        super().setUpClass(China, years=range(1950, 2050), years_non_observed=range(2001, 2025))
-
-    def test_country_aliases(self):
-        self.assertAliases(China, CN, CHN)
-
-    def test_no_holidays(self):
-        self.assertNoHolidays(China(years=1949))
-        self.assertNoHolidays(China(years=1949, categories=HALF_DAY))
+        super().setUpClass(China, years_non_observed=range(2001, 2025))
 
     def test_substituted_holidays(self):
         self.assertHoliday(
@@ -194,6 +186,12 @@ class TestChina(CommonCountryTests, WorkingDayTests, TestCase):
             "2025-05-05",
             "2025-10-07",
             "2025-10-08",
+            "2026-01-02",
+            "2026-02-20",
+            "2026-02-23",
+            "2026-05-05",
+            "2026-10-06",
+            "2026-10-07",
         )
 
     def test_workdays(self):
@@ -361,6 +359,12 @@ class TestChina(CommonCountryTests, WorkingDayTests, TestCase):
             "2025-04-27",
             "2025-09-28",
             "2025-10-11",
+            "2026-01-04",
+            "2026-02-14",
+            "2026-02-28",
+            "2026-05-09",
+            "2026-09-20",
+            "2026-10-10",
         )
 
         for year, dts in {
@@ -405,9 +409,10 @@ class TestChina(CommonCountryTests, WorkingDayTests, TestCase):
             self.assertWorkingDay(China(years=year), dts)
 
     def test_new_years_day(self):
-        self.assertHolidayName("元旦", (f"{year}-01-01" for year in range(1950, 2050)))
+        name = "元旦"
+        self.assertHolidayName(name, (f"{year}-01-01" for year in self.full_range))
 
-        self.assertNoNonObservedHoliday(
+        obs_dts = (
             "2005-01-03",
             "2006-01-02",
             "2011-01-03",
@@ -416,6 +421,8 @@ class TestChina(CommonCountryTests, WorkingDayTests, TestCase):
             "2022-01-03",
             "2023-01-02",
         )
+        self.assertHolidayName(f"{name}（观察日）", obs_dts)
+        self.assertNoNonObservedHoliday(obs_dts)
 
     def test_chinese_new_year_eve(self):
         name = "农历除夕"
@@ -428,19 +435,20 @@ class TestChina(CommonCountryTests, WorkingDayTests, TestCase):
             "2012-01-22",
             "2013-02-09",
         )
-        self.assertHolidayName(name, range(2025, 2050))
-        self.assertNoHolidayName(name, range(1950, 2008), range(2014, 2025))
+        self.assertHolidayName(name, range(2008, 2014), range(2025, self.end_year))
+        self.assertNoHolidayName(name, range(self.start_year, 2008), range(2014, 2025))
 
-        self.assertNoNonObservedHoliday(
+        obs_dts = (
             "2009-01-28",
             "2010-02-16",
             "2012-01-25",
             "2013-02-12",
         )
+        self.assertHolidayName(f"{name}（观察日）", obs_dts)
+        self.assertNoNonObservedHoliday(obs_dts)
 
     def test_chinese_new_year(self):
         name = "春节"
-        self.assertHolidayName(name, range(1950, 2050))
         self.assertHolidayName(
             name,
             "2021-02-12",
@@ -453,8 +461,12 @@ class TestChina(CommonCountryTests, WorkingDayTests, TestCase):
             "2023-01-23",
             "2023-01-24",
         )
+        self.assertHolidayNameCount(
+            name, 3, range(self.start_year, 2008), range(2014, self.end_year)
+        )
+        self.assertHolidayNameCount(name, 2, range(2008, 2014))
 
-        self.assertNoNonObservedHoliday(
+        obs_dts = (
             "2003-02-04",
             "2003-02-05",
             "2004-01-26",
@@ -478,18 +490,18 @@ class TestChina(CommonCountryTests, WorkingDayTests, TestCase):
             "2024-02-13",
             "2024-02-14",
         )
-        self.assertHolidayNameCount(name, 3, range(1950, 2008), range(2014, 2050))
-        self.assertHolidayNameCount(name, 2, range(2008, 2014))
+        self.assertHolidayName(f"{name}（观察日）", obs_dts)
+        self.assertNoNonObservedHoliday(obs_dts)
 
     def test_labor_day(self):
         name = "劳动节"
-        self.assertHolidayName(name, (f"{year}-05-01" for year in range(1950, 2050)))
+        self.assertHolidayName(name, (f"{year}-05-01" for year in self.full_range))
         self.assertHolidayName(
-            name, (f"{year}-05-02" for year in (*range(2000, 2008), *range(2025, 2050)))
+            name, (f"{year}-05-02" for year in (*range(2000, 2008), *range(2025, self.end_year)))
         )
         self.assertHolidayName(name, (f"{year}-05-03" for year in range(2000, 2008)))
 
-        self.assertNoNonObservedHoliday(
+        obs_dts = (
             "2003-05-05",
             "2004-05-04",
             "2004-05-05",
@@ -500,15 +512,16 @@ class TestChina(CommonCountryTests, WorkingDayTests, TestCase):
             "2021-05-03",
             "2022-05-02",
         )
+        self.assertHolidayName(f"{name}（观察日）", obs_dts)
+        self.assertNoNonObservedHoliday(obs_dts)
 
     def test_national_day(self):
         name = "国庆节"
-        for year in range(1950, 1999):
-            self.assertHolidayName(name, (f"{year}-10-01", f"{year}-10-02"))
-        for year in range(1999, 2050):
-            self.assertHolidayName(name, (f"{year}-10-01", f"{year}-10-02", f"{year}-10-03"))
+        self.assertHolidayName(name, (f"{year}-10-01" for year in self.full_range))
+        self.assertHolidayName(name, (f"{year}-10-02" for year in self.full_range))
+        self.assertHolidayName(name, (f"{year}-10-03" for year in range(1999, self.end_year)))
 
-        self.assertNoNonObservedHoliday(
+        obs_dts = (
             "2004-10-04",
             "2004-10-05",
             "2005-10-04",
@@ -530,12 +543,11 @@ class TestChina(CommonCountryTests, WorkingDayTests, TestCase):
             "2022-10-05",
             "2023-10-04",
         )
+        self.assertHolidayName(f"{name}（观察日）", obs_dts)
+        self.assertNoNonObservedHoliday(obs_dts)
 
     def test_qingming_festival(self):
         name = "清明节"
-        self.assertHolidayName(name, range(2008, 2050))
-        self.assertNoHolidayName(name, range(1950, 2008))
-
         self.assertHolidayName(
             name,
             "2017-04-04",
@@ -547,20 +559,21 @@ class TestChina(CommonCountryTests, WorkingDayTests, TestCase):
             "2023-04-05",
             "2024-04-04",
         )
+        self.assertHolidayName(name, range(2008, self.end_year))
+        self.assertNoHolidayName(name, range(self.start_year, 2008))
 
-        self.assertNoNonObservedHoliday(
+        obs_dts = (
             "2009-04-06",
             "2014-04-07",
             "2015-04-06",
             "2020-04-06",
             "2021-04-05",
         )
+        self.assertHolidayName(f"{name}（观察日）", obs_dts)
+        self.assertNoNonObservedHoliday(obs_dts)
 
     def test_dragon_boat_festival(self):
         name = "端午节"
-        self.assertHolidayName(name, range(2008, 2050))
-        self.assertNoHolidayName(name, range(1950, 2008))
-
         self.assertHolidayName(
             name,
             "2017-05-30",
@@ -572,18 +585,19 @@ class TestChina(CommonCountryTests, WorkingDayTests, TestCase):
             "2023-06-22",
             "2024-06-10",
         )
+        self.assertHolidayName(name, range(2008, self.end_year))
+        self.assertNoHolidayName(name, range(self.start_year, 2008))
 
-        self.assertNoNonObservedHoliday(
+        obs_dts = (
             "2008-06-09",
             "2012-06-22",
             "2015-06-22",
         )
+        self.assertHolidayName(f"{name}（观察日）", obs_dts)
+        self.assertNoNonObservedHoliday(obs_dts)
 
     def test_mid_autumn_festival(self):
         name = "中秋节"
-        self.assertHolidayName(name, range(2008, 2050))
-        self.assertNoHolidayName(name, range(1950, 2008))
-
         self.assertHolidayName(
             name,
             "2017-10-04",
@@ -595,8 +609,10 @@ class TestChina(CommonCountryTests, WorkingDayTests, TestCase):
             "2023-09-29",
             "2024-09-17",
         )
+        self.assertHolidayName(name, range(2008, self.end_year))
+        self.assertNoHolidayName(name, range(self.start_year, 2008))
 
-        self.assertNoNonObservedHoliday(
+        obs_dts = (
             "2008-09-15",
             "2009-10-05",
             "2012-10-04",
@@ -604,10 +620,32 @@ class TestChina(CommonCountryTests, WorkingDayTests, TestCase):
             "2020-10-06",
             "2022-09-12",
         )
+        self.assertHolidayName(f"{name}（观察日）", obs_dts)
+        self.assertNoNonObservedHoliday(obs_dts)
+
+    def test_international_womens_day(self):
+        name = "国际妇女节"
+        self.assertNoHolidayName(name)
+        self.assertHalfDayHolidayName(name, (f"{year}-03-08" for year in self.full_range))
+
+    def test_youth_day(self):
+        name = "五四青年节"
+        self.assertNoHolidayName(name)
+        self.assertHalfDayHolidayName(name, (f"{year}-05-04" for year in self.full_range))
+
+    def test_childrens_day(self):
+        name = "六一儿童节"
+        self.assertNoHolidayName(name)
+        self.assertHalfDayHolidayName(name, (f"{year}-06-01" for year in self.full_range))
+
+    def test_army_day(self):
+        name = "建军节"
+        self.assertNoHolidayName(name)
+        self.assertHalfDayHolidayName(name, (f"{year}-08-01" for year in self.full_range))
 
     def test_1950_public_holiday(self):
-        self.assertHolidays(
-            China(categories=PUBLIC, years=1950),
+        self.assertHolidaysInYear(
+            1950,
             ("1950-01-01", "元旦"),
             ("1950-02-17", "春节"),
             ("1950-02-18", "春节"),
@@ -618,8 +656,8 @@ class TestChina(CommonCountryTests, WorkingDayTests, TestCase):
         )
 
     def test_1999_public_holiday(self):
-        self.assertHolidays(
-            China(categories=PUBLIC, years=1999),
+        self.assertHolidaysInYear(
+            1999,
             ("1999-01-01", "元旦"),
             ("1999-02-16", "春节"),
             ("1999-02-17", "春节"),
@@ -632,8 +670,8 @@ class TestChina(CommonCountryTests, WorkingDayTests, TestCase):
 
     def test_2001_public_holiday(self):
         # https://zh.wikisource.org/wiki/国务院办公厅关于2001年春节、“五一”、“十一”放假安排的通知
-        self.assertHolidays(
-            China(categories=PUBLIC, years=2001),
+        self.assertHolidaysInYear(
+            2001,
             # New Year is not listed, but should be there according to 1999 revision.
             ("2001-01-01", "元旦"),
             ("2001-01-24", "春节"),
@@ -655,8 +693,8 @@ class TestChina(CommonCountryTests, WorkingDayTests, TestCase):
 
     def test_2002_public_holiday(self):
         # https://zh.wikisource.org/wiki/国务院办公厅关于2002年部分节假日休息安排的通知
-        self.assertHolidays(
-            China(categories=PUBLIC, years=2002),
+        self.assertHolidaysInYear(
+            2002,
             ("2002-01-01", "元旦"),
             ("2002-01-02", "休息日（2001-12-29日起取代）"),
             ("2002-01-03", "休息日（2001-12-30日起取代）"),
@@ -679,8 +717,8 @@ class TestChina(CommonCountryTests, WorkingDayTests, TestCase):
 
     def test_2003_public_holiday(self):
         # https://zh.wikisource.org/wiki/国务院办公厅关于2003年部分节假日休息安排的通知
-        self.assertHolidays(
-            China(categories=PUBLIC, years=2003),
+        self.assertHolidaysInYear(
+            2003,
             ("2003-01-01", "元旦"),
             ("2003-02-01", "春节"),
             ("2003-02-02", "春节"),
@@ -704,8 +742,8 @@ class TestChina(CommonCountryTests, WorkingDayTests, TestCase):
 
     def test_2004_public_holiday(self):
         # https://zh.wikisource.org/wiki/国务院办公厅关于2004年部分节假日安排的通知
-        self.assertHolidays(
-            China(categories=PUBLIC, years=2004),
+        self.assertHolidaysInYear(
+            2004,
             ("2004-01-01", "元旦"),
             ("2004-01-22", "春节"),
             ("2004-01-23", "春节"),
@@ -731,8 +769,8 @@ class TestChina(CommonCountryTests, WorkingDayTests, TestCase):
 
     def test_2005_public_holiday(self):
         # https://zh.wikisource.org/wiki/国务院办公厅关于2005年部分节假日安排的通知
-        self.assertHolidays(
-            China(categories=PUBLIC, years=2005),
+        self.assertHolidaysInYear(
+            2005,
             ("2005-01-01", "元旦"),
             ("2005-01-03", "元旦（观察日）"),
             ("2005-02-09", "春节"),
@@ -757,8 +795,8 @@ class TestChina(CommonCountryTests, WorkingDayTests, TestCase):
 
     def test_2006_public_holiday(self):
         # https://zh.wikisource.org/wiki/国务院办公厅关于2006年部分节假日安排的通知
-        self.assertHolidays(
-            China(categories=PUBLIC, years=2006),
+        self.assertHolidaysInYear(
+            2006,
             ("2006-01-01", "元旦"),
             ("2006-01-02", "元旦（观察日）"),
             ("2006-01-03", "休息日（2005-12-31日起取代）"),
@@ -783,8 +821,8 @@ class TestChina(CommonCountryTests, WorkingDayTests, TestCase):
 
     def test_2007_public_holiday(self):
         # https://www.gov.cn/gongbao/content/2007/content_503397.htm
-        self.assertHolidays(
-            China(categories=PUBLIC, years=2007),
+        self.assertHolidaysInYear(
+            2007,
             ("2007-01-01", "元旦"),
             ("2007-01-02", "休息日（2006-12-30日起取代）"),
             ("2007-01-03", "休息日（2006-12-31日起取代）"),
@@ -809,8 +847,8 @@ class TestChina(CommonCountryTests, WorkingDayTests, TestCase):
 
     def test_2008_public_holiday(self):
         # https://www.gov.cn/gongbao/content/2008/content_859870.htm
-        self.assertHolidays(
-            China(categories=PUBLIC, years=2008),
+        self.assertHolidaysInYear(
+            2008,
             ("2008-01-01", "元旦"),
             ("2008-02-06", "农历除夕"),
             ("2008-02-07", "春节"),
@@ -833,8 +871,8 @@ class TestChina(CommonCountryTests, WorkingDayTests, TestCase):
 
     def test_2009_public_holiday(self):
         # https://www.gov.cn/gongbao/content/2008/content_1175823.htm
-        self.assertHolidays(
-            China(categories=PUBLIC, years=2009),
+        self.assertHolidaysInYear(
+            2009,
             ("2009-01-01", "元旦"),
             ("2009-01-02", "休息日（2009-01-04日起取代）"),
             ("2009-01-25", "农历除夕"),
@@ -859,8 +897,8 @@ class TestChina(CommonCountryTests, WorkingDayTests, TestCase):
 
     def test_2010_public_holiday(self):
         # https://www.gov.cn/gongbao/content/2009/content_1487011.htm
-        self.assertHolidays(
-            China(categories=PUBLIC, years=2010),
+        self.assertHolidaysInYear(
+            2010,
             ("2010-01-01", "元旦"),
             ("2010-02-13", "农历除夕"),
             ("2010-02-14", "春节"),
@@ -889,8 +927,8 @@ class TestChina(CommonCountryTests, WorkingDayTests, TestCase):
 
     def test_2011_public_holiday(self):
         # https://www.gov.cn/gongbao/content/2010/content_1765282.htm
-        self.assertHolidays(
-            China(categories=PUBLIC, years=2011),
+        self.assertHolidaysInYear(
+            2011,
             ("2011-01-01", "元旦"),
             ("2011-01-03", "元旦（观察日）"),
             ("2011-02-02", "农历除夕"),
@@ -915,8 +953,8 @@ class TestChina(CommonCountryTests, WorkingDayTests, TestCase):
 
     def test_2012_public_holiday(self):
         # https://www.gov.cn/gongbao/content/2011/content_2020918.htm
-        self.assertHolidays(
-            China(categories=PUBLIC, years=2012),
+        self.assertHolidaysInYear(
+            2012,
             ("2012-01-01", "元旦"),
             ("2012-01-02", "元旦（观察日）"),
             ("2012-01-03", "休息日（2011-12-31日起取代）"),
@@ -943,8 +981,8 @@ class TestChina(CommonCountryTests, WorkingDayTests, TestCase):
 
     def test_2013_public_holiday(self):
         # https://www.gov.cn/gongbao/content/2012/content_2292057.htm
-        self.assertHolidays(
-            China(categories=PUBLIC, years=2013),
+        self.assertHolidaysInYear(
+            2013,
             ("2013-01-01", "元旦"),
             ("2013-01-02", "休息日（2013-01-05日起取代）"),
             ("2013-01-03", "休息日（2013-01-06日起取代）"),
@@ -974,8 +1012,8 @@ class TestChina(CommonCountryTests, WorkingDayTests, TestCase):
 
     def test_2014_public_holiday(self):
         # https://www.gov.cn/gongbao/content/2014/content_2561299.htm
-        self.assertHolidays(
-            China(categories=PUBLIC, years=2014),
+        self.assertHolidaysInYear(
+            2014,
             ("2014-01-01", "元旦"),
             ("2014-01-31", "春节"),
             ("2014-02-01", "春节"),
@@ -999,8 +1037,8 @@ class TestChina(CommonCountryTests, WorkingDayTests, TestCase):
 
     def test_2015_public_holiday(self):
         # https://www.gov.cn/gongbao/content/2015/content_2799019.htm
-        self.assertHolidays(
-            China(categories=PUBLIC, years=2015),
+        self.assertHolidaysInYear(
+            2015,
             ("2015-01-01", "元旦"),
             ("2015-01-02", "休息日（2015-01-04日起取代）"),
             ("2015-02-18", "休息日（2015-02-15日起取代）"),
@@ -1027,8 +1065,8 @@ class TestChina(CommonCountryTests, WorkingDayTests, TestCase):
 
     def test_2016_public_holiday(self):
         # https://www.gov.cn/gongbao/content/2016/content_2979719.htm
-        self.assertHolidays(
-            China(categories=PUBLIC, years=2016),
+        self.assertHolidaysInYear(
+            2016,
             ("2016-01-01", "元旦"),
             ("2016-02-08", "春节"),
             ("2016-02-09", "春节"),
@@ -1053,8 +1091,8 @@ class TestChina(CommonCountryTests, WorkingDayTests, TestCase):
 
     def test_2017_public_holiday(self):
         # https://www.gov.cn/gongbao/content/2016/content_5148793.htm
-        self.assertHolidays(
-            China(categories=PUBLIC, years=2017),
+        self.assertHolidaysInYear(
+            2017,
             ("2017-01-01", "元旦"),
             ("2017-01-02", "元旦（观察日）"),
             ("2017-01-27", "休息日（2017-01-22日起取代）"),
@@ -1079,8 +1117,8 @@ class TestChina(CommonCountryTests, WorkingDayTests, TestCase):
 
     def test_2018_public_holiday(self):
         # https://www.gov.cn/gongbao/content/2017/content_5248221.htm
-        self.assertHolidays(
-            China(categories=PUBLIC, years=2018),
+        self.assertHolidaysInYear(
+            2018,
             ("2018-01-01", "元旦"),
             ("2018-02-15", "休息日（2018-02-11日起取代）"),
             ("2018-02-16", "春节"),
@@ -1105,8 +1143,8 @@ class TestChina(CommonCountryTests, WorkingDayTests, TestCase):
 
     def test_2019_public_holiday(self):
         # https://www.gov.cn/gongbao/content/2018/content_5350046.htm
-        self.assertHolidays(
-            China(categories=PUBLIC, years=2019),
+        self.assertHolidaysInYear(
+            2019,
             ("2019-01-01", "元旦"),
             ("2019-02-04", "休息日（2019-02-02日起取代）"),
             ("2019-02-05", "春节"),
@@ -1127,8 +1165,8 @@ class TestChina(CommonCountryTests, WorkingDayTests, TestCase):
     def test_2020_public_holiday(self):
         # https://www.gov.cn/gongbao/content/2019/content_5459138.htm
         # https://www.gov.cn/zhengce/zhengceku/2020-01/27/content_5472352.htm
-        self.assertHolidays(
-            China(categories=PUBLIC, years=2020),
+        self.assertHolidaysInYear(
+            2020,
             ("2020-01-01", "元旦"),
             ("2020-01-24", "休息日（2020-01-19日起取代）"),
             ("2020-01-25", "春节"),
@@ -1158,8 +1196,8 @@ class TestChina(CommonCountryTests, WorkingDayTests, TestCase):
 
     def test_2021_public_holiday(self):
         # https://www.gov.cn/gongbao/content/2020/content_5567750.htm
-        self.assertHolidays(
-            China(categories=PUBLIC, years=2021),
+        self.assertHolidaysInYear(
+            2021,
             ("2021-01-01", "元旦"),
             ("2021-02-11", "休息日（2021-02-07日起取代）"),
             ("2021-02-12", "春节"),
@@ -1188,8 +1226,8 @@ class TestChina(CommonCountryTests, WorkingDayTests, TestCase):
 
     def test_2022_public_holiday(self):
         # https://www.gov.cn/gongbao/content/2021/content_5651728.htm
-        self.assertHolidays(
-            China(categories=PUBLIC, years=2022),
+        self.assertHolidaysInYear(
+            2022,
             ("2022-01-01", "元旦"),
             ("2022-01-03", "元旦（观察日）"),
             ("2022-01-31", "休息日（2022-01-29日起取代）"),
@@ -1217,8 +1255,8 @@ class TestChina(CommonCountryTests, WorkingDayTests, TestCase):
 
     def test_2023_public_holiday(self):
         # https://www.gov.cn/gongbao/content/2023/content_5736714.htm
-        self.assertHolidays(
-            China(categories=PUBLIC, years=2023),
+        self.assertHolidaysInYear(
+            2023,
             ("2023-01-01", "元旦"),
             ("2023-01-02", "元旦（观察日）"),
             ("2023-01-22", "春节"),
@@ -1244,8 +1282,8 @@ class TestChina(CommonCountryTests, WorkingDayTests, TestCase):
 
     def test_2024_public_holiday(self):
         # https://www.gov.cn/zhengce/content/202310/content_6911527.htm
-        self.assertHolidays(
-            China(categories=PUBLIC, years=2024),
+        self.assertHolidaysInYear(
+            2024,
             ("2024-01-01", "元旦"),
             ("2024-02-10", "春节"),
             ("2024-02-11", "春节"),
@@ -1271,8 +1309,8 @@ class TestChina(CommonCountryTests, WorkingDayTests, TestCase):
 
     def test_2025_public_holiday(self):
         # https://www.gov.cn/zhengce/content/202411/content_6986382.htm
-        self.assertHolidays(
-            China(categories=PUBLIC, years=2025),
+        self.assertHolidaysInYear(
+            2025,
             ("2025-01-01", "元旦"),
             ("2025-01-28", "农历除夕"),
             ("2025-01-29", "春节"),
@@ -1294,22 +1332,32 @@ class TestChina(CommonCountryTests, WorkingDayTests, TestCase):
             ("2025-10-08", "休息日（2025-10-11日起取代）"),
         )
 
-    def test_2022_half_day_holiday(self):
-        self.assertHolidays(
-            China(categories=HALF_DAY, years=2022),
-            ("2022-03-08", "国际妇女节"),
-            ("2022-05-04", "五四青年节"),
-            ("2022-06-01", "六一儿童节"),
-            ("2022-08-01", "建军节"),
-        )
-
-    def test_2023_half_day_holiday(self):
-        self.assertHolidays(
-            China(categories=HALF_DAY, years=2023),
-            ("2023-03-08", "国际妇女节"),
-            ("2023-05-04", "五四青年节"),
-            ("2023-06-01", "六一儿童节"),
-            ("2023-08-01", "建军节"),
+    def test_2026_public_holiday(self):
+        # https://www.gov.cn/zhengce/content/202511/content_7047090.htm
+        self.assertHolidaysInYear(
+            2026,
+            ("2026-01-01", "元旦"),
+            ("2026-01-02", "休息日（2026-01-04日起取代）"),
+            ("2026-02-16", "农历除夕"),
+            ("2026-02-17", "春节"),
+            ("2026-02-18", "春节"),
+            ("2026-02-19", "春节"),
+            ("2026-02-20", "休息日（2026-02-14日起取代）"),
+            ("2026-02-23", "休息日（2026-02-28日起取代）"),
+            ("2026-04-05", "清明节"),
+            ("2026-04-06", "清明节（观察日）"),
+            ("2026-05-01", "劳动节"),
+            ("2026-05-02", "劳动节"),
+            ("2026-05-04", "劳动节（观察日）"),
+            ("2026-05-05", "休息日（2026-05-09日起取代）"),
+            ("2026-06-19", "端午节"),
+            ("2026-09-25", "中秋节"),
+            ("2026-10-01", "国庆节"),
+            ("2026-10-02", "国庆节"),
+            ("2026-10-03", "国庆节"),
+            ("2026-10-05", "国庆节（观察日）"),
+            ("2026-10-06", "休息日（2026-09-20日起取代）"),
+            ("2026-10-07", "休息日（2026-10-10日起取代）"),
         )
 
     def test_l10n_default(self):
@@ -1389,7 +1437,7 @@ class TestChina(CommonCountryTests, WorkingDayTests, TestCase):
             ("2022-05-01", "วันแรงงาน"),
             ("2022-05-02", "ชดเชยวันแรงงาน"),
             ("2022-05-03", "วันหยุด (แทน 24/04/2022)"),
-            ("2022-05-04", "วันหยุด (แทน 07/05/2022); วันเยาวชนห่งชาติจีน"),
+            ("2022-05-04", "วันหยุด (แทน 07/05/2022); วันเยาวชนแห่งชาติจีน"),
             ("2022-06-01", "วันเด็กสากล"),
             ("2022-06-03", "วันไหว้บ๊ะจ่าง"),
             ("2022-08-01", "วันสถาปนากองทัพปลดปล่อยประชาชนจีน"),
