@@ -14,8 +14,6 @@ from unittest import TestCase
 
 from holidays.countries.heard_island_and_mcdonald_islands import (
     HeardIslandAndMcDonaldIslands,
-    HM,
-    HMD,
 )
 from tests.common import CommonCountryTests
 
@@ -24,10 +22,4 @@ class TestHeardIslandAndMcDonaldIslands(CommonCountryTests, TestCase):
     @classmethod
     def setUpClass(cls):
         cls.full_range = range(1900, 2050)
-        super().setUpClass(HeardIslandAndMcDonaldIslands, years=cls.full_range)
-
-    def test_country_aliases(self):
-        self.assertAliases(HeardIslandAndMcDonaldIslands, HM, HMD)
-
-    def test_no_holidays(self):
-        self.assertNoHolidays(HeardIslandAndMcDonaldIslands(years=self.full_range))
+        super().setUpClass(HeardIslandAndMcDonaldIslands)
