@@ -14,28 +14,26 @@ import warnings
 from unittest import TestCase
 
 from holidays.constants import OPTIONAL
-from holidays.countries.india import India, IN, IND
+from holidays.countries.india import India
 from tests.common import CommonCountryTests
 
 
 class TestIndia(CommonCountryTests, TestCase):
     @classmethod
     def setUpClass(cls):
+        warnings.simplefilter("ignore")
         super().setUpClass(India)
 
     def setUp(self):
         super().setUp()
         warnings.simplefilter("ignore")
 
-    def test_country_aliases(self):
-        self.assertAliases(India, IN, IND)
-
     def test_subdiv_deprecation(self):
         self.assertDeprecatedSubdivisions("This subdivision is deprecated and will be removed")
 
     def test_2018(self):
-        self.assertHolidayDates(
-            India(years=2018),
+        self.assertHolidayDatesInYear(
+            2018,
             "2018-01-26",
             "2018-02-13",
             "2018-03-29",
@@ -173,8 +171,8 @@ class TestIndia(CommonCountryTests, TestCase):
             self.assertHoliday(India(subdiv=subdiv), holidays)
 
     def test_2018_optional(self):
-        self.assertHolidayDates(
-            India(categories=OPTIONAL, years=2018),
+        self.assertOptionalHolidayDatesInYear(
+            2018,
             "2018-01-14",
             "2018-03-02",
             "2018-03-25",
