@@ -13,7 +13,7 @@
 from unittest import TestCase
 
 from holidays import CHRISTIAN, HEBREW, SABIAN, YAZIDI
-from holidays.countries.iraq import Iraq, IQ, IRQ
+from holidays.countries.iraq import Iraq
 from tests.common import CommonCountryTests
 
 
@@ -28,12 +28,6 @@ class TestIraq(CommonCountryTests, TestCase):
         cls.sabian_holidays = Iraq(categories=SABIAN, years=years)
         cls.yazidi_holidays = Iraq(categories=YAZIDI, years=years)
 
-    def test_country_aliases(self):
-        self.assertAliases(Iraq, IQ, IRQ)
-
-    def test_no_holidays(self):
-        self.assertNoHolidays(Iraq(categories=Iraq.supported_categories, years=1963))
-
     def test_new_years_day(self):
         name = "رأس السنة الميلادية"
         self.assertHolidayName(name, (f"{year}-01-01" for year in range(1973, 2050)))
@@ -380,8 +374,8 @@ class TestIraq(CommonCountryTests, TestCase):
         )
 
     def test_2024(self):
-        self.assertHolidays(
-            Iraq(years=2024),
+        self.assertHolidaysInYear(
+            2024,
             ("2024-01-01", "رأس السنة الميلادية"),
             ("2024-01-06", "عيد الجيش"),
             ("2024-02-08", "ثورة 8 شباط"),
