@@ -12,7 +12,7 @@
 
 from unittest import TestCase
 
-from holidays.countries.jordan import Jordan, JO, JOR
+from holidays.countries.jordan import Jordan
 from tests.common import CommonCountryTests
 
 
@@ -21,12 +21,9 @@ class TestJordan(CommonCountryTests, TestCase):
     def setUpClass(cls):
         super().setUpClass(Jordan)
 
-    def test_country_aliases(self):
-        self.assertAliases(Jordan, JO, JOR)
-
     def test_2024(self):
-        self.assertHolidays(
-            Jordan(years=2024),
+        self.assertHolidaysInYear(
+            2024,
             ("2024-01-01", "رأس السنة الميلادية"),
             ("2024-02-08", "ليلة المعراج (المقدرة)"),
             ("2024-04-10", "عيد الفطر (المقدرة)"),
