@@ -12,7 +12,7 @@
 
 from unittest import TestCase
 
-from holidays.countries.kazakhstan import Kazakhstan, KZ, KAZ
+from holidays.countries.kazakhstan import Kazakhstan
 from tests.common import CommonCountryTests, WorkingDayTests
 
 
@@ -23,12 +23,6 @@ class TestKazakhstan(CommonCountryTests, WorkingDayTests, TestCase):
         super().setUpClass(Kazakhstan, years=years, years_non_observed=years)
         cls.no_estimated_holidays = Kazakhstan(years=years, islamic_show_estimated=False)
 
-    def test_country_aliases(self):
-        self.assertAliases(Kazakhstan, KZ, KAZ)
-
-    def test_no_holidays(self):
-        self.assertNoHolidays(Kazakhstan(years=1990))
-
     def test_substituted_holidays(self):
         self.assertHoliday(
             "2000-05-08",
@@ -304,9 +298,9 @@ class TestKazakhstan(CommonCountryTests, WorkingDayTests, TestCase):
         self.assertHoliday(observed_holidays)
         self.assertNoNonObservedHoliday(observed_holidays)
 
-    def test2022(self):
-        self.assertHolidays(
-            Kazakhstan(years=2022),
+    def test_2022(self):
+        self.assertHolidaysInYear(
+            2022,
             ("2022-01-01", "Жаңа жыл"),
             ("2022-01-02", "Жаңа жыл"),
             ("2022-01-03", "Жаңа жыл (қайта белгіленген демалыс)"),
