@@ -13,7 +13,7 @@
 from unittest import TestCase
 
 from holidays.constants import HINDU, ISLAMIC
-from holidays.countries.kenya import Kenya, KE, KEN
+from holidays.countries.kenya import Kenya
 from tests.common import CommonCountryTests
 
 
@@ -22,11 +22,9 @@ class TestKenya(CommonCountryTests, TestCase):
     def setUpClass(cls):
         super().setUpClass(Kenya, years=range(1964, 2050), years_non_observed=range(2000, 2050))
 
-    def test_country_aliases(self):
-        self.assertAliases(Kenya, KE, KEN)
-
     def test_no_holidays(self):
-        self.assertNoHolidays(Kenya(years=1963))
+        super().test_no_holidays()
+
         self.assertNoHolidays(Kenya(categories=ISLAMIC, years=1963))
         self.assertNoHolidays(Kenya(categories=HINDU, years=1983))
 
@@ -261,8 +259,8 @@ class TestKenya(CommonCountryTests, TestCase):
         )
 
     def test_2010(self):
-        self.assertHolidays(
-            Kenya(years=2010),
+        self.assertHolidaysInYear(
+            2010,
             ("2010-01-01", "New Year's Day"),
             ("2010-04-02", "Good Friday"),
             ("2010-04-05", "Easter Monday"),
@@ -277,8 +275,8 @@ class TestKenya(CommonCountryTests, TestCase):
         )
 
     def test_2019(self):
-        self.assertHolidays(
-            Kenya(years=2019),
+        self.assertHolidaysInYear(
+            2019,
             ("2019-01-01", "New Year's Day"),
             ("2019-04-19", "Good Friday"),
             ("2019-04-22", "Easter Monday"),
@@ -294,8 +292,8 @@ class TestKenya(CommonCountryTests, TestCase):
         )
 
     def test_2022(self):
-        self.assertHolidays(
-            Kenya(years=2022),
+        self.assertHolidaysInYear(
+            2022,
             ("2022-01-01", "New Year's Day"),
             ("2022-04-15", "Good Friday"),
             ("2022-04-18", "Easter Monday"),
