@@ -12,7 +12,7 @@
 
 from unittest import TestCase
 
-from holidays.countries.kuwait import Kuwait, KW, KWT
+from holidays.countries.kuwait import Kuwait
 from tests.common import CommonCountryTests
 
 
@@ -21,12 +21,9 @@ class TestKuwait(CommonCountryTests, TestCase):
     def setUpClass(cls):
         super().setUpClass(Kuwait)
 
-    def test_country_aliases(self):
-        self.assertAliases(Kuwait, KW, KWT)
-
     def test_2022(self):
-        self.assertHolidays(
-            Kuwait(years=2022),
+        self.assertHolidaysInYear(
+            2022,
             ("2022-01-01", "رأس السنة الميلادية"),
             ("2022-02-25", "اليوم الوطني"),
             ("2022-02-26", "يوم التحرير"),
