@@ -12,8 +12,8 @@
 
 from unittest import TestCase
 
-from holidays.constants import BANK, PUBLIC, SCHOOL, WORKDAY
-from holidays.countries.laos import Laos, LA, LAO
+from holidays.constants import BANK, WORKDAY
+from holidays.countries.laos import Laos
 from tests.common import CommonCountryTests
 
 
@@ -22,12 +22,6 @@ class TestLaos(CommonCountryTests, TestCase):
     def setUpClass(cls):
         super().setUpClass(Laos, years=range(1976, 2050), years_non_observed=range(2018, 2050))
 
-    def test_country_aliases(self):
-        self.assertAliases(Laos, LA, LAO)
-
-    def test_no_holidays(self):
-        self.assertNoHolidays(Laos(categories=(BANK, PUBLIC, SCHOOL, WORKDAY), years=1975))
-
     def test_special_bank_holiday(self):
         self.assertHoliday(
             Laos(categories=BANK),
@@ -61,8 +55,8 @@ class TestLaos(CommonCountryTests, TestCase):
         )
 
     def test_2022_public_holiday(self):
-        self.assertHolidays(
-            Laos(categories=PUBLIC, years=2022),
+        self.assertHolidaysInYear(
+            2022,
             ("2022-01-01", "ວັນປີໃໝ່ສາກົນ"),
             ("2022-01-03", "ພັກຊົດເຊີຍວັນປີໃໝ່ສາກົນ"),
             ("2022-03-08", "ວັນແມ່ຍິງສາກົນ"),
@@ -76,8 +70,8 @@ class TestLaos(CommonCountryTests, TestCase):
         )
 
     def test_2023_public_holiday(self):
-        self.assertHolidays(
-            Laos(categories=PUBLIC, years=2023),
+        self.assertHolidaysInYear(
+            2023,
             ("2023-01-01", "ວັນປີໃໝ່ສາກົນ"),
             ("2023-01-02", "ພັກຊົດເຊີຍວັນປີໃໝ່ສາກົນ"),
             ("2023-03-08", "ວັນແມ່ຍິງສາກົນ"),
@@ -165,8 +159,8 @@ class TestLaos(CommonCountryTests, TestCase):
 
     def test_2014_bank_holidays(self):
         # Dec 31 is Wednesday.
-        self.assertHolidays(
-            Laos(categories=BANK, years=2014),
+        self.assertBankHolidaysInYear(
+            2014,
             ("2014-10-07", "ວັນສ້າງຕັ້ງທະນາຄານແຫ່ງ ສປປ ລາວ"),
             ("2014-12-29", "ສາມວັນລັດຖະການສຸດທ້າຍຂອງທຸກໆປີ"),
             ("2014-12-30", "ສາມວັນລັດຖະການສຸດທ້າຍຂອງທຸກໆປີ"),
@@ -175,8 +169,8 @@ class TestLaos(CommonCountryTests, TestCase):
 
     def test_2018_bank_holidays(self):
         # Dec 31 is Monday.
-        self.assertHolidays(
-            Laos(categories=BANK, years=2018),
+        self.assertBankHolidaysInYear(
+            2018,
             ("2018-10-07", "ວັນສ້າງຕັ້ງທະນາຄານແຫ່ງ ສປປ ລາວ"),
             ("2018-10-08", "ພັກຊົດເຊີຍວັນສ້າງຕັ້ງທະນາຄານແຫ່ງ ສປປ ລາວ"),
             ("2018-12-27", "ສາມວັນລັດຖະການສຸດທ້າຍຂອງທຸກໆປີ"),
@@ -186,8 +180,8 @@ class TestLaos(CommonCountryTests, TestCase):
 
     def test_2019_bank_holidays(self):
         # Dec 31 is Tuesday.
-        self.assertHolidays(
-            Laos(categories=BANK, years=2019),
+        self.assertBankHolidaysInYear(
+            2019,
             ("2019-10-07", "ວັນສ້າງຕັ້ງທະນາຄານແຫ່ງ ສປປ ລາວ"),
             ("2019-12-27", "ສາມວັນລັດຖະການສຸດທ້າຍຂອງທຸກໆປີ"),
             ("2019-12-30", "ສາມວັນລັດຖະການສຸດທ້າຍຂອງທຸກໆປີ"),
@@ -196,8 +190,8 @@ class TestLaos(CommonCountryTests, TestCase):
 
     def test_2020_bank_holidays(self):
         # Dec 31 is Thursday.
-        self.assertHolidays(
-            Laos(categories=BANK, years=2020),
+        self.assertBankHolidaysInYear(
+            2020,
             ("2020-10-07", "ວັນສ້າງຕັ້ງທະນາຄານແຫ່ງ ສປປ ລາວ"),
             ("2020-12-29", "ສາມວັນລັດຖະການສຸດທ້າຍຂອງທຸກໆປີ"),
             ("2020-12-30", "ສາມວັນລັດຖະການສຸດທ້າຍຂອງທຸກໆປີ"),
@@ -206,8 +200,8 @@ class TestLaos(CommonCountryTests, TestCase):
 
     def test_2021_bank_holidays(self):
         # Dec 31 is Friday.
-        self.assertHolidays(
-            Laos(categories=BANK, years=2021),
+        self.assertBankHolidaysInYear(
+            2021,
             ("2021-10-07", "ວັນສ້າງຕັ້ງທະນາຄານແຫ່ງ ສປປ ລາວ"),
             ("2021-12-29", "ສາມວັນລັດຖະການສຸດທ້າຍຂອງທຸກໆປີ"),
             ("2021-12-30", "ສາມວັນລັດຖະການສຸດທ້າຍຂອງທຸກໆປີ"),
@@ -216,8 +210,8 @@ class TestLaos(CommonCountryTests, TestCase):
 
     def test_2022_bank_holidays(self):
         # Dec 31 is Saturday.
-        self.assertHolidays(
-            Laos(categories=BANK, years=2022),
+        self.assertBankHolidaysInYear(
+            2022,
             ("2022-10-07", "ວັນສ້າງຕັ້ງທະນາຄານແຫ່ງ ສປປ ລາວ"),
             ("2022-12-28", "ສາມວັນລັດຖະການສຸດທ້າຍຂອງທຸກໆປີ"),
             ("2022-12-29", "ສາມວັນລັດຖະການສຸດທ້າຍຂອງທຸກໆປີ"),
@@ -226,8 +220,8 @@ class TestLaos(CommonCountryTests, TestCase):
 
     def test_2023_bank_holidays(self):
         # Dec 31 is Sunday.
-        self.assertHolidays(
-            Laos(categories=BANK, years=2023),
+        self.assertBankHolidaysInYear(
+            2023,
             ("2023-10-07", "ວັນສ້າງຕັ້ງທະນາຄານແຫ່ງ ສປປ ລາວ"),
             ("2023-10-09", "ພັກຊົດເຊີຍວັນສ້າງຕັ້ງທະນາຄານແຫ່ງ ສປປ ລາວ"),
             ("2023-12-27", "ສາມວັນລັດຖະການສຸດທ້າຍຂອງທຸກໆປີ"),
@@ -237,8 +231,8 @@ class TestLaos(CommonCountryTests, TestCase):
 
     def test_1993_school_holidays(self):
         # Prior to Adoption of National Teacher Day
-        self.assertHolidays(
-            Laos(categories=SCHOOL, years=1993),
+        self.assertSchoolHolidaysInYear(
+            1993,
             ("1993-02-06", "ວັນບຸນມາຂະບູຊາ"),
             ("1993-05-05", "ວັນບຸນວິສາຂະບູຊາ"),
             ("1993-07-03", "ວັນບຸນເຂົ້າພັນສາ"),
@@ -250,8 +244,8 @@ class TestLaos(CommonCountryTests, TestCase):
         )
 
     def test_2022_school_holidays(self):
-        self.assertHolidays(
-            Laos(categories=SCHOOL, years=2022),
+        self.assertSchoolHolidaysInYear(
+            2022,
             ("2022-02-16", "ວັນບຸນມາຂະບູຊາ"),
             ("2022-05-15", "ວັນບຸນວິສາຂະບູຊາ"),
             ("2022-07-13", "ວັນບຸນເຂົ້າພັນສາ"),
@@ -264,8 +258,8 @@ class TestLaos(CommonCountryTests, TestCase):
         )
 
     def test_2023_school_holidays(self):
-        self.assertHolidays(
-            Laos(categories=SCHOOL, years=2023),
+        self.assertSchoolHolidaysInYear(
+            2023,
             ("2023-02-05", "ວັນບຸນມາຂະບູຊາ"),
             ("2023-05-04", "ວັນບຸນວິສາຂະບູຊາ"),
             ("2023-08-01", "ວັນບຸນເຂົ້າພັນສາ"),
@@ -279,8 +273,8 @@ class TestLaos(CommonCountryTests, TestCase):
 
     def test_1988_workdays(self):
         # Prior to National Arbor Day creation in 1989.
-        self.assertHolidays(
-            Laos(categories=WORKDAY, years=1988),
+        self.assertWorkdayHolidaysInYear(
+            1988,
             ("1988-01-20", "ວັນສ້າງຕັ້ງກອງທັບປະຊາຊົນລາວ"),
             ("1988-02-01", "ວັນສ້າງຕັ້ງສະຫະພັນກໍາມະບານລາວ"),
             ("1988-03-22", "ວັນສ້າງຕັ້ງພັກປະຊາຊົນປະຕິວັດລາວ"),
@@ -294,8 +288,8 @@ class TestLaos(CommonCountryTests, TestCase):
 
     def test_1990_workdays(self):
         # Prior to Kaysone Phomvihane's Presidency and 1991 Constitution Adoption.
-        self.assertHolidays(
-            Laos(categories=WORKDAY, years=1990),
+        self.assertWorkdayHolidaysInYear(
+            1990,
             ("1990-01-20", "ວັນສ້າງຕັ້ງກອງທັບປະຊາຊົນລາວ"),
             ("1990-02-01", "ວັນສ້າງຕັ້ງສະຫະພັນກໍາມະບານລາວ"),
             ("1990-03-22", "ວັນສ້າງຕັ້ງພັກປະຊາຊົນປະຕິວັດລາວ"),
@@ -310,8 +304,8 @@ class TestLaos(CommonCountryTests, TestCase):
 
     def test_1996_workdays(self):
         # Prior to 1997's Lao Wildlife Conservation Day Designation.
-        self.assertHolidays(
-            Laos(categories=WORKDAY, years=1996),
+        self.assertWorkdayHolidaysInYear(
+            1996,
             ("1996-01-20", "ວັນສ້າງຕັ້ງກອງທັບປະຊາຊົນລາວ"),
             ("1996-02-01", "ວັນສ້າງຕັ້ງສະຫະພັນກໍາມະບານລາວ"),
             ("1996-03-22", "ວັນສ້າງຕັ້ງພັກປະຊາຊົນປະຕິວັດລາວ"),
@@ -328,8 +322,8 @@ class TestLaos(CommonCountryTests, TestCase):
 
     def test_2017_workdays(self):
         # Prior to 2018 International Children's Day is in `PUBLIC` category
-        self.assertHolidays(
-            Laos(categories=WORKDAY, years=2017),
+        self.assertWorkdayHolidaysInYear(
+            2017,
             ("2017-01-20", "ວັນສ້າງຕັ້ງກອງທັບປະຊາຊົນລາວ"),
             ("2017-02-01", "ວັນສ້າງຕັ້ງສະຫະພັນກໍາມະບານລາວ"),
             ("2017-03-22", "ວັນສ້າງຕັ້ງພັກປະຊາຊົນປະຕິວັດລາວ"),
@@ -345,8 +339,8 @@ class TestLaos(CommonCountryTests, TestCase):
         )
 
     def test_2022_workdays(self):
-        self.assertHolidays(
-            Laos(categories=WORKDAY, years=2022),
+        self.assertWorkdayHolidaysInYear(
+            2022,
             ("2022-01-20", "ວັນສ້າງຕັ້ງກອງທັບປະຊາຊົນລາວ"),
             ("2022-02-01", "ວັນສ້າງຕັ້ງສະຫະພັນກໍາມະບານລາວ"),
             ("2022-03-22", "ວັນສ້າງຕັ້ງພັກປະຊາຊົນປະຕິວັດລາວ"),
