@@ -13,7 +13,7 @@
 from unittest import TestCase
 
 from holidays.constants import BANK, GOVERNMENT
-from holidays.countries.lebanon import Lebanon, LB, LBN
+from holidays.countries.lebanon import Lebanon
 from tests.common import CommonCountryTests
 
 
@@ -26,11 +26,9 @@ class TestLebanon(CommonCountryTests, TestCase):
         cls.government_holidays = Lebanon(categories=GOVERNMENT, years=years)
         cls.no_estimated_holidays = Lebanon(years=years, islamic_show_estimated=False)
 
-    def test_country_aliases(self):
-        self.assertAliases(Lebanon, LB, LBN)
-
     def test_no_holidays(self):
-        self.assertNoHolidays(Lebanon(years=1977))
+        super().test_no_holidays()
+
         self.assertNoHolidays(Lebanon(categories=BANK, years=2019))
         self.assertNoHolidays(Lebanon(categories=GOVERNMENT, years=2019))
 
@@ -311,8 +309,8 @@ class TestLebanon(CommonCountryTests, TestCase):
         self.assertHolidayNameCount(name, 3, self.no_estimated_holidays, range(1986, 1994))
 
     def test_2024(self):
-        self.assertHolidays(
-            Lebanon(years=2024),
+        self.assertHolidaysInYear(
+            2024,
             ("2024-01-01", "رأس السنة الميلادية"),
             ("2024-01-06", "عيد الميلاد عند الطوائف الارمنية الارثوذكسية"),
             ("2024-02-09", "عيد مار مارون"),
