@@ -12,7 +12,7 @@
 
 from unittest import TestCase
 
-from holidays.countries.malaysia import Malaysia, MY, MYS
+from holidays.countries.malaysia import Malaysia
 from tests.common import CommonCountryTests
 
 
@@ -25,12 +25,6 @@ class TestMalaysia(CommonCountryTests, TestCase):
             for subdiv in Malaysia.subdivisions
         }
 
-    def test_country_aliases(self):
-        self.assertAliases(Malaysia, MY, MYS)
-
-    def test_no_holidays(self):
-        self.assertNoHolidays(Malaysia(years=1951))
-
     def test_2023(self):
         rows = (
             ("2023-01-01", (0, 0, 0, 1, 1, 1, 1, 1, 0, 1, 0, 1, 1, 1, 1, 1)),
@@ -1041,8 +1035,8 @@ class TestMalaysia(CommonCountryTests, TestCase):
             self.assertFalse(subdiv_01_holidays.is_weekend(dt))
 
     def test_2024(self):
-        self.assertHolidays(
-            Malaysia(years=2024),
+        self.assertHolidaysInYear(
+            2024,
             ("2024-02-10", "Tahun Baharu Cina"),
             ("2024-02-11", "Tahun Baharu Cina (Hari Kedua)"),
             ("2024-02-12", "Cuti Tahun Baharu Cina (Hari Kedua)"),
