@@ -12,7 +12,7 @@
 
 from unittest import TestCase
 
-from holidays.countries.mauritius import Mauritius, MU, MUS
+from holidays.countries.mauritius import Mauritius
 from tests.common import CommonCountryTests
 
 
@@ -23,12 +23,6 @@ class TestMauritius(CommonCountryTests, TestCase):
         super().setUpClass(Mauritius, years=years)
         cls.no_estimated_holidays = Mauritius(years=years, islamic_show_estimated=False)
 
-    def test_country_aliases(self):
-        self.assertAliases(Mauritius, MU, MUS)
-
-    def test_no_holidays(self):
-        self.assertNoHolidays(Mauritius(years=1987))
-
     def test_special_holidays(self):
         self.assertHolidayName("Public Holiday", "2019-07-29", "2019-09-09")
 
@@ -158,8 +152,8 @@ class TestMauritius(CommonCountryTests, TestCase):
         self.assertHolidayName(name, range(2001, 2036))
 
     def test_2024(self):
-        self.assertHolidays(
-            Mauritius(years=2024),
+        self.assertHolidaysInYear(
+            2024,
             ("2024-01-01", "New Year's Day"),
             ("2024-01-02", "Day after New Year's Day"),
             ("2024-01-25", "Thaipoosam Cavadee"),
