@@ -12,8 +12,8 @@
 
 from unittest import TestCase
 
-from holidays.constants import PUBLIC, WORKDAY
-from holidays.countries.mongolia import Mongolia, MN, MNG
+from holidays.constants import WORKDAY
+from holidays.countries.mongolia import Mongolia
 from tests.common import CommonCountryTests
 
 
@@ -24,12 +24,6 @@ class TestMongolia(CommonCountryTests, TestCase):
         super().setUpClass(Mongolia, years=years)
         cls.workday_holidays = Mongolia(categories=WORKDAY, years=years)
 
-    def test_country_aliases(self):
-        self.assertAliases(Mongolia, MN, MNG)
-
-    def test_no_holidays(self):
-        self.assertNoHolidays(Mongolia(years=2003, categories=(PUBLIC, WORKDAY)))
-
     def test_new_years_day(self):
         self.assertHolidayName("Шинэ жил", (f"{year}-01-01" for year in range(2004, 2050)))
 
@@ -269,8 +263,8 @@ class TestMongolia(CommonCountryTests, TestCase):
         self.assertNoHolidayName(name_2011, self.workday_holidays)
 
     def test_2025(self):
-        self.assertHolidays(
-            Mongolia(years=2025),
+        self.assertHolidaysInYear(
+            2025,
             ("2025-01-01", "Шинэ жил"),
             ("2025-03-01", "Цагаан сар"),
             ("2025-03-02", "Цагаан сар"),
