@@ -12,7 +12,7 @@
 
 from unittest import TestCase
 
-from holidays.countries.myanmar import Myanmar, MM, MMR
+from holidays.countries.myanmar import Myanmar
 from tests.common import CommonCountryTests, WorkingDayTests
 
 
@@ -23,12 +23,6 @@ class TestMyanmar(CommonCountryTests, WorkingDayTests, TestCase):
         super().setUpClass(Myanmar, years=years)
         cls.no_estimated_holidays = Myanmar(years=years, islamic_show_estimated=False)
 
-    def test_country_aliases(self):
-        self.assertAliases(Myanmar, MM, MMR)
-
-    def test_no_holidays(self):
-        self.assertNoHolidays(Myanmar(years=1947))
-
     def test_substituted_holidays(self):
         self.assertHoliday(
             "2024-12-31",
@@ -287,8 +281,8 @@ class TestMyanmar(CommonCountryTests, WorkingDayTests, TestCase):
         )
 
     def test_2024(self):
-        self.assertHolidays(
-            Myanmar(years=2024),
+        self.assertHolidaysInYear(
+            2024,
             ("2024-01-04", "လွတ်လပ်ရေးနေ့"),
             ("2024-01-11", "ကရင်နှစ်သစ်ကူးနေ့"),
             ("2024-02-12", "ပြည်ထောင်စုနေ့"),
