@@ -13,7 +13,7 @@
 import warnings
 from unittest import TestCase
 
-from holidays.countries.new_zealand import NewZealand, NZ, NZL
+from holidays.countries.new_zealand import NewZealand
 from tests.common import CommonCountryTests
 
 
@@ -28,12 +28,6 @@ class TestNZ(CommonCountryTests, TestCase):
         super().setUp()
         warnings.simplefilter("ignore", category=DeprecationWarning)
 
-    def test_country_aliases(self):
-        self.assertAliases(NewZealand, NZ, NZL)
-
-    def test_no_holidays(self):
-        self.assertNoHolidays(NewZealand(years=1893))
-
     def test_new_years(self):
         name = "New Year's Day"
         self.assertHolidayName(name, (f"{year}-01-01" for year in range(1900, 2050)))
