@@ -12,7 +12,7 @@
 
 from unittest import TestCase
 
-from holidays.countries.russia import Russia, RU, RUS
+from holidays.countries.russia import Russia
 from tests.common import CommonCountryTests, WorkingDayTests
 
 
@@ -21,12 +21,6 @@ class TestRussia(CommonCountryTests, WorkingDayTests, TestCase):
     def setUpClass(cls):
         super().setUpClass(Russia, years=range(1991, 2025))
 
-    def test_country_aliases(self):
-        self.assertAliases(Russia, RU, RUS)
-
-    def test_no_holidays(self):
-        self.assertNoHolidays(Russia(years=1990))
-
     def test_substituted_holidays(self):
         self.assertHoliday(
             "1991-05-03",
@@ -386,8 +380,8 @@ class TestRussia(CommonCountryTests, WorkingDayTests, TestCase):
         self.assertNoHolidayName(name_2, range(1991, 1996), range(2005, 2025))
 
     def test_2018(self):
-        self.assertHolidays(
-            Russia(years=2018),
+        self.assertHolidaysInYear(
+            2018,
             ("2018-01-01", "Новогодние каникулы"),
             ("2018-01-02", "Новогодние каникулы"),
             ("2018-01-03", "Новогодние каникулы"),
