@@ -14,7 +14,7 @@ from datetime import date
 from unittest import TestCase
 
 from holidays.calendars.gregorian import JAN, FEB, MAR, APR, MAY, JUN, JUL, AUG, SEP, OCT, NOV, DEC
-from holidays.countries.spain import Spain, ES, ESP
+from holidays.countries.spain import Spain
 from tests.common import CommonCountryTests
 
 
@@ -23,22 +23,39 @@ class TestSpain(CommonCountryTests, TestCase):
     def setUpClass(cls):
         super().setUpClass(Spain)
 
-    def _assertVariableDays(self, year: int, expected_subdiv_holidays: dict):  # noqa: N802
-        observed_subdiv_holidays = {
-            subdiv: Spain(subdiv=subdiv, years=year) for subdiv in Spain.subdivisions
-        }
-        for month_day, subdivisions in expected_subdiv_holidays.items():
-            dt = date(year, *month_day)
-            for subdiv, observed_holidays in observed_subdiv_holidays.items():
+    def _assertVariableDays(self, year: int, subdiv_holidays_mapping: dict):  # noqa: N802
+        for dt, subdivisions in subdiv_holidays_mapping.items():
+            dt = date(year, *dt)
+            for subdiv, holidays in self.subdiv_holidays.items():  # type: ignore[attr-defined]
                 self.assertEqual(
-                    dt in observed_holidays,
+                    dt in holidays,
                     subdiv in subdivisions,
-                    f"Failed date `{dt:%Y-%m-%d}`, subdiv `{subdiv}`: "
-                    f"{', '.join(sorted(subdivisions))}",
+                    f"Failed date `{dt:%Y-%m-%d}`, subdiv `{subdiv}`: {', '.join(subdivisions)}",
                 )
 
-    def test_country_aliases(self):
-        self.assertAliases(Spain, ES, ESP)
+    def test_fixed_holidays_2008(self):
+        self.assertNonObservedHoliday(
+            "2008-01-01",
+            "2008-03-21",
+            "2008-05-01",
+            "2008-08-15",
+            "2008-11-01",
+            "2008-12-06",
+            "2008-12-08",
+            "2008-12-25",
+        )
+
+    def test_fixed_holidays_2009(self):
+        self.assertNonObservedHoliday(
+            "2009-01-01",
+            "2009-01-06",
+            "2009-04-10",
+            "2009-05-01",
+            "2009-08-15",
+            "2009-10-12",
+            "2009-12-08",
+            "2009-12-25",
+        )
 
     def test_fixed_holidays_2010(self):
         self.assertNonObservedHoliday(
@@ -242,6 +259,18 @@ class TestSpain(CommonCountryTests, TestCase):
             "2025-12-25",
         )
 
+    def test_fixed_holidays_2026(self):
+        self.assertNonObservedHoliday(
+            "2026-01-01",
+            "2026-01-06",
+            "2026-04-03",
+            "2026-05-01",
+            "2026-08-15",
+            "2026-10-12",
+            "2026-12-08",
+            "2026-12-25",
+        )
+
     def test_islamic(self):
         self.assertNoHolidayName(
             "Fiesta del Sacrificio-Eidul Adha", Spain(subdiv="CE", years=2009)
@@ -250,6 +279,117 @@ class TestSpain(CommonCountryTests, TestCase):
             "Fiesta del Sacrificio-Aid Al Adha", Spain(subdiv="ML", years=2009)
         )
 
+    def test_variable_holidays_2008(self):
+        province_days = {
+            (JAN, 7): {"AN", "AR", "AS", "CE", "CL", "CM", "CN", "EX", "MD", "ML"},
+            (FEB, 28): {"AN"},
+            (MAR, 1): {"IB"},
+            (MAR, 19): {"CM", "GA", "MC", "ML", "NC", "PV", "VC"},
+            (MAR, 20): {
+                "AN",
+                "AR",
+                "AS",
+                "CB",
+                "CE",
+                "CL",
+                "CM",
+                "CN",
+                "EX",
+                "GA",
+                "IB",
+                "MC",
+                "MD",
+                "ML",
+                "NC",
+                "PV",
+                "RI",
+                "VC",
+            },
+            (MAR, 24): {"CT", "IB", "NC", "PV", "RI", "VC"},
+            (APR, 23): {"AR", "CL"},
+            (MAY, 2): {"MD"},
+            (MAY, 17): {"GA"},
+            (MAY, 30): {"CN"},
+            (MAY, 31): {"CM"},
+            (JUN, 9): {"MC", "RI"},
+            (JUN, 13): {"CE"},
+            (JUN, 24): {"CT"},
+            (JUL, 25): {"GA", "MD", "NC", "PV", "RI"},
+            (JUL, 28): {"CB"},
+            (SEP, 2): {"CE"},
+            (SEP, 8): {"AS", "EX", "ML"},
+            (SEP, 11): {"CT"},
+            (SEP, 15): {"CB"},
+            (SEP, 17): {"ML"},
+            (OCT, 9): {"VC"},
+            (OCT, 13): {"AN", "AR", "AS", "CB", "CE", "CL", "EX", "IB", "MC", "ML"},
+            (DEC, 3): {"NC"},
+            (DEC, 26): {"IB", "CT"},
+        }
+        self._assertVariableDays(2008, province_days)
+
+    def test_variable_holidays_2009(self):
+        province_days = {
+            (FEB, 28): {"AN"},
+            (MAR, 19): {"CL", "CM", "GA", "MC", "MD", "ML", "NC", "PV", "RI", "VC"},
+            (APR, 9): {
+                "AN",
+                "AR",
+                "AS",
+                "CB",
+                "CE",
+                "CL",
+                "CM",
+                "CN",
+                "EX",
+                "GA",
+                "IB",
+                "MC",
+                "MD",
+                "ML",
+                "NC",
+                "PV",
+                "RI",
+                "VC",
+            },
+            (APR, 13): {"CT", "IB", "NC", "PV", "VC"},
+            (APR, 23): {"AR", "CL"},
+            (MAY, 2): {"MD"},
+            (MAY, 30): {"CN"},
+            (JUN, 1): {"CM"},
+            (JUN, 9): {"MC", "RI"},
+            (JUN, 11): {"MD"},
+            (JUN, 13): {"CE"},
+            (JUN, 24): {"CT"},
+            (JUL, 25): {"GA", "NC", "PV"},
+            (JUL, 28): {"CB"},
+            (SEP, 2): {"CE"},
+            (SEP, 8): {"AS", "EX", "ML"},
+            (SEP, 11): {"CT"},
+            (SEP, 15): {"CB"},
+            (SEP, 17): {"ML"},
+            (OCT, 9): {"VC"},
+            (NOV, 2): {"AN", "AR", "AS", "CE", "CL", "EX", "ML"},
+            (DEC, 3): {"NC"},
+            (DEC, 7): {
+                "AN",
+                "AR",
+                "AS",
+                "CB",
+                "CE",
+                "CM",
+                "CN",
+                "EX",
+                "GA",
+                "IB",
+                "MC",
+                "ML",
+                "RI",
+            },
+            (DEC, 26): {"IB", "CT"},
+        }
+        self._assertVariableDays(2009, province_days)
+
     def test_variable_holidays_2010(self):
         province_days = {
             (MAR, 1): {"AN", "IB"},
@@ -279,13 +419,15 @@ class TestSpain(CommonCountryTests, TestCase):
             (MAY, 31): {"CM", "CN"},
             (JUN, 3): {"MD"},
             (JUN, 9): {"MC", "RI"},
+            (JUN, 14): {"CE"},
             (JUN, 24): {"CT"},
             (JUL, 28): {"CB"},
             (AUG, 16): {"AN", "AR", "AS"},
             (SEP, 2): {"CE"},
-            (SEP, 8): {"AS", "EX"},
+            (SEP, 8): {"AS", "EX", "ML"},
             (SEP, 11): {"CT"},
             (SEP, 15): {"CB"},
+            (SEP, 17): {"ML"},
             (OCT, 9): {"VC"},
             (NOV, 17): {"CE", "ML"},
             (DEC, 3): {"NC"},
@@ -324,12 +466,12 @@ class TestSpain(CommonCountryTests, TestCase):
             (MAY, 30): {"CN"},
             (MAY, 31): {"CM"},
             (JUN, 9): {"MC", "RI"},
-            (JUN, 13): {"CT"},
+            (JUN, 13): {"CE", "CT"},
             (JUN, 23): {"CM", "MD"},
             (JUN, 24): {"CT"},
             (JUL, 25): {"CL", "GA", "MD", "NC", "PV", "RI"},
             (JUL, 28): {"CB"},
-            (SEP, 8): {"AS", "EX"},
+            (SEP, 8): {"AS", "EX", "ML"},
             (SEP, 15): {"CB"},
             (OCT, 25): {"PV"},
             (NOV, 7): {"CE", "ML"},
@@ -371,10 +513,12 @@ class TestSpain(CommonCountryTests, TestCase):
             (MAY, 31): {"CM"},
             (JUN, 7): {"CM"},
             (JUN, 9): {"MC", "RI"},
+            (JUN, 13): {"CE"},
             (JUL, 25): {"CB", "GA"},
-            (SEP, 8): {"AS", "EX"},
+            (SEP, 8): {"AS", "EX", "ML"},
             (SEP, 11): {"CT"},
             (SEP, 15): {"CB"},
+            (SEP, 17): {"ML"},
             (OCT, 9): {"VC"},
             (OCT, 25): {"PV"},
             (OCT, 26): {"ML"},
@@ -431,10 +575,12 @@ class TestSpain(CommonCountryTests, TestCase):
             (MAY, 30): {"CM", "CN"},
             (MAY, 31): {"CM"},
             (JUN, 10): {"RI"},
+            (JUN, 13): {"CE"},
             (JUN, 24): {"CT", "GA"},
             (JUL, 25): {"CB", "GA", "NC", "PV"},
-            (SEP, 9): {"AS", "EX"},
+            (SEP, 9): {"AS", "EX", "ML"},
             (SEP, 11): {"CT"},
+            (SEP, 17): {"ML"},
             (OCT, 9): {"VC"},
             (OCT, 15): {"CE", "ML"},
             (OCT, 25): {"PV"},
@@ -474,12 +620,14 @@ class TestSpain(CommonCountryTests, TestCase):
             (MAY, 17): {"GA"},
             (MAY, 30): {"CN"},
             (JUN, 9): {"MC", "RI"},
+            (JUN, 13): {"CE"},
             (JUN, 19): {"CM", "MD"},
             (JUN, 24): {"CT"},
             (JUL, 25): {"CB", "GA"},
-            (SEP, 8): {"AS", "EX"},
+            (SEP, 8): {"AS", "EX", "ML"},
             (SEP, 11): {"CT"},
             (SEP, 15): {"CB"},
+            (SEP, 17): {"ML"},
             (OCT, 4): {"ML"},
             (OCT, 6): {"CE"},
             (OCT, 9): {"VC"},
@@ -520,11 +668,13 @@ class TestSpain(CommonCountryTests, TestCase):
             (MAY, 30): {"CN"},
             (JUN, 4): {"CM"},
             (JUN, 9): {"MC", "RI"},
+            (JUN, 13): {"CE"},
             (JUN, 24): {"CT"},
             (JUL, 25): {"GA", "NC", "PV"},
-            (SEP, 8): {"AS", "EX"},
+            (SEP, 8): {"AS", "EX", "ML"},
             (SEP, 11): {"CT"},
             (SEP, 15): {"CB"},
+            (SEP, 17): {"ML"},
             (SEP, 25): {"CE", "ML"},
             (OCT, 9): {"VC"},
             (NOV, 2): {"AN", "AR", "AS", "CB", "CE", "CL", "CN", "EX", "GA", "IB"},
@@ -568,13 +718,15 @@ class TestSpain(CommonCountryTests, TestCase):
             (MAY, 30): {"CN"},
             (MAY, 31): {"CM"},
             (JUN, 9): {"MC", "RI"},
+            (JUN, 13): {"CE"},
             (JUN, 24): {"CT", "GA"},
             (JUL, 25): {"GA", "MD", "NC", "PV", "RI"},
             (JUL, 28): {"CB"},
             (SEP, 2): {"CE"},
-            (SEP, 8): {"AS", "EX"},
+            (SEP, 8): {"AS", "EX", "ML"},
             (SEP, 12): {"CE", "ML"},
             (SEP, 15): {"CB"},
+            (SEP, 17): {"ML"},
             (OCT, 7): {"PV"},
             (DEC, 3): {"NC"},
             (DEC, 26): {
@@ -630,15 +782,17 @@ class TestSpain(CommonCountryTests, TestCase):
             (MAY, 30): {"CN"},
             (MAY, 31): {"CM"},
             (JUN, 9): {"MC", "RI"},
+            (JUN, 13): {"CE"},
             (JUN, 15): {"CM"},
             (JUN, 24): {"CT"},
             (JUL, 25): {"GA", "NC", "PV"},
             (JUL, 28): {"CB"},
             (SEP, 1): {"CE", "ML"},
             (SEP, 2): {"CE"},
-            (SEP, 8): {"AS", "EX"},
+            (SEP, 8): {"AS", "EX", "ML"},
             (SEP, 11): {"CT"},
             (SEP, 15): {"CB"},
+            (SEP, 18): {"ML"},
             (OCT, 9): {"VC"},
             (DEC, 4): {"NC"},
             (DEC, 26): {"CT"},
@@ -675,12 +829,14 @@ class TestSpain(CommonCountryTests, TestCase):
             (MAY, 30): {"CN"},
             (MAY, 31): {"CM"},
             (JUN, 9): {"MC", "RI"},
+            (JUN, 13): {"CE"},
             (JUL, 25): {"GA"},
             (JUL, 28): {"CB"},
             (AUG, 22): {"CE", "ML"},
-            (SEP, 8): {"AS", "EX"},
+            (SEP, 8): {"AS", "EX", "ML"},
             (SEP, 11): {"CT"},
             (SEP, 15): {"CB"},
+            (SEP, 17): {"ML"},
             (OCT, 9): {"VC"},
             (DEC, 3): {"NC"},
             (DEC, 26): {"CT"},
@@ -719,13 +875,15 @@ class TestSpain(CommonCountryTests, TestCase):
             (MAY, 30): {"CN"},
             (MAY, 31): {"CM"},
             (JUN, 10): {"MC", "RI"},
+            (JUN, 13): {"CE"},
             (JUN, 20): {"CM"},
             (JUN, 24): {"CT", "VC"},
             (JUL, 25): {"CB", "GA", "PV"},
             (AUG, 12): {"CE", "ML"},
             (SEP, 2): {"CE"},
-            (SEP, 9): {"AS", "EX"},
+            (SEP, 9): {"AS", "EX", "ML"},
             (SEP, 11): {"CT"},
+            (SEP, 17): {"ML"},
             (OCT, 9): {"VC"},
             (DEC, 3): {"NC"},
             (DEC, 9): {"AN", "AR", "AS", "CB", "CL", "EX", "MD", "ML", "RI"},
@@ -763,14 +921,16 @@ class TestSpain(CommonCountryTests, TestCase):
             (MAY, 30): {"CN"},
             (JUN, 9): {"MC", "RI"},
             (JUN, 11): {"CM"},
+            (JUN, 13): {"CE"},
             (JUN, 24): {"CT", "GA", "VC"},
             (JUL, 25): {"GA", "PV"},
             (JUL, 28): {"CB"},
             (JUL, 31): {"CE", "ML"},
             (SEP, 2): {"CE"},
-            (SEP, 8): {"AS", "EX"},
+            (SEP, 8): {"AS", "EX", "ML"},
             (SEP, 11): {"CT"},
             (SEP, 15): {"CB"},
+            (SEP, 17): {"ML"},
             (OCT, 9): {"VC"},
             (NOV, 2): {"AN", "AR", "AS", "CL", "EX", "MD"},
             (DEC, 3): {"NC"},
@@ -824,15 +984,17 @@ class TestSpain(CommonCountryTests, TestCase):
             (MAY, 31): {"CM"},
             (JUN, 3): {"CM"},
             (JUN, 9): {"MC", "RI"},
+            (JUN, 14): {"CE"},
             (JUN, 24): {"CT", "VC"},
             (JUL, 20): {"CE"},
             (JUL, 21): {"ML"},
             (JUL, 28): {"CB"},
             (AUG, 16): {"AN", "AR", "AS", "CL", "CN"},
             (SEP, 2): {"CE"},
-            (SEP, 8): {"AS", "EX"},
+            (SEP, 8): {"AS", "EX", "ML"},
             (SEP, 11): {"CT"},
             (SEP, 15): {"CB"},
+            (SEP, 17): {"ML"},
             (OCT, 9): {"VC"},
             (DEC, 3): {"NC"},
         }
@@ -872,6 +1034,7 @@ class TestSpain(CommonCountryTests, TestCase):
             (MAY, 31): {"CM"},
             (JUN, 6): {"CT"},
             (JUN, 9): {"MC", "RI"},
+            (JUN, 13): {"CE"},
             (JUN, 16): {"CM"},
             (JUN, 24): {"CT", "GA", "VC"},
             (JUL, 9): {"CE"},
@@ -881,8 +1044,9 @@ class TestSpain(CommonCountryTests, TestCase):
             (AUG, 5): {"CE"},
             (SEP, 2): {"CE"},
             (SEP, 6): {"PV"},
-            (SEP, 8): {"AS", "EX"},
+            (SEP, 8): {"AS", "EX", "ML"},
             (SEP, 15): {"CB"},
+            (SEP, 17): {"ML"},
             (DEC, 3): {"NC"},
             (DEC, 26): {
                 "AN",
@@ -910,6 +1074,7 @@ class TestSpain(CommonCountryTests, TestCase):
             (FEB, 21): {"EX"},
             (FEB, 28): {"AN"},
             (MAR, 1): {"IB"},
+            (MAR, 13): {"ML"},
             (MAR, 20): {"MD"},
             (APR, 6): {
                 "AN",
@@ -939,12 +1104,13 @@ class TestSpain(CommonCountryTests, TestCase):
             (MAY, 31): {"CM"},
             (JUN, 8): {"CM"},
             (JUN, 9): {"MC", "RI"},
+            (JUN, 13): {"CE"},
             (JUN, 24): {"CT", "VC"},
             (JUN, 29): {"CE", "ML"},
             (JUL, 25): {"CL", "GA", "NC", "PV"},
             (JUL, 28): {"CB"},
             (AUG, 5): {"CE"},
-            (SEP, 8): {"AS", "EX"},
+            (SEP, 8): {"AS", "EX", "ML"},
             (SEP, 11): {"CT"},
             (SEP, 15): {"CB"},
             (OCT, 9): {"VC"},
@@ -985,12 +1151,14 @@ class TestSpain(CommonCountryTests, TestCase):
             (MAY, 30): {"CM", "CN"},
             (MAY, 31): {"CM"},
             (JUN, 10): {"RI"},
+            (JUN, 13): {"CE"},
             (JUN, 17): {"CE", "ML"},
             (JUN, 24): {"CT", "VC"},
             (JUL, 25): {"CB", "GA", "MD", "NC", "PV"},
             (AUG, 5): {"CE"},
             (SEP, 9): {"AS"},
             (SEP, 11): {"CT"},
+            (SEP, 17): {"ML"},
             (OCT, 9): {"VC"},
             (DEC, 3): {"NC"},
             (DEC, 9): {"AN", "AR", "AS", "CL", "EX", "MC", "ML"},
@@ -1031,14 +1199,16 @@ class TestSpain(CommonCountryTests, TestCase):
             (MAY, 31): {"CM"},
             (JUN, 6): {"CE", "ML"},
             (JUN, 9): {"MC", "RI"},
+            (JUN, 13): {"CE"},
             (JUN, 19): {"CM"},
             (JUN, 24): {"CT", "VC"},
             (JUL, 25): {"GA", "MD", "NC", "PV"},
             (JUL, 28): {"CB"},
             (AUG, 5): {"CE"},
-            (SEP, 8): {"AS", "EX"},
+            (SEP, 8): {"AS", "EX", "ML"},
             (SEP, 11): {"CT"},
             (SEP, 15): {"CB"},
+            (SEP, 17): {"ML"},
             (OCT, 9): {"VC"},
             (OCT, 13): {"AN", "AR", "AS", "CL", "EX"},
             (DEC, 3): {"NC"},
@@ -1046,6 +1216,56 @@ class TestSpain(CommonCountryTests, TestCase):
         }
         self._assertVariableDays(2025, province_days)
 
+    def test_variable_holidays_2026(self):
+        province_days = {
+            (FEB, 28): {"AN"},
+            (MAR, 2): {"IB"},
+            (MAR, 19): {"GA", "MC", "NC", "PV", "VC"},
+            (MAR, 20): {"ML"},
+            (APR, 2): {
+                "AN",
+                "AR",
+                "AS",
+                "CB",
+                "CE",
+                "CL",
+                "CM",
+                "CN",
+                "EX",
+                "GA",
+                "IB",
+                "MC",
+                "MD",
+                "ML",
+                "NC",
+                "PV",
+                "RI",
+            },
+            (APR, 6): {"IB", "CM", "CT", "NC", "PV", "RI", "VC"},
+            (APR, 23): {"AR", "CL"},
+            (MAY, 2): {"MD"},
+            (MAY, 27): {"CE", "ML"},
+            (MAY, 30): {"CN"},
+            (JUN, 4): {"CM"},
+            (JUN, 9): {"MC", "RI"},
+            (JUN, 13): {"CE"},
+            (JUN, 24): {"CT", "GA", "VC"},
+            (JUL, 25): {"GA", "PV"},
+            (JUL, 28): {"CB"},
+            (AUG, 5): {"CE"},
+            (SEP, 2): {"CE"},
+            (SEP, 8): {"AS", "EX", "ML"},
+            (SEP, 11): {"CT"},
+            (SEP, 15): {"CB"},
+            (SEP, 17): {"ML"},
+            (OCT, 9): {"VC"},
+            (NOV, 2): {"AN", "AR", "AS", "CN", "CM", "CL", "EX", "MD", "NC"},
+            (DEC, 3): {"NC"},
+            (DEC, 7): {"AN", "AR", "AS", "CB", "CL", "EX", "MC", "MD", "ML", "RI"},
+            (DEC, 26): {"CT", "IB"},
+        }
+        self._assertVariableDays(2026, province_days)
+
     def test_l10n_default(self):
         self.assertLocalizedHolidays(
             ("2023-01-02", "Lunes siguiente a Año Nuevo"),
@@ -1053,6 +1273,7 @@ class TestSpain(CommonCountryTests, TestCase):
             ("2023-02-21", "Martes de Carnaval"),
             ("2023-02-28", "Día de Andalucía"),
             ("2023-03-01", "Día de las Islas Baleares"),
+            ("2023-03-13", "Estatuto de Autonomía de la Ciudad de Melilla"),
             ("2023-03-20", "Lunes siguiente a San José"),
             ("2023-04-06", "Jueves Santo"),
             ("2023-04-07", "Viernes Santo"),
@@ -1066,6 +1287,7 @@ class TestSpain(CommonCountryTests, TestCase):
             ("2023-05-31", "Día de Castilla-La Mancha"),
             ("2023-06-08", "Corpus Christi"),
             ("2023-06-09", "Día de La Rioja; Día de la Región de Murcia"),
+            ("2023-06-13", "San Antonio"),
             ("2023-06-24", "San Juan"),
             ("2023-06-29", "Fiesta del Sacrificio-Aid Al Adha; Fiesta del Sacrificio-Eidul Adha"),
             ("2023-07-25", "Día Nacional de Galicia; Santiago Apóstol"),
@@ -1073,7 +1295,13 @@ class TestSpain(CommonCountryTests, TestCase):
             ("2023-08-05", "Nuestra Señora de África"),
             ("2023-08-15", "Asunción de la Virgen"),
             ("2023-09-02", "Día de Ceuta"),
-            ("2023-09-08", "Día de Asturias; Día de Extremadura"),
+            (
+                "2023-09-08",
+                (
+                    "Día de Asturias; Día de Extremadura; "
+                    "Día de Nuestra Señora la Virgen de la Victoria"
+                ),
+            ),
             ("2023-09-11", "Fiesta Nacional de Cataluña"),
             ("2023-09-15", "La Bien Aparecida"),
             ("2023-10-09", "Día de la Comunidad Valenciana"),
@@ -1094,6 +1322,7 @@ class TestSpain(CommonCountryTests, TestCase):
             ("2023-02-21", "Dimarts de Carnaval"),
             ("2023-02-28", "Dia d'Andalusia"),
             ("2023-03-01", "Dia de les Illes Balears"),
+            ("2023-03-13", "Estatut d'Autonomia de la Ciutat de Melilla"),
             ("2023-03-20", "Dilluns següent a Sant Josep"),
             ("2023-04-06", "Dijous Sant"),
             ("2023-04-07", "Divendres Sant"),
@@ -1107,6 +1336,7 @@ class TestSpain(CommonCountryTests, TestCase):
             ("2023-05-31", "Dia de Castella-la Manxa"),
             ("2023-06-08", "Corpus Christi"),
             ("2023-06-09", "Dia de La Rioja; Dia de la Regió de Múrcia"),
+            ("2023-06-13", "Sant Antoni"),
             ("2023-06-24", "Sant Joan"),
             ("2023-06-29", "Festa del Sacrifici-Aid Al Adha; Festa del Sacrifici-Eidul Adha"),
             ("2023-07-25", "Dia Nacional de Galícia; Sant Jaume Apòstol"),
@@ -1114,7 +1344,10 @@ class TestSpain(CommonCountryTests, TestCase):
             ("2023-08-05", "Nostra Senyora d'Àfrica"),
             ("2023-08-15", "Assumpció de la Verge"),
             ("2023-09-02", "Dia de Ceuta"),
-            ("2023-09-08", "Dia d'Astúries; Dia d'Extremadura"),
+            (
+                "2023-09-08",
+                "Dia d'Astúries; Dia d'Extremadura; Dia de la Mare de Déu de la Victòria",
+            ),
             ("2023-09-11", "Diada Nacional de Catalunya"),
             ("2023-09-15", "La Bien Aparecida"),
             ("2023-10-09", "Dia de la Comunitat Valenciana"),
@@ -1135,6 +1368,7 @@ class TestSpain(CommonCountryTests, TestCase):
             ("2023-02-21", "Shrove Tuesday"),
             ("2023-02-28", "Andalusia Day"),
             ("2023-03-01", "Day of the Balearic Islands"),
+            ("2023-03-13", "Statute of Autonomy of Melilla Day"),
             ("2023-03-20", "Monday following Saint Joseph's Day"),
             ("2023-04-06", "Maundy Thursday"),
             ("2023-04-07", "Good Friday"),
@@ -1148,6 +1382,7 @@ class TestSpain(CommonCountryTests, TestCase):
             ("2023-05-31", "Castilla-La Mancha Day"),
             ("2023-06-08", "Corpus Christi"),
             ("2023-06-09", "La Rioja Day; Murcia Day"),
+            ("2023-06-13", "Saint Anthony's Day"),
             ("2023-06-24", "Saint John the Baptist"),
             ("2023-06-29", "Eid al-Adha"),
             ("2023-07-25", "Galician National Day; Saint James' Day"),
@@ -1155,7 +1390,7 @@ class TestSpain(CommonCountryTests, TestCase):
             ("2023-08-05", "Santa Maria of Africa"),
             ("2023-08-15", "Assumption Day"),
             ("2023-09-02", "Ceuta Day"),
-            ("2023-09-08", "Asturias Day; Extremadura Day"),
+            ("2023-09-08", "Asturias Day; Day of Our Lady of Victory; Extremadura Day"),
             ("2023-09-11", "National Day of Catalonia"),
             ("2023-09-15", "Our Lady of Bien Aparecida"),
             ("2023-10-09", "Valencian Community Day"),
@@ -1168,6 +1403,49 @@ class TestSpain(CommonCountryTests, TestCase):
             ("2023-12-26", "Saint Stephen's Day"),
         )
 
+    def test_l10n_th(self):
+        self.assertLocalizedHolidays(
+            "th",
+            ("2023-01-02", "วันจันทร์หลังวันขึ้นปีใหม่"),
+            ("2023-01-06", "วันสมโภชพระคริสต์แสดงองค์"),
+            ("2023-02-21", "วันอังคารคาร์นิวัล"),
+            ("2023-02-28", "วันอันดาลูเซีย"),
+            ("2023-03-01", "วันหมู่เกาะบาเลอาริก"),
+            ("2023-03-13", "วันกฎธรรมนูญปกครองตนเองแห่งเมืองเมลียา"),
+            ("2023-03-20", "วันจันทร์หลังวันสมโภชนักบุญโยเซฟ"),
+            ("2023-04-06", "วันพฤหัสศักดิ์สิทธิ์"),
+            ("2023-04-07", "วันศุกร์ประเสริฐ"),
+            ("2023-04-10", "วันจันทร์อีสเตอร์"),
+            ("2023-04-21", "วันอีฎิ้ลฟิตริ"),
+            ("2023-04-24", "วันจันทร์หลังวันสมโภชนักบุญจอร์จ"),
+            ("2023-05-01", "วันแรงงาน"),
+            ("2023-05-02", "วันมาดริด"),
+            ("2023-05-17", "วันวรรณกรรมกาลิเซีย"),
+            ("2023-05-30", "วันหมู่เกาะคานารี"),
+            ("2023-05-31", "วันกัสติยา-ลามันชา"),
+            ("2023-06-08", "วันสมโภชพระคริสตวรกาย"),
+            ("2023-06-09", "วันมูร์เซีย; วันลารีโอฆา"),
+            ("2023-06-13", "วันสมโภชนักบุญอันตน"),
+            ("2023-06-24", "วันสมโภชนักบุญยอห์น แบปติสต์บังเกิด"),
+            ("2023-06-29", "วันอีดิ้ลอัฎฮา"),
+            ("2023-07-25", "วันชาติกาลิเซีย; วันสมโภชนักบุญยากอบ อัครสาวก"),
+            ("2023-07-28", "วันสถาบันแห่งกันตาเบรีย"),
+            ("2023-08-05", "วันแม่พระแห่งแอฟริกา"),
+            ("2023-08-15", "วันสมโภชแม่พระรับเกียรติยกขึ้นสวรรค์"),
+            ("2023-09-02", "วันเซวตา"),
+            ("2023-09-08", "วันอัสตูเรียส; วันเอกซ์เตรมาดูรา; วันแม่พระแห่งชัยชนะ"),
+            ("2023-09-11", "วันชาติคาตาลูญญา"),
+            ("2023-09-15", "วันแม่พระแห่งอาปาเรซิดา"),
+            ("2023-10-09", "วันแคว้นบาเลนเซีย"),
+            ("2023-10-12", "วันชาติสเปน"),
+            ("2023-11-01", "วันสมโภชนักบุญทั้งหลาย"),
+            ("2023-12-04", "วันจันทร์หลังวันสมโภชนักบุญฟรังซิสเซเวียร์"),
+            ("2023-12-06", "วันรัฐธรรมนูญสเปน"),
+            ("2023-12-08", "วันสมโภชแม่พระผู้ปฏิสนธินิรมล"),
+            ("2023-12-25", "วันคริสต์มาส"),
+            ("2023-12-26", "วันสมโภชนักบุญสเตเฟน"),
+        )
+
     def test_l10n_uk(self):
         self.assertLocalizedHolidays(
             "uk",
@@ -1176,6 +1454,7 @@ class TestSpain(CommonCountryTests, TestCase):
             ("2023-02-21", "Масний вівторок"),
             ("2023-02-28", "День Андалусії"),
             ("2023-03-01", "День Балеарських островів"),
+            ("2023-03-13", "День Статуту автономії міста Мелілья"),
             ("2023-03-20", "Понеділок після День Святого Йосипа"),
             ("2023-04-06", "Великий четвер"),
             ("2023-04-07", "Страсна пʼятниця"),
@@ -1189,16 +1468,17 @@ class TestSpain(CommonCountryTests, TestCase):
             ("2023-05-31", "День Кастилії-Ла-Манча"),
             ("2023-06-08", "Свято Тіла і Крові Христових"),
             ("2023-06-09", "День Мурсії; День Ріохи"),
+            ("2023-06-13", "День Святого Антонія"),
             ("2023-06-24", "День Івана Хрестителя"),
             ("2023-06-29", "Курбан-байрам"),
             ("2023-07-25", "День Святого Якова; Національний день Галісії"),
             ("2023-07-28", "День Інституцій Кантабрії"),
-            ("2023-08-05", "День Богоматері Африканської"),
+            ("2023-08-05", "День Пресвятої Богородиці Африканської"),
             ("2023-08-15", "Внебовзяття Пресвятої Діви Марії"),
             ("2023-09-02", "День Сеути"),
-            ("2023-09-08", "День Астурії; День Естремадури"),
+            ("2023-09-08", "День Астурії; День Естремадури; День Пресвятої Богородиці Перемоги"),
             ("2023-09-11", "Національний день Каталонії"),
-            ("2023-09-15", "День Богоматері Обʼявлення"),
+            ("2023-09-15", "День Пресвятої Богородиці Обʼявленої"),
             ("2023-10-09", "День Валенсії"),
             ("2023-10-12", "Національний день Іспанії"),
             ("2023-11-01", "День усіх святих"),
