@@ -12,8 +12,8 @@
 
 from unittest import TestCase
 
-from holidays.constants import GOVERNMENT, OPTIONAL, PUBLIC
-from holidays.countries.united_arab_emirates import UnitedArabEmirates, AE, ARE
+from holidays.constants import GOVERNMENT, OPTIONAL
+from holidays.countries.united_arab_emirates import UnitedArabEmirates
 from tests.common import CommonCountryTests
 
 
@@ -25,14 +25,6 @@ class TestUnitedArabEmirates(CommonCountryTests, TestCase):
             years=range(1972, 2050), islamic_show_estimated=False
         )
 
-    def test_country_aliases(self):
-        self.assertAliases(UnitedArabEmirates, AE, ARE)
-
-    def test_no_holidays(self):
-        self.assertNoHolidays(
-            UnitedArabEmirates(years=1971, categories=(GOVERNMENT, OPTIONAL, PUBLIC))
-        )
-
     def test_special(self):
         self.assertHoliday(
             # 29 Ramadan Eid al-Fitr specials.
@@ -161,8 +153,8 @@ class TestUnitedArabEmirates(CommonCountryTests, TestCase):
     def test_2020(self):
         # https://gulfbusiness.com/revealed-uae-private-sector-holidays-for-eid-al-fitr-2020/
         # https://www.timeanddate.com/holidays/united-arab-emirates/2020?hol=134217729
-        self.assertHolidays(
-            UnitedArabEmirates(years=2020),
+        self.assertHolidaysInYear(
+            2020,
             ("2020-01-01", "رأس السنة الميلادية"),
             ("2020-05-22", "عطلة عيد الفطر"),
             ("2020-05-23", "عطلة عيد الفطر"),
